(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[    456924,       9964]
NotebookOptionsPosition[    435129,       9605]
NotebookOutlinePosition[    435579,       9623]
CellTagsIndexPosition[    435536,       9620]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Perturbation calculation for weak gap junction coupling (only linear \
contribution from gap junction and chemical synapse) for the piecewise linear \
neuron of Chow and Kopell 2000.\nThere are two interpretations for the \
calculation. \n1: there are only 2 segments. segment 0 gets no gap or \
synaptic junction input and has its own steady current injection, segment 1 \
gets gap junction and synaptic input with some phase shift that is to be \
determined\n2: there is an infinite sequence of segments and they all have \
the same voltage, except for a phase shift. The gap junction and synaptic \
coupling is weak. Therefore the first-order contribution to the voltage \
satisfies an equation like that of segment 1 driven by segment 0.  v=v0+g*v1\n\
Due to the switch in the spiking current the time has to be broken up into 4 \
parts:\n1: v0 (=segment 0) and v1 are below threshold\n2: v0 is above \
threshold and v1 still below\n3: segment 0 and segment 1 are above threshold\n\
4: segment 1 is after the spike and segment 1 is above threshold\n",
 StyleBox["Important: ",
  FontWeight->"Bold"],
 "This ordering assumes that the spike times differ by less  than the spike \
width. Otherwise, in part 3 segment 0 is after the spike while segment 1 \
still below threshold. Part 4 is unchanged. \nvij[t] is the voltage in \
segment i during part j\nInstead of expanding the threshold time in g, expand \
the current in g, keeping the overall period and with it the threshold time \
fixed (the spike duration Delta is fixed). \nphi is the phase shift between \
the segments, phi>0  corresponds to segment 0 being ahead of segment 1\nsince \
we cannot solve for phi eventually, we solve for I0 as a function of phi. I1, \
however, needs to be determined to satisfy the threshold condition also at \
O(g).\n",
 StyleBox["IMPORTANT: \nIn the final results va needs to be rescaled by \
exp[-xi*ts], since the spiking-current term should be va*exp(xi*(t-ts)] and \
not simply va*exp[t] . This is implemented in defnum below, but not in the \
output sent to matlab\n",
  FontWeight->"Bold"],
 "Some variables are not named exactly as in the paper KimRie22\n\[Delta]",
 StyleBox["  ",
  FontWeight->"Bold"],
 "spike width (w in the paper)\n\[CapitalDelta] delay of type-Ii (\[Tau]_\
\[CapitalDelta] in the paper)\nvth threshold (v_T in the paper)\nVr reversal \
potential (E_syn in the paper)\n"
}], "Text",
 CellChangeTimes->{{3.797586434118161*^9, 3.7975864534914503`*^9}, {
   3.797587275418138*^9, 3.797587630465611*^9}, {3.797587703375689*^9, 
   3.797587709673895*^9}, {3.797588199210805*^9, 3.797588367693193*^9}, {
   3.7975932762833242`*^9, 3.797593420692051*^9}, {3.797602744155704*^9, 
   3.7976027997801847`*^9}, 3.849021191856669*^9, {3.849025100680209*^9, 
   3.849025175045977*^9}, {3.8522925468418922`*^9, 3.852292593772214*^9}, {
   3.852292652951109*^9, 3.852292674393553*^9}, {3.8523658929080343`*^9, 
   3.852366003802763*^9}, {3.8523660568910503`*^9, 3.852366092486887*^9}, {
   3.852366217933877*^9, 3.8523662256900463`*^9}, {3.852368413479857*^9, 
   3.852368414832119*^9}},ExpressionUUID->"4dfaffcc-4d8d-4293-99b2-\
0f6af7a7feb8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNameJoin", "[", 
  RowBox[{"{", 
   RowBox[{"$UserBaseDirectory", ",", "\"\<Applications\>\""}], "}"}], 
  "]"}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"a86198ef-b65c-4ae3-9fe1-f37b416eb620"],

Cell[BoxData["\<\"/Users/hermann/Library/Mathematica/Applications\"\>"], \
"Output",
 CellChangeTimes->{
  3.8039788351695957`*^9, 3.804270155751766*^9, 3.8044462177246933`*^9, 
   3.804598397192712*^9, 3.805044876335352*^9, 3.8069378454611273`*^9, 
   3.807091798045225*^9, {3.8070924285751123`*^9, 3.807092447452519*^9}, 
   3.8070924831768293`*^9, 3.82542504027151*^9, 3.825425155232419*^9, 
   3.825425205209867*^9, 3.828107404385851*^9, 3.828716435952466*^9, 
   3.828716493696003*^9, 3.82871765337716*^9, 3.8320751231542187`*^9, 
   3.832085377292244*^9, 3.839324790986281*^9, 3.849021254890595*^9, 
   3.852115130641309*^9, 3.852137000737404*^9, 3.852137747146668*^9, 
   3.8521427551939087`*^9, 3.852293236387494*^9, 3.852293901705554*^9, 
   3.8522941964922247`*^9, 3.852327479763274*^9, 3.852328166447914*^9, 
   3.8523640859264317`*^9, 3.852364775498259*^9, 3.8523664504470463`*^9, 
   3.853745728466625*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"9bab464a-3879-48c7-a3f6-4546cadf8378"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["\"\</Users/hermann/Library/Mathematica/Applications\>\""], \
"Input",
 CellChangeTimes->{{3.803893382578703*^9, 3.803893383408614*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"528579bc-7d5e-47b7-9135-bf27c64c7795"],

Cell[BoxData["\<\"/Users/hermann/Library/Mathematica/Applications\"\>"], \
"Output",
 CellChangeTimes->{
  3.803978835377244*^9, 3.8042701565770283`*^9, 3.8044462178929033`*^9, 
   3.804598397571422*^9, 3.8050448766114264`*^9, 3.806937845646049*^9, 
   3.807091798129233*^9, {3.807092428744989*^9, 3.8070924520565157`*^9}, 
   3.80709248327124*^9, 3.825425040359185*^9, 3.82542515532839*^9, 
   3.825425205317307*^9, 3.8281074045131407`*^9, 3.828716436944518*^9, 
   3.8287164937593517`*^9, 3.8287176534244633`*^9, 3.832075123426444*^9, 
   3.83208537734341*^9, 3.839324791349102*^9, 3.84902125498816*^9, 
   3.852115130821701*^9, 3.8521370009720573`*^9, 3.852137747212462*^9, 
   3.852142755296628*^9, 3.852293236535828*^9, 3.8522939018317213`*^9, 
   3.852294196607107*^9, 3.852327480051784*^9, 3.85232816660048*^9, 
   3.8523640860959673`*^9, 3.8523647756675243`*^9, 3.852366450616529*^9, 
   3.8537457288259287`*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"24445103-a314-437a-9d4b-644db6078519"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "ToMatlab.m"}]], "Input",
 CellChangeTimes->{{3.803893386454314*^9, 3.803893391299375*^9}, {
  3.803893450662019*^9, 3.803893454073184*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"8a1e072f-7ecc-49ae-8212-d9681a8680cc"],

Cell[BoxData[
 RowBox[{"WriteMatlab", "[", 
  RowBox[{
   RowBox[{"a", "^", "2"}], ",", 
   "\"\<~hermann/Dropbox/Zebrafish_Spine/testmathmatlab.m\>\"", ",", "b"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.803893484239768*^9, 3.803893496885228*^9}, {
  3.803893538691807*^9, 3.803893539256135*^9}, {3.803893575025786*^9, 
  3.803893696838521*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"daff1a6f-8b85-4c35-b5c7-62c24f83f911"],

Cell["\<\
\[LineSeparator]Chemical synapse as double exponential starting at t=Tc1
To incorporate the periodicity and the fact that the synaptic input may not \
decay sufficiently within one period, the synapse is triggered by  the most \
recent spike of the previous segment as well as the earlier spike. One that \
is triggered after the spike in the previous segment (i.e. tc1>T-\[Phi]) and \
one before then (ts<tc2<T-\[Phi]) (the latter case seems more useful, but \
less likely to be realistic)\
\>", "Text",
 CellChangeTimes->{{3.7977601189922743`*^9, 3.79776020429709*^9}, 
   3.828716439409113*^9, {3.8393238103273067`*^9, 3.839323840673972*^9}, {
   3.839324070576715*^9, 3.839324179261272*^9}, 3.852292692418077*^9, {
   3.8523645564061537`*^9, 
   3.8523645676836557`*^9}},ExpressionUUID->"4ca9e746-0910-4191-ac29-\
996be2ad40de"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"S", "=", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gc1", "[", "t_", "]"}], "=", 
  RowBox[{"gc01", " ", 
   RowBox[{"UnitStep", "[", 
    RowBox[{"t", "-", "Tc1"}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[Sigma]f"}], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "Tc1"}], ")"}]}], "]"}], "-", " ", 
     RowBox[{"S", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[Sigma]r"}], " ", 
        RowBox[{"(", 
         RowBox[{"t", "-", "Tc1"}], ")"}]}], "]"}]}]}], ")"}]}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQfehdjt0y7zeOTY3TA0C0w6t9d0C0QvG5ByA6r2sx
+3IgvU1EnhtEf2WStADRx3KmgOlv7TF7QHTE11Ngeo92BdNFIN3B0w+mix4u
enYdSJfdvvMCRB/W6Zt3C0g/rI5cCKJ7+A4cAtH7j10B02fLnk7383nj2OYl
PQ9EKy+K86oOfON45W+iD4g+dFboyiIg7Ve3E0zf+TCjbimQblk1D0yXyv+0
kggFivsyW4Po22IJriB6jWY2mI6xtA8D0S7nXcC0z9l9YZZhbxyDLl0H00Jn
DONAdA6rXDyI/qPZ+tQaSP/a2AmmARS6m/I=
  "],
 CellLabel->"In[5]:=",ExpressionUUID->"3aeb75c3-7116-4a1f-8860-e0871d898682"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.79786016755859*^9, 3.797860191853631*^9}, 
   3.797860923244787*^9, 3.7978657393795233`*^9, 3.7978659435088997`*^9, {
   3.797866007351057*^9, 3.7978660142703323`*^9}, 3.797866518658876*^9, 
   3.797874686048045*^9, 3.797881255131027*^9, 3.7978819746309633`*^9, 
   3.797927801478147*^9, 3.797928427818368*^9, 3.797929819455675*^9, 
   3.7979302617208157`*^9, 3.797930715992938*^9, 3.797940009423173*^9, 
   3.797940566939101*^9, 3.7979407260030823`*^9, 3.7979410111756287`*^9, 
   3.798103303505515*^9, 3.798111419658474*^9, 3.798329528526*^9, 
   3.798381665253824*^9, 3.7984772247146893`*^9, 3.798795037870417*^9, 
   3.798843439972542*^9, 3.799059602089694*^9, 3.799076829055709*^9, 
   3.7996827436099586`*^9, 3.800348498712573*^9, 3.800814550184629*^9, {
   3.80081491462435*^9, 3.8008149291894083`*^9}, 3.800816227828334*^9, 
   3.800816260546471*^9, 3.800828401652775*^9, 3.8008301963259068`*^9, 
   3.800830339611883*^9, 3.800869035272449*^9, 3.8008707885458603`*^9, {
   3.8008709747792187`*^9, 3.800870990469331*^9}, 3.800897125180717*^9, 
   3.800897197476961*^9, 3.800900915309595*^9, 3.800901496885578*^9, 
   3.800902654418826*^9, 3.800905166052821*^9, 3.800962045508905*^9, 
   3.800968200822742*^9, 3.8013308492972813`*^9, 3.802709270816668*^9, {
   3.802710586183113*^9, 3.802710606578923*^9}, 3.802713468173605*^9, 
   3.80271358972753*^9, 3.8027652488046713`*^9, 3.802770726482562*^9, 
   3.802771362262981*^9, 3.802774643008623*^9, 3.8031177549723177`*^9, 
   3.803196876549386*^9, 3.8033023031151447`*^9, 3.8033026498825293`*^9, 
   3.803302680000061*^9, 3.8033078310421753`*^9, 3.803324087665495*^9, 
   3.8034116086305923`*^9, 3.803412127298478*^9, 3.8034121671572323`*^9, 
   3.803474719103389*^9, 3.803729346437632*^9, 3.8037432419936857`*^9, 
   3.803806381845216*^9, 3.803807927740576*^9, 3.8038120469373913`*^9, 
   3.8038248483844023`*^9, 3.803829789596023*^9, 3.803891448016594*^9, 
   3.8039788354425488`*^9, 3.804270156665495*^9, 3.804446217990223*^9, 
   3.804598397733439*^9, 3.805044876713965*^9, 3.806937845704164*^9, 
   3.807091798246203*^9, 3.807092428855782*^9, 3.807092483334676*^9, 
   3.82542504042273*^9, 3.825425155381611*^9, 3.825425205370377*^9, 
   3.828107404565226*^9, 3.828716441610086*^9, 3.828716493816463*^9, 
   3.828717653494129*^9, 3.832075123488909*^9, 3.832085377393845*^9, 
   3.8393247913956347`*^9, 3.849021255091456*^9, 3.852115130878845*^9, 
   3.852137001024356*^9, 3.85213774728082*^9, 3.852142755355281*^9, 
   3.852284620928351*^9, 3.85229323658988*^9, 3.85229390188199*^9, 
   3.852294196679879*^9, 3.8523274801114683`*^9, 3.852328166650681*^9, 
   3.8523640861524878`*^9, 3.8523647757662086`*^9, 3.852366450679872*^9, 
   3.853745728882782*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"ca382533-5772-489a-bb1b-26cbdd006735"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], ")"}]}]], "-", 
    
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], ")"}]}]]}], 
   ")"}], " ", "gc01", " ", 
  RowBox[{"UnitStep", "[", 
   RowBox[{"t", "-", "Tc1"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.79786016755859*^9, 3.797860191853631*^9}, 
   3.797860923244787*^9, 3.7978657393795233`*^9, 3.7978659435088997`*^9, {
   3.797866007351057*^9, 3.7978660142703323`*^9}, 3.797866518658876*^9, 
   3.797874686048045*^9, 3.797881255131027*^9, 3.7978819746309633`*^9, 
   3.797927801478147*^9, 3.797928427818368*^9, 3.797929819455675*^9, 
   3.7979302617208157`*^9, 3.797930715992938*^9, 3.797940009423173*^9, 
   3.797940566939101*^9, 3.7979407260030823`*^9, 3.7979410111756287`*^9, 
   3.798103303505515*^9, 3.798111419658474*^9, 3.798329528526*^9, 
   3.798381665253824*^9, 3.7984772247146893`*^9, 3.798795037870417*^9, 
   3.798843439972542*^9, 3.799059602089694*^9, 3.799076829055709*^9, 
   3.7996827436099586`*^9, 3.800348498712573*^9, 3.800814550184629*^9, {
   3.80081491462435*^9, 3.8008149291894083`*^9}, 3.800816227828334*^9, 
   3.800816260546471*^9, 3.800828401652775*^9, 3.8008301963259068`*^9, 
   3.800830339611883*^9, 3.800869035272449*^9, 3.8008707885458603`*^9, {
   3.8008709747792187`*^9, 3.800870990469331*^9}, 3.800897125180717*^9, 
   3.800897197476961*^9, 3.800900915309595*^9, 3.800901496885578*^9, 
   3.800902654418826*^9, 3.800905166052821*^9, 3.800962045508905*^9, 
   3.800968200822742*^9, 3.8013308492972813`*^9, 3.802709270816668*^9, {
   3.802710586183113*^9, 3.802710606578923*^9}, 3.802713468173605*^9, 
   3.80271358972753*^9, 3.8027652488046713`*^9, 3.802770726482562*^9, 
   3.802771362262981*^9, 3.802774643008623*^9, 3.8031177549723177`*^9, 
   3.803196876549386*^9, 3.8033023031151447`*^9, 3.8033026498825293`*^9, 
   3.803302680000061*^9, 3.8033078310421753`*^9, 3.803324087665495*^9, 
   3.8034116086305923`*^9, 3.803412127298478*^9, 3.8034121671572323`*^9, 
   3.803474719103389*^9, 3.803729346437632*^9, 3.8037432419936857`*^9, 
   3.803806381845216*^9, 3.803807927740576*^9, 3.8038120469373913`*^9, 
   3.8038248483844023`*^9, 3.803829789596023*^9, 3.803891448016594*^9, 
   3.8039788354425488`*^9, 3.804270156665495*^9, 3.804446217990223*^9, 
   3.804598397733439*^9, 3.805044876713965*^9, 3.806937845704164*^9, 
   3.807091798246203*^9, 3.807092428855782*^9, 3.807092483334676*^9, 
   3.82542504042273*^9, 3.825425155381611*^9, 3.825425205370377*^9, 
   3.828107404565226*^9, 3.828716441610086*^9, 3.828716493816463*^9, 
   3.828717653494129*^9, 3.832075123488909*^9, 3.832085377393845*^9, 
   3.8393247913956347`*^9, 3.849021255091456*^9, 3.852115130878845*^9, 
   3.852137001024356*^9, 3.85213774728082*^9, 3.852142755355281*^9, 
   3.852284620928351*^9, 3.85229323658988*^9, 3.85229390188199*^9, 
   3.852294196679879*^9, 3.8523274801114683`*^9, 3.852328166650681*^9, 
   3.8523640861524878`*^9, 3.8523647757662086`*^9, 3.852366450679872*^9, 
   3.853745728887005*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"663c6978-aecf-4031-a17e-7df0ab82c3c0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defgc01", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"gc1", "[", "t", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "Tc1", ",", "Infinity"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Tc1", ">", "0"}], ",", 
          RowBox[{"\[Sigma]r", ">", "0"}], ",", 
          RowBox[{"\[Sigma]f", ">", "0"}]}], "}"}]}], "]"}], "\[Equal]", 
      "gcn"}], ",", "gc01"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.80381421902125*^9, 3.8038142322789288`*^9}, {
  3.803814569523678*^9, 3.8038145965427237`*^9}, {3.803814637840234*^9, 
  3.803814671051751*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"52a9f14b-01ed-48af-a73c-1025905a54b3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"gc01", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"gcn", " ", "\[Sigma]f", " ", "\[Sigma]r"}], 
     RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.803814240465026*^9, {3.8038145926798363`*^9, 3.803814602705217*^9}, {
   3.803814662178713*^9, 3.803814677148746*^9}, 3.8038248557493*^9, 
   3.803829796468545*^9, 3.803891455188612*^9, 3.80397884281749*^9, 
   3.804270163115603*^9, 3.804446225100465*^9, 3.804598404449277*^9, 
   3.805044884635522*^9, 3.806937852945797*^9, 3.80709180611723*^9, 
   3.807092433098034*^9, 3.807092490495619*^9, 3.825425047549911*^9, 
   3.825425163079626*^9, 3.8254252054553537`*^9, 3.8281074121421537`*^9, 
   3.828716452105434*^9, 3.828716499895151*^9, 3.828717659865595*^9, 
   3.832075131203599*^9, 3.832085384880538*^9, 3.83932479876672*^9, 
   3.849021261438858*^9, 3.8521151382937403`*^9, 3.852137008553323*^9, 
   3.8521377534643393`*^9, 3.852142761434353*^9, 3.852284629738525*^9, 
   3.852293242456934*^9, 3.852293909729353*^9, 3.852294204406948*^9, 
   3.8523274861638536`*^9, 3.852328174444882*^9, 3.85236409382228*^9, 
   3.8523647834709377`*^9, 3.852366458519019*^9, 3.853745736702004*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"4d7dc536-8b67-442c-a08d-3ee990f3b10c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{"gc01", "=", "0"}], "*)"}]], "Input",
 CellChangeTimes->{{3.825425028197344*^9, 3.825425029024794*^9}, {
  3.8254251391873417`*^9, 3.825425140069325*^9}, {3.82871642886062*^9, 
  3.828716449949965*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"eedf817a-5494-4048-85b8-4ec7d8800752"],

Cell[TextData[{
 "\[LineSeparator]",
 StyleBox["To speed up the computation for testing purposes turn off the \
synaptic contributions from previous spikes. For the full result we need to \
set \[Alpha], \[Beta], and \[Gamma] to 1",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.8393239261330023`*^9, 3.839323943816216*^9}, {
   3.839324253423822*^9, 3.839324345169614*^9}, 3.84902120627206*^9, {
   3.852284625770845*^9, 3.852284643121299*^9}, {3.8522927194394073`*^9, 
   3.85229271965926*^9}, {3.852364745824544*^9, 
   3.852364755668373*^9}},ExpressionUUID->"e99b3b4a-d7a5-4800-8ad7-\
e28b2b708469"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"def\[Alpha]\[Beta]\[Gamma]", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Alpha]", "->", "1"}], ",", 
    RowBox[{"\[Beta]", "->", "1"}], ",", 
    RowBox[{"\[Gamma]", "->", "1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.800901477541459*^9, 3.800901484653034*^9}, {
  3.8009681937882433`*^9, 3.800968194283012*^9}, {3.828716457224478*^9, 
  3.828716461710359*^9}, {3.828717634204215*^9, 3.828717647024271*^9}, {
  3.83932728014323*^9, 3.839327289716075*^9}, {3.852293222919838*^9, 
  3.852293225779871*^9}, {3.852293849439052*^9, 3.8522938787318993`*^9}, {
  3.8523647575890427`*^9, 3.852364760538826*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"4a5379c6-5f3b-43b4-843c-cd67a794a889"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Alpha]", "\[Rule]", "1"}], ",", 
   RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8287176599453497`*^9, 3.832075131411872*^9, 3.8320853850124283`*^9, 
   3.8393247989463663`*^9, 3.8393272852651663`*^9, 3.849021261581991*^9, 
   3.852115138441332*^9, 3.852137008689481*^9, 3.852137753521866*^9, 
   3.8521427614961843`*^9, {3.852284629964219*^9, 3.852284647834746*^9}, 
   3.852293242536413*^9, {3.852293885810512*^9, 3.852293909896061*^9}, 
   3.852294204545979*^9, 3.852327486238792*^9, 3.852328174639196*^9, 
   3.8523640940097237`*^9, 3.852364783672051*^9, 3.8523664587236013`*^9, 
   3.853745736854897*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"b0b9d21c-6563-49b6-b89f-84e8c2c1d830"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Xi]", "=", 
  RowBox[{"\[Psi]", " ", "-", "1"}]}]], "Input",
 CellChangeTimes->{{3.797850002893092*^9, 3.797850008530732*^9}, {
  3.825432430141185*^9, 3.825432441184956*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"46fa5bc8-d136-4d23-a5ed-0f23f0782278"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", "\[Psi]"}]], "Output",
 CellChangeTimes->{{3.797850010680331*^9, 3.797850014266469*^9}, 
   3.7978546962626534`*^9, 3.7978588205927153`*^9, 3.797859214748206*^9, 
   3.797859604817972*^9, 3.797859746756248*^9, 3.797860191988348*^9, 
   3.7978609234925623`*^9, 3.797865943670483*^9, {3.797866009888597*^9, 
   3.7978660143981657`*^9}, 3.797866518787175*^9, 3.7978746861375427`*^9, 
   3.797881258933193*^9, 3.7978819751399097`*^9, 3.797927801636715*^9, 
   3.7979284279854517`*^9, 3.79792981961115*^9, 3.797930261821085*^9, 
   3.7979307167628193`*^9, 3.79794000955509*^9, 3.797940567074914*^9, 
   3.79794072614349*^9, 3.797941011325184*^9, 3.798103303675063*^9, 
   3.798111419779848*^9, 3.7983295287836657`*^9, 3.7983816657317133`*^9, 
   3.798477224856485*^9, 3.798795038682683*^9, 3.798843440269383*^9, 
   3.799059602285578*^9, 3.799076829298791*^9, 3.7996827440147543`*^9, 
   3.800348498911573*^9, 3.800814550377452*^9, 3.80081492933504*^9, 
   3.80081626096834*^9, 3.800828401875774*^9, 3.800830196404413*^9, 
   3.800830339813936*^9, 3.800869035399708*^9, 3.8008707886232033`*^9, 
   3.80087099048096*^9, 3.8008971262454243`*^9, 3.800897166174246*^9, 
   3.800897197546443*^9, 3.8009009153775797`*^9, 3.800901497010585*^9, 
   3.8009026545565977`*^9, 3.800905166196632*^9, 3.800962045631123*^9, 
   3.800968201051937*^9, 3.8013308496357718`*^9, 3.80270927099326*^9, {
   3.802710586362049*^9, 3.802710607927841*^9}, 3.802713468334392*^9, 
   3.8027135899373837`*^9, 3.8027652489359713`*^9, 3.8027707267251053`*^9, 
   3.802771362477841*^9, 3.802774643147731*^9, 3.803117755126081*^9, 
   3.803196876684125*^9, 3.803302303390337*^9, 3.803302680213338*^9, 
   3.803307831165875*^9, 3.803324087917798*^9, 3.803411608764141*^9, 
   3.803412127382976*^9, 3.8034121673768387`*^9, 3.803474719389832*^9, 
   3.803729346666609*^9, 3.8037432421587687`*^9, 3.803806382059547*^9, 
   3.803807927951426*^9, 3.8038120471416893`*^9, 3.8038248558426456`*^9, 
   3.803829796578724*^9, 3.803891455330347*^9, 3.803978842967383*^9, 
   3.804270163208445*^9, 3.804446225273674*^9, 3.8045984046052227`*^9, 
   3.805044884852421*^9, 3.806937853109562*^9, 3.807091806415316*^9, 
   3.807092490693736*^9, 3.825425047693886*^9, 3.82542516324233*^9, 
   3.8254252055224447`*^9, {3.8254324430533247`*^9, 3.825432486859543*^9}, 
   3.82810741229497*^9, 3.82871646504762*^9, 3.8287165000025997`*^9, 
   3.8287176600044823`*^9, 3.8320751314694567`*^9, 3.8320853850214*^9, 
   3.839324798962531*^9, 3.849021261679706*^9, 3.8521151384531918`*^9, 
   3.852137008740944*^9, 3.852137753537387*^9, 3.8521427615146427`*^9, 
   3.852284650800952*^9, 3.8522932425808983`*^9, 3.8522939099062366`*^9, 
   3.85229420458134*^9, 3.8523274862945127`*^9, 3.852328174648994*^9, 
   3.852364094020371*^9, 3.8523647836808558`*^9, 3.852366458771097*^9, 
   3.853745736883423*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"86d62c03-f495-4f55-8a2c-6ef4eb228b61"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "The", " ", "chemical", " ", "synapse", " ", "needs", " ", "to", " ", 
     "be", " ", "triggered", " ", "within", " ", "the", " ", "period"}], ",", 
    
    RowBox[{
    "otherwise", " ", "contributions", " ", "in", " ", "the", " ", 
     "equations", " ", "will", " ", "be", " ", 
     RowBox[{"missing", ".", " ", "Even"}], " ", "then", " ", "it", " ", "is",
      " ", "an", " ", "approximation", " ", "for", " ", "sufficiently", " ", 
     "fast", " ", "decaying", " ", "synapses"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"$Assumptions_", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Tc1", ">", "0"}], ",", 
      RowBox[{"Tc1", "<", "T"}]}], "}"}]}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.797866401259281*^9, 3.797866421935754*^9}, {
   3.79786646498951*^9, 3.797866498906345*^9}, {3.797881222519701*^9, 
   3.797881223593935*^9}, {3.79788175074765*^9, 3.7978817538814087`*^9}, {
   3.797939930453945*^9, 3.797939970156416*^9}, 3.7979405497458973`*^9, 
   3.797940714036216*^9, {3.800897117665938*^9, 3.800897142481833*^9}, 
   3.852292738354641*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"accaaae3-2335-4172-8022-198663c6a02f"],

Cell[CellGroupData[{

Cell["O(1)", "Section",
 CellChangeTimes->{{3.79759198176595*^9, 3.7975919828294067`*^9}, {
   3.797764052948859*^9, 3.7977640553146477`*^9}, 3.828716479150956*^9, {
   3.852284660106058*^9, 
   3.852284663370932*^9}},ExpressionUUID->"68d0a436-1a95-43b1-be8a-\
3f42197fe5f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq01", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"v01", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
   RowBox[{"v01", "[", "t", "]"}], "+", "I0", "  "}]}]], "Input",
 CellChangeTimes->{{3.7827550725131073`*^9, 3.7827551378250523`*^9}, {
  3.782755203326262*^9, 3.782755221279893*^9}, {3.782755581808998*^9, 
  3.7827556092988987`*^9}, {3.7827557747965307`*^9, 3.782755776713986*^9}, {
  3.7827569188683243`*^9, 3.7827569197295923`*^9}, {3.852284665416375*^9, 
  3.852284667753664*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"25aa7f8d-59e2-416d-a950-2579b62036c4"],

Cell[BoxData[
 RowBox[{"I0", "-", 
  RowBox[{"v01", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v01", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.7827556640471888`*^9, 3.782755777278185*^9, 3.782755912722966*^9, 
   3.7827569222997227`*^9, 3.782756989627604*^9, 3.7827573095842113`*^9, 
   3.782758318481613*^9, 3.782758459620554*^9, 3.78276074173818*^9, 
   3.797587482613484*^9, 3.797587719857327*^9, 3.797587886719943*^9, 
   3.797596454436472*^9, 3.7976007608270283`*^9, 3.797600791076004*^9, 
   3.7976014216593037`*^9, 3.7976020986447783`*^9, 3.797602139943646*^9, 
   3.7976022096596746`*^9, 3.7976022627415743`*^9, {3.797602323422017*^9, 
   3.797602349482893*^9}, 3.797618743714514*^9, 3.797619206535605*^9, 
   3.7976195810366297`*^9, 3.797619631365431*^9, 3.79761974829583*^9, 
   3.797619825113879*^9, 3.79776046202689*^9, 3.79776069596522*^9, 
   3.797760872072797*^9, 3.797761522725469*^9, 3.797762012346952*^9, 
   3.797762042986828*^9, 3.797763931928677*^9, 3.797763991984748*^9, 
   3.797764046902904*^9, 3.797764251142413*^9, 3.797764560703006*^9, 
   3.797765255830288*^9, 3.797765526773479*^9, 3.797765778703497*^9, 
   3.797766118763996*^9, 3.797774307004265*^9, 3.7977885891257563`*^9, 
   3.797794568327447*^9, 3.797794703392386*^9, 3.79779473607231*^9, 
   3.7977948721109543`*^9, 3.797794972122315*^9, 3.7978431796574793`*^9, 
   3.7978457505779552`*^9, 3.797846042182852*^9, 3.797847231142304*^9, 
   3.797849044953925*^9, 3.797849118533791*^9, 3.79784936254109*^9, 
   3.7978496347708473`*^9, 3.797849723786294*^9, 3.797849923626506*^9, 
   3.7978500142778463`*^9, 3.797854696304514*^9, 3.797858820635006*^9, 
   3.797859214803629*^9, 3.797859604853175*^9, 3.797859746770247*^9, 
   3.797860192027426*^9, 3.797860923547022*^9, 3.7978657694754887`*^9, 
   3.7978659437369757`*^9, 3.797866014470471*^9, 3.797866518904358*^9, 
   3.797874686276882*^9, 3.797881261975531*^9, 3.79788197553377*^9, 
   3.797927801838626*^9, 3.797928428203578*^9, 3.7979298197648497`*^9, 
   3.797930261995348*^9, 3.7979307169724827`*^9, 3.797940009861287*^9, 
   3.797940567336359*^9, 3.797940726514566*^9, 3.79794101160387*^9, 
   3.7981033038376513`*^9, 3.798111419972687*^9, 3.7983295290211287`*^9, 
   3.798381665875421*^9, 3.7984772251040087`*^9, 3.798795038937545*^9, 
   3.798843440524482*^9, 3.799059602474847*^9, 3.799076829522469*^9, 
   3.799682744397703*^9, 3.800348499094195*^9, 3.800814550582712*^9, 
   3.800814929581965*^9, 3.800816261302854*^9, 3.8008284021949472`*^9, 
   3.8008301965331583`*^9, 3.800830340041769*^9, 3.800869035579266*^9, 
   3.800870788753368*^9, 3.8008709907075157`*^9, 3.800897197651615*^9, 
   3.800900915457739*^9, 3.80090149712157*^9, 3.8009026546658154`*^9, 
   3.800905166313229*^9, 3.800962045736125*^9, 3.800968201154108*^9, 
   3.8013308498039427`*^9, 3.802709271160201*^9, {3.802710586445224*^9, 
   3.8027106080869417`*^9}, 3.802713468422573*^9, 3.8027135899993153`*^9, 
   3.802765249030181*^9, 3.8027707267851353`*^9, 3.802771362584144*^9, 
   3.802774643231717*^9, 3.803117755211211*^9, 3.803196876743573*^9, 
   3.8033023035112762`*^9, 3.8033026803761883`*^9, 3.803307831266933*^9, 
   3.803324088026465*^9, 3.803411608859518*^9, 3.8034121274900312`*^9, 
   3.803412167508972*^9, 3.8034747195226593`*^9, 3.803729346758377*^9, 
   3.803743242235251*^9, 3.803806382119666*^9, 3.803807928010502*^9, 
   3.8038120471956053`*^9, 3.803824855912232*^9, 3.803829796741849*^9, 
   3.803891455413937*^9, 3.803978843044318*^9, 3.8042701633824053`*^9, 
   3.804446225384273*^9, 3.8045984047545643`*^9, 3.805044884945265*^9, 
   3.806937853169924*^9, 3.807091806584901*^9, 3.8070924908655453`*^9, 
   3.825425047765224*^9, 3.825425163317219*^9, 3.825425205543672*^9, 
   3.828107412359839*^9, {3.828716481268889*^9, 3.82871650008543*^9}, 
   3.828717660087446*^9, 3.832075131584239*^9, 3.83208538511125*^9, 
   3.8393247990560217`*^9, 3.849021261799185*^9, 3.8521151385552053`*^9, 
   3.852137008850252*^9, 3.8521377536435013`*^9, 3.852142761629465*^9, 
   3.852284668844421*^9, 3.852293242624282*^9, 3.852293909972663*^9, 
   3.8522942046214867`*^9, 3.852327486359075*^9, 3.852328174694765*^9, 
   3.852364094076832*^9, 3.852364783755137*^9, 3.8523664588378153`*^9, 
   3.85374573691502*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"3e7136aa-4b6a-442d-9e0c-b3164f0b8d17"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"defv01d", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"deq01", "\[Equal]", "0"}], "}"}], ",", "v01", ",", "t"}], 
     "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"defIC01", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v01", "[", "0", "]"}], "/.", "defv01d"}], "}"}], "\[Equal]", 
      "V00"}], ",", 
     RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"defv01", "=", 
  RowBox[{"defv01d", "/.", "defIC01"}]}]}], "Input",
 CellChangeTimes->{{3.797761996800597*^9, 3.797762004369261*^9}, {
  3.797762095156084*^9, 3.797762122689064*^9}, {3.797762569165408*^9, 
  3.7977625853233347`*^9}, {3.797764502208493*^9, 3.797764502911772*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"b1ac7172-ffbb-4c2f-856e-992ff4ca7054"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v01", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{"I0", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       TemplateBox[{"1"},
        "C"]}]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797762007574184*^9, 3.797762015791391*^9}, 
   3.797762048403474*^9, {3.797762096895315*^9, 3.797762123364874*^9}, 
   3.797762589815042*^9, 3.797763932021935*^9, 3.797763992055852*^9, 
   3.797764046971744*^9, 3.797764251202983*^9, 3.7977645048243637`*^9, 
   3.797764560772008*^9, 3.797765255889024*^9, 3.797765526827474*^9, 
   3.797765778754184*^9, 3.797766118838984*^9, 3.797774307057869*^9, 
   3.797788589153913*^9, 3.7977945683883047`*^9, 3.7977947034470367`*^9, 
   3.7977947361215343`*^9, 3.79779487219851*^9, 3.797794972165085*^9, 
   3.797843179749316*^9, 3.7978457506576643`*^9, 3.797846042219879*^9, 
   3.797847231227578*^9, 3.797849045005834*^9, 3.797849118604653*^9, 
   3.7978493625997057`*^9, 3.797849634817884*^9, 3.79784972387566*^9, 
   3.7978499236786127`*^9, 3.797850014319191*^9, 3.797854696355344*^9, 
   3.797858820719471*^9, 3.797859214883679*^9, 3.797859604901162*^9, 
   3.797859746835083*^9, 3.797860192073792*^9, 3.7978609236074753`*^9, 
   3.7978657704785852`*^9, 3.797865943840616*^9, 3.797866014486208*^9, 
   3.797866518950715*^9, 3.797874686337919*^9, 3.797881262760754*^9, 
   3.797881975736858*^9, 3.797927801936915*^9, 3.7979284282991056`*^9, 
   3.797929819859252*^9, 3.7979302620556383`*^9, 3.7979307170485363`*^9, 
   3.797940009937934*^9, 3.797940567447145*^9, 3.797940726570633*^9, 
   3.7979410116597557`*^9, 3.798103303899774*^9, 3.7981114200190372`*^9, 
   3.798329529127898*^9, 3.798381665936233*^9, 3.798477225214884*^9, 
   3.798795039110229*^9, 3.798843440614626*^9, 3.799059602556315*^9, 
   3.7990768296105003`*^9, 3.799682744526547*^9, 3.800348499168276*^9, 
   3.800814550659771*^9, 3.800814929645811*^9, 3.800816261401786*^9, 
   3.800828403020702*^9, 3.800830196583169*^9, 3.800830340112109*^9, 
   3.80086903565056*^9, 3.8008707888030033`*^9, 3.8008709907541122`*^9, 
   3.800897197709609*^9, 3.800900915514406*^9, 3.800901497177526*^9, 
   3.800902654752605*^9, 3.8009051664113483`*^9, 3.800962045806518*^9, 
   3.800968201214416*^9, 3.8013308499066267`*^9, 3.802709271247632*^9, {
   3.802710586510352*^9, 3.802710608214451*^9}, 3.8027134685121117`*^9, 
   3.802713590038003*^9, 3.802765249086426*^9, 3.8027707268473787`*^9, 
   3.802771362669487*^9, 3.802774643314526*^9, 3.803117755368897*^9, 
   3.8031968767943087`*^9, 3.803302303651978*^9, 3.803302680495051*^9, 
   3.803307831325851*^9, 3.8033240881206093`*^9, 3.80341160892001*^9, 
   3.803412127536875*^9, 3.803412167562828*^9, 3.8034747195998*^9, 
   3.8037293468844967`*^9, 3.803743242292204*^9, 3.803806382170341*^9, 
   3.803807928061968*^9, 3.8038120472499647`*^9, 3.803824855953882*^9, 
   3.803829796831237*^9, 3.803891455451413*^9, 3.8039788430926933`*^9, 
   3.8042701634267807`*^9, 3.804446225441481*^9, 3.804598404815477*^9, 
   3.805044885040607*^9, 3.8069378532403517`*^9, 3.807091806678665*^9, 
   3.807092490953742*^9, 3.825425047807212*^9, 3.825425163358753*^9, 
   3.8254252055792637`*^9, 3.828107412415732*^9, {3.828716483264584*^9, 
   3.8287165001432247`*^9}, 3.828717660140732*^9, 3.8320751316492853`*^9, 
   3.832085385159844*^9, 3.839324799110093*^9, 3.849021261877104*^9, 
   3.85211513861086*^9, 3.852137008905929*^9, 3.8521377536866417`*^9, 
   3.8521427616760597`*^9, 3.852284670252002*^9, 3.852293242665489*^9, 
   3.852293910027337*^9, 3.85229420467393*^9, 3.8523274864172153`*^9, 
   3.852328174749358*^9, 3.852364094131023*^9, 3.852364783825161*^9, 
   3.852366458892273*^9, 3.8537457369672203`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"2c46e15b-9e71-4623-9344-7058ed119ef0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"1"},
    "C"], "\[Rule]", 
   RowBox[{
    RowBox[{"-", "I0"}], "+", "V00"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797762007574184*^9, 3.797762015791391*^9}, 
   3.797762048403474*^9, {3.797762096895315*^9, 3.797762123364874*^9}, 
   3.797762589815042*^9, 3.797763932021935*^9, 3.797763992055852*^9, 
   3.797764046971744*^9, 3.797764251202983*^9, 3.7977645048243637`*^9, 
   3.797764560772008*^9, 3.797765255889024*^9, 3.797765526827474*^9, 
   3.797765778754184*^9, 3.797766118838984*^9, 3.797774307057869*^9, 
   3.797788589153913*^9, 3.7977945683883047`*^9, 3.7977947034470367`*^9, 
   3.7977947361215343`*^9, 3.79779487219851*^9, 3.797794972165085*^9, 
   3.797843179749316*^9, 3.7978457506576643`*^9, 3.797846042219879*^9, 
   3.797847231227578*^9, 3.797849045005834*^9, 3.797849118604653*^9, 
   3.7978493625997057`*^9, 3.797849634817884*^9, 3.79784972387566*^9, 
   3.7978499236786127`*^9, 3.797850014319191*^9, 3.797854696355344*^9, 
   3.797858820719471*^9, 3.797859214883679*^9, 3.797859604901162*^9, 
   3.797859746835083*^9, 3.797860192073792*^9, 3.7978609236074753`*^9, 
   3.7978657704785852`*^9, 3.797865943840616*^9, 3.797866014486208*^9, 
   3.797866518950715*^9, 3.797874686337919*^9, 3.797881262760754*^9, 
   3.797881975736858*^9, 3.797927801936915*^9, 3.7979284282991056`*^9, 
   3.797929819859252*^9, 3.7979302620556383`*^9, 3.7979307170485363`*^9, 
   3.797940009937934*^9, 3.797940567447145*^9, 3.797940726570633*^9, 
   3.7979410116597557`*^9, 3.798103303899774*^9, 3.7981114200190372`*^9, 
   3.798329529127898*^9, 3.798381665936233*^9, 3.798477225214884*^9, 
   3.798795039110229*^9, 3.798843440614626*^9, 3.799059602556315*^9, 
   3.7990768296105003`*^9, 3.799682744526547*^9, 3.800348499168276*^9, 
   3.800814550659771*^9, 3.800814929645811*^9, 3.800816261401786*^9, 
   3.800828403020702*^9, 3.800830196583169*^9, 3.800830340112109*^9, 
   3.80086903565056*^9, 3.8008707888030033`*^9, 3.8008709907541122`*^9, 
   3.800897197709609*^9, 3.800900915514406*^9, 3.800901497177526*^9, 
   3.800902654752605*^9, 3.8009051664113483`*^9, 3.800962045806518*^9, 
   3.800968201214416*^9, 3.8013308499066267`*^9, 3.802709271247632*^9, {
   3.802710586510352*^9, 3.802710608214451*^9}, 3.8027134685121117`*^9, 
   3.802713590038003*^9, 3.802765249086426*^9, 3.8027707268473787`*^9, 
   3.802771362669487*^9, 3.802774643314526*^9, 3.803117755368897*^9, 
   3.8031968767943087`*^9, 3.803302303651978*^9, 3.803302680495051*^9, 
   3.803307831325851*^9, 3.8033240881206093`*^9, 3.80341160892001*^9, 
   3.803412127536875*^9, 3.803412167562828*^9, 3.8034747195998*^9, 
   3.8037293468844967`*^9, 3.803743242292204*^9, 3.803806382170341*^9, 
   3.803807928061968*^9, 3.8038120472499647`*^9, 3.803824855953882*^9, 
   3.803829796831237*^9, 3.803891455451413*^9, 3.8039788430926933`*^9, 
   3.8042701634267807`*^9, 3.804446225441481*^9, 3.804598404815477*^9, 
   3.805044885040607*^9, 3.8069378532403517`*^9, 3.807091806678665*^9, 
   3.807092490953742*^9, 3.825425047807212*^9, 3.825425163358753*^9, 
   3.8254252055792637`*^9, 3.828107412415732*^9, {3.828716483264584*^9, 
   3.8287165001432247`*^9}, 3.828717660140732*^9, 3.8320751316492853`*^9, 
   3.832085385159844*^9, 3.839324799110093*^9, 3.849021261877104*^9, 
   3.85211513861086*^9, 3.852137008905929*^9, 3.8521377536866417`*^9, 
   3.8521427616760597`*^9, 3.852284670252002*^9, 3.852293242665489*^9, 
   3.852293910027337*^9, 3.85229420467393*^9, 3.8523274864172153`*^9, 
   3.852328174749358*^9, 3.852364094131023*^9, 3.852364783825161*^9, 
   3.852366458892273*^9, 3.853745736971137*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"89bd5c0c-34b8-4971-8e41-1da443e4f894"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v01", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{"I0", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.797762007574184*^9, 3.797762015791391*^9}, 
   3.797762048403474*^9, {3.797762096895315*^9, 3.797762123364874*^9}, 
   3.797762589815042*^9, 3.797763932021935*^9, 3.797763992055852*^9, 
   3.797764046971744*^9, 3.797764251202983*^9, 3.7977645048243637`*^9, 
   3.797764560772008*^9, 3.797765255889024*^9, 3.797765526827474*^9, 
   3.797765778754184*^9, 3.797766118838984*^9, 3.797774307057869*^9, 
   3.797788589153913*^9, 3.7977945683883047`*^9, 3.7977947034470367`*^9, 
   3.7977947361215343`*^9, 3.79779487219851*^9, 3.797794972165085*^9, 
   3.797843179749316*^9, 3.7978457506576643`*^9, 3.797846042219879*^9, 
   3.797847231227578*^9, 3.797849045005834*^9, 3.797849118604653*^9, 
   3.7978493625997057`*^9, 3.797849634817884*^9, 3.79784972387566*^9, 
   3.7978499236786127`*^9, 3.797850014319191*^9, 3.797854696355344*^9, 
   3.797858820719471*^9, 3.797859214883679*^9, 3.797859604901162*^9, 
   3.797859746835083*^9, 3.797860192073792*^9, 3.7978609236074753`*^9, 
   3.7978657704785852`*^9, 3.797865943840616*^9, 3.797866014486208*^9, 
   3.797866518950715*^9, 3.797874686337919*^9, 3.797881262760754*^9, 
   3.797881975736858*^9, 3.797927801936915*^9, 3.7979284282991056`*^9, 
   3.797929819859252*^9, 3.7979302620556383`*^9, 3.7979307170485363`*^9, 
   3.797940009937934*^9, 3.797940567447145*^9, 3.797940726570633*^9, 
   3.7979410116597557`*^9, 3.798103303899774*^9, 3.7981114200190372`*^9, 
   3.798329529127898*^9, 3.798381665936233*^9, 3.798477225214884*^9, 
   3.798795039110229*^9, 3.798843440614626*^9, 3.799059602556315*^9, 
   3.7990768296105003`*^9, 3.799682744526547*^9, 3.800348499168276*^9, 
   3.800814550659771*^9, 3.800814929645811*^9, 3.800816261401786*^9, 
   3.800828403020702*^9, 3.800830196583169*^9, 3.800830340112109*^9, 
   3.80086903565056*^9, 3.8008707888030033`*^9, 3.8008709907541122`*^9, 
   3.800897197709609*^9, 3.800900915514406*^9, 3.800901497177526*^9, 
   3.800902654752605*^9, 3.8009051664113483`*^9, 3.800962045806518*^9, 
   3.800968201214416*^9, 3.8013308499066267`*^9, 3.802709271247632*^9, {
   3.802710586510352*^9, 3.802710608214451*^9}, 3.8027134685121117`*^9, 
   3.802713590038003*^9, 3.802765249086426*^9, 3.8027707268473787`*^9, 
   3.802771362669487*^9, 3.802774643314526*^9, 3.803117755368897*^9, 
   3.8031968767943087`*^9, 3.803302303651978*^9, 3.803302680495051*^9, 
   3.803307831325851*^9, 3.8033240881206093`*^9, 3.80341160892001*^9, 
   3.803412127536875*^9, 3.803412167562828*^9, 3.8034747195998*^9, 
   3.8037293468844967`*^9, 3.803743242292204*^9, 3.803806382170341*^9, 
   3.803807928061968*^9, 3.8038120472499647`*^9, 3.803824855953882*^9, 
   3.803829796831237*^9, 3.803891455451413*^9, 3.8039788430926933`*^9, 
   3.8042701634267807`*^9, 3.804446225441481*^9, 3.804598404815477*^9, 
   3.805044885040607*^9, 3.8069378532403517`*^9, 3.807091806678665*^9, 
   3.807092490953742*^9, 3.825425047807212*^9, 3.825425163358753*^9, 
   3.8254252055792637`*^9, 3.828107412415732*^9, {3.828716483264584*^9, 
   3.8287165001432247`*^9}, 3.828717660140732*^9, 3.8320751316492853`*^9, 
   3.832085385159844*^9, 3.839324799110093*^9, 3.849021261877104*^9, 
   3.85211513861086*^9, 3.852137008905929*^9, 3.8521377536866417`*^9, 
   3.8521427616760597`*^9, 3.852284670252002*^9, 3.852293242665489*^9, 
   3.852293910027337*^9, 3.85229420467393*^9, 3.8523274864172153`*^9, 
   3.852328174749358*^9, 3.852364094131023*^9, 3.852364783825161*^9, 
   3.852366458892273*^9, 3.853745736973783*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"ad163300-baf3-4885-8991-9df3e657a713"]
}, Open  ]],

Cell["Part 2", "Text",
 CellChangeTimes->{{3.797592000713814*^9, 3.797592001830521*^9}, 
   3.797865771319963*^9, 3.849021217949891*^9, 
   3.852284676046527*^9},ExpressionUUID->"4e27cbc1-4342-44d2-be93-\
5e785c926bed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq02", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"v02", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
   RowBox[{"v02", "[", "t", "]"}], "+", "I0"}]}]], "Input",
 CellChangeTimes->{{3.782756520293415*^9, 3.782756571116694*^9}, {
  3.7827569420219584`*^9, 3.782756951129785*^9}, {3.7827584273345747`*^9, 
  3.782758427541273*^9}, {3.7977631449360237`*^9, 3.797763149174371*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"68c1be2d-21de-49b0-a182-43b6526aeebe"],

Cell[BoxData[
 RowBox[{"I0", "-", 
  RowBox[{"v02", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v02", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.78275658712717*^9, 3.782756958172165*^9, 3.782756990403307*^9, 
   3.7827573131671124`*^9, 3.7827583214796*^9, 3.782758461368404*^9, 
   3.782760743276002*^9, 3.7975878872252827`*^9, 3.797591126753724*^9, 
   3.7975964548554373`*^9, 3.797600761308724*^9, 3.797600791554809*^9, 
   3.7976014220698853`*^9, 3.797602099006266*^9, 3.797602140572629*^9, 
   3.7976022100825853`*^9, 3.797602263188198*^9, {3.7976023238376293`*^9, 
   3.7976023499123487`*^9}, 3.797618744289558*^9, 3.7976192070245113`*^9, 
   3.797619748767277*^9, 3.7976198256842833`*^9, 3.7977623460418587`*^9, 
   3.797763149936503*^9, 3.797763932153842*^9, 3.797763992073118*^9, 
   3.7977640469879913`*^9, 3.797764251219653*^9, 3.79776456078909*^9, 
   3.7977652559041443`*^9, 3.797765526842504*^9, 3.797765778768783*^9, 
   3.797766118853607*^9, 3.797774307075204*^9, 3.797788589169298*^9, 
   3.79779456840271*^9, 3.797794703459547*^9, 3.797794736133498*^9, 
   3.797794872214223*^9, 3.797794972179584*^9, 3.797843179761548*^9, 
   3.7978457506688337`*^9, 3.797846042232212*^9, 3.7978472312401733`*^9, 
   3.7978490450172253`*^9, 3.797849118617635*^9, 3.797849362611928*^9, 
   3.797849634829178*^9, 3.7978497238901577`*^9, 3.79784992369277*^9, 
   3.797850014331197*^9, 3.7978546963684607`*^9, 3.797858820732963*^9, 
   3.797859214899922*^9, 3.797859604916418*^9, 3.7978597468512287`*^9, 
   3.797860192086578*^9, 3.797860923620059*^9, 3.7978657740329323`*^9, 
   3.797865943854396*^9, 3.797866014541765*^9, 3.797866518963502*^9, 
   3.7978746863511763`*^9, 3.797881266900611*^9, 3.7978819760361967`*^9, 
   3.797927801950506*^9, 3.797928428313785*^9, 3.797929819873592*^9, 
   3.797930262070513*^9, 3.797930718108707*^9, 3.797940009966762*^9, 
   3.797940567463182*^9, 3.7979407265855293`*^9, 3.797941011677062*^9, 
   3.798103303910017*^9, 3.798111420033119*^9, 3.798329529140435*^9, 
   3.798381665950927*^9, 3.798477225231366*^9, 3.798795039129799*^9, 
   3.7988434406294527`*^9, 3.7990596025723677`*^9, 3.799076829623391*^9, 
   3.799682744546483*^9, 3.800348499180764*^9, 3.800814550672813*^9, 
   3.8008149296600847`*^9, 3.800816261421969*^9, 3.8008284032991734`*^9, 
   3.8008301965990133`*^9, 3.800830340130849*^9, 3.800869035671937*^9, 
   3.800870788815715*^9, 3.800870990766094*^9, 3.800897197723774*^9, 
   3.800900915527019*^9, 3.800901497191044*^9, 3.800902654765834*^9, 
   3.8009051664246473`*^9, 3.8009620458246603`*^9, 3.800968201228355*^9, 
   3.8013308499181147`*^9, 3.802709271270632*^9, {3.802710586523918*^9, 
   3.80271060823071*^9}, 3.802713468527526*^9, 3.8027135900543137`*^9, 
   3.8027652490996447`*^9, 3.802770726861699*^9, 3.802771362684185*^9, 
   3.8027746433272676`*^9, 3.8031177553831387`*^9, 3.803196876807076*^9, 
   3.803302303664997*^9, 3.803302680514597*^9, 3.803307831337824*^9, 
   3.803324088132719*^9, 3.8034116089357977`*^9, 3.803412127551222*^9, 
   3.803412167579555*^9, 3.803474719624145*^9, 3.803729346898279*^9, 
   3.803743242305109*^9, 3.803806382182539*^9, 3.8038079280746813`*^9, 
   3.803812047264215*^9, 3.803824855968617*^9, 3.803829796850037*^9, 
   3.803891455463649*^9, 3.8039788431062193`*^9, 3.804270163442472*^9, 
   3.804446225455433*^9, 3.8045984048442183`*^9, 3.8050448850604553`*^9, 
   3.8069378532545557`*^9, 3.807091806696868*^9, 3.8070924909817543`*^9, 
   3.8254250478166323`*^9, 3.825425163370242*^9, 3.825425205589191*^9, 
   3.82810741243328*^9, {3.8287164874132757`*^9, 3.82871650016254*^9}, 
   3.828717660158675*^9, 3.832075131659259*^9, 3.832085385171299*^9, 
   3.839324799128525*^9, 3.849021261903187*^9, 3.852115138660596*^9, 
   3.852137008922245*^9, 3.852137753702989*^9, 3.8521427616961737`*^9, 
   3.852284677630393*^9, 3.8522932426838207`*^9, 3.8522939100837584`*^9, 
   3.852294204727046*^9, 3.852327486439151*^9, 3.852328174797176*^9, 
   3.852364094186473*^9, 3.852364783880847*^9, 3.8523664589565563`*^9, 
   3.853745736981944*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"82d998aa-25ab-461f-a3e7-5abd52c0f61d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"defv02d", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"deq02", "\[Equal]", "0"}], "}"}], ",", "v02", ",", "t"}], 
     "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"defIC02", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"v02", "[", 
          RowBox[{"ts", "-", "\[Phi]"}], "]"}], "\[Equal]", 
         RowBox[{"v01", "[", 
          RowBox[{"ts", "-", "\[Phi]"}], "]"}]}], "}"}], "/.", "defv02d"}], "/.",
       "defv01"}], ",", 
     RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"defv02", "=", 
  RowBox[{"defv02d", "/.", "defIC02"}]}]}], "Input",
 CellChangeTimes->{{3.797763086922845*^9, 3.797763141215526*^9}, {
  3.797763177725719*^9, 3.79776322811532*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"7ab6f854-39e6-4b39-a577-79b35d6f5549"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v02", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{"I0", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       TemplateBox[{"1"},
        "C"]}]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797763142060725*^9, 3.7977631527169237`*^9}, {
   3.797763190261909*^9, 3.797763228753677*^9}, 3.7977639322142897`*^9, 
   3.797763992144744*^9, 3.7977640470517473`*^9, 3.797764251274618*^9, 
   3.797764560856778*^9, 3.797765255959381*^9, 3.797765526892621*^9, 
   3.797765778817203*^9, 3.797766118897614*^9, 3.797774307118362*^9, 
   3.797788589198504*^9, 3.797794568454441*^9, 3.79779470351085*^9, 
   3.797794736174831*^9, 3.797794872271984*^9, 3.797794972227865*^9, 
   3.797843179805408*^9, 3.797845750704811*^9, 3.7978460422798367`*^9, 
   3.797847231279118*^9, 3.797849045056431*^9, 3.797849118681134*^9, 
   3.7978493626502523`*^9, 3.7978496348695183`*^9, 3.797849723946703*^9, 
   3.797849923735928*^9, 3.797850014378314*^9, 3.797854696418186*^9, 
   3.797858820770619*^9, 3.797859214939815*^9, 3.79785960495008*^9, 
   3.797859746891239*^9, 3.797860192127583*^9, 3.7978609236723547`*^9, 
   3.797865775120041*^9, 3.7978659439132223`*^9, 3.797866014553195*^9, 
   3.797866519015828*^9, 3.797874686412076*^9, 3.797881267797304*^9, 
   3.797881976241475*^9, 3.797927802004568*^9, 3.797928428373917*^9, 
   3.797929819928277*^9, 3.797930262136197*^9, 3.797930718303012*^9, 
   3.797940010040628*^9, 3.797940567522615*^9, 3.7979407266391582`*^9, 
   3.797941011732711*^9, 3.798103303956707*^9, 3.7981114200770493`*^9, 
   3.798329529179255*^9, 3.798381666010376*^9, 3.798477225335298*^9, 
   3.798795039187604*^9, 3.7988434407112722`*^9, 3.799059602640045*^9, 
   3.799076829683895*^9, 3.799682744677587*^9, 3.800348499228046*^9, 
   3.800814550726529*^9, 3.8008149297168217`*^9, 3.8008162615386972`*^9, 
   3.800828403379197*^9, 3.8008301966526833`*^9, 3.8008303407800503`*^9, 
   3.800869035737852*^9, 3.8008707888631363`*^9, 3.800870990817482*^9, 
   3.800897197778071*^9, 3.800900915582752*^9, 3.800901497238093*^9, 
   3.800902654812366*^9, 3.800905166477935*^9, 3.8009620458727922`*^9, 
   3.8009682012743073`*^9, 3.801330849991004*^9, 3.802709271337007*^9, {
   3.802710586587435*^9, 3.802710608294855*^9}, 3.802713468567358*^9, 
   3.802713590099819*^9, 3.802765249135251*^9, 3.802770726899974*^9, 
   3.80277136277103*^9, 3.802774643362307*^9, 3.803117755421195*^9, 
   3.803196876853634*^9, 3.803302303714271*^9, 3.8033026805955353`*^9, 
   3.803307831384818*^9, 3.803324088186376*^9, 3.803411608970999*^9, 
   3.8034121275956163`*^9, 3.803412167632708*^9, 3.8034747197083673`*^9, 
   3.8037293469408913`*^9, 3.803743242339939*^9, 3.803806382226632*^9, 
   3.803807928118516*^9, 3.803812047304928*^9, 3.803824856024108*^9, 
   3.8038297969319363`*^9, 3.803891455501196*^9, 3.803978843151079*^9, 
   3.804270163491341*^9, 3.8044462255056467`*^9, 3.8045984049100103`*^9, 
   3.80504488511664*^9, 3.8069378533002253`*^9, 3.807091806792676*^9, 
   3.807092491047522*^9, 3.825425047849348*^9, 3.825425163405251*^9, 
   3.825425205623662*^9, 3.828107412475809*^9, 3.828716500218948*^9, 
   3.828717660212244*^9, 3.832075131710102*^9, 3.83208538521185*^9, 
   3.8393247991643877`*^9, 3.8490212619908123`*^9, 3.852115138706119*^9, 
   3.852137008961547*^9, 3.852137753741675*^9, 3.852142761741828*^9, 
   3.8522846789026127`*^9, 3.852293242725418*^9, 3.852293910124103*^9, 
   3.852294204766453*^9, 3.852327486489098*^9, 3.8523281748365192`*^9, 
   3.852364094230255*^9, 3.852364783923567*^9, 3.8523664590068083`*^9, 
   3.853745737012906*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"7156eff2-a9f7-4a01-9ed9-bc10e43934fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"1"},
    "C"], "\[Rule]", 
   RowBox[{
    RowBox[{"-", "I0"}], "+", "V00"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797763142060725*^9, 3.7977631527169237`*^9}, {
   3.797763190261909*^9, 3.797763228753677*^9}, 3.7977639322142897`*^9, 
   3.797763992144744*^9, 3.7977640470517473`*^9, 3.797764251274618*^9, 
   3.797764560856778*^9, 3.797765255959381*^9, 3.797765526892621*^9, 
   3.797765778817203*^9, 3.797766118897614*^9, 3.797774307118362*^9, 
   3.797788589198504*^9, 3.797794568454441*^9, 3.79779470351085*^9, 
   3.797794736174831*^9, 3.797794872271984*^9, 3.797794972227865*^9, 
   3.797843179805408*^9, 3.797845750704811*^9, 3.7978460422798367`*^9, 
   3.797847231279118*^9, 3.797849045056431*^9, 3.797849118681134*^9, 
   3.7978493626502523`*^9, 3.7978496348695183`*^9, 3.797849723946703*^9, 
   3.797849923735928*^9, 3.797850014378314*^9, 3.797854696418186*^9, 
   3.797858820770619*^9, 3.797859214939815*^9, 3.79785960495008*^9, 
   3.797859746891239*^9, 3.797860192127583*^9, 3.7978609236723547`*^9, 
   3.797865775120041*^9, 3.7978659439132223`*^9, 3.797866014553195*^9, 
   3.797866519015828*^9, 3.797874686412076*^9, 3.797881267797304*^9, 
   3.797881976241475*^9, 3.797927802004568*^9, 3.797928428373917*^9, 
   3.797929819928277*^9, 3.797930262136197*^9, 3.797930718303012*^9, 
   3.797940010040628*^9, 3.797940567522615*^9, 3.7979407266391582`*^9, 
   3.797941011732711*^9, 3.798103303956707*^9, 3.7981114200770493`*^9, 
   3.798329529179255*^9, 3.798381666010376*^9, 3.798477225335298*^9, 
   3.798795039187604*^9, 3.7988434407112722`*^9, 3.799059602640045*^9, 
   3.799076829683895*^9, 3.799682744677587*^9, 3.800348499228046*^9, 
   3.800814550726529*^9, 3.8008149297168217`*^9, 3.8008162615386972`*^9, 
   3.800828403379197*^9, 3.8008301966526833`*^9, 3.8008303407800503`*^9, 
   3.800869035737852*^9, 3.8008707888631363`*^9, 3.800870990817482*^9, 
   3.800897197778071*^9, 3.800900915582752*^9, 3.800901497238093*^9, 
   3.800902654812366*^9, 3.800905166477935*^9, 3.8009620458727922`*^9, 
   3.8009682012743073`*^9, 3.801330849991004*^9, 3.802709271337007*^9, {
   3.802710586587435*^9, 3.802710608294855*^9}, 3.802713468567358*^9, 
   3.802713590099819*^9, 3.802765249135251*^9, 3.802770726899974*^9, 
   3.80277136277103*^9, 3.802774643362307*^9, 3.803117755421195*^9, 
   3.803196876853634*^9, 3.803302303714271*^9, 3.8033026805955353`*^9, 
   3.803307831384818*^9, 3.803324088186376*^9, 3.803411608970999*^9, 
   3.8034121275956163`*^9, 3.803412167632708*^9, 3.8034747197083673`*^9, 
   3.8037293469408913`*^9, 3.803743242339939*^9, 3.803806382226632*^9, 
   3.803807928118516*^9, 3.803812047304928*^9, 3.803824856024108*^9, 
   3.8038297969319363`*^9, 3.803891455501196*^9, 3.803978843151079*^9, 
   3.804270163491341*^9, 3.8044462255056467`*^9, 3.8045984049100103`*^9, 
   3.80504488511664*^9, 3.8069378533002253`*^9, 3.807091806792676*^9, 
   3.807092491047522*^9, 3.825425047849348*^9, 3.825425163405251*^9, 
   3.825425205623662*^9, 3.828107412475809*^9, 3.828716500218948*^9, 
   3.828717660212244*^9, 3.832075131710102*^9, 3.83208538521185*^9, 
   3.8393247991643877`*^9, 3.8490212619908123`*^9, 3.852115138706119*^9, 
   3.852137008961547*^9, 3.852137753741675*^9, 3.852142761741828*^9, 
   3.8522846789026127`*^9, 3.852293242725418*^9, 3.852293910124103*^9, 
   3.852294204766453*^9, 3.852327486489098*^9, 3.8523281748365192`*^9, 
   3.852364094230255*^9, 3.852364783923567*^9, 3.8523664590068083`*^9, 
   3.853745737020412*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"78541d38-b5f3-462f-92d9-d8965affae3e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v02", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{"I0", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.797763142060725*^9, 3.7977631527169237`*^9}, {
   3.797763190261909*^9, 3.797763228753677*^9}, 3.7977639322142897`*^9, 
   3.797763992144744*^9, 3.7977640470517473`*^9, 3.797764251274618*^9, 
   3.797764560856778*^9, 3.797765255959381*^9, 3.797765526892621*^9, 
   3.797765778817203*^9, 3.797766118897614*^9, 3.797774307118362*^9, 
   3.797788589198504*^9, 3.797794568454441*^9, 3.79779470351085*^9, 
   3.797794736174831*^9, 3.797794872271984*^9, 3.797794972227865*^9, 
   3.797843179805408*^9, 3.797845750704811*^9, 3.7978460422798367`*^9, 
   3.797847231279118*^9, 3.797849045056431*^9, 3.797849118681134*^9, 
   3.7978493626502523`*^9, 3.7978496348695183`*^9, 3.797849723946703*^9, 
   3.797849923735928*^9, 3.797850014378314*^9, 3.797854696418186*^9, 
   3.797858820770619*^9, 3.797859214939815*^9, 3.79785960495008*^9, 
   3.797859746891239*^9, 3.797860192127583*^9, 3.7978609236723547`*^9, 
   3.797865775120041*^9, 3.7978659439132223`*^9, 3.797866014553195*^9, 
   3.797866519015828*^9, 3.797874686412076*^9, 3.797881267797304*^9, 
   3.797881976241475*^9, 3.797927802004568*^9, 3.797928428373917*^9, 
   3.797929819928277*^9, 3.797930262136197*^9, 3.797930718303012*^9, 
   3.797940010040628*^9, 3.797940567522615*^9, 3.7979407266391582`*^9, 
   3.797941011732711*^9, 3.798103303956707*^9, 3.7981114200770493`*^9, 
   3.798329529179255*^9, 3.798381666010376*^9, 3.798477225335298*^9, 
   3.798795039187604*^9, 3.7988434407112722`*^9, 3.799059602640045*^9, 
   3.799076829683895*^9, 3.799682744677587*^9, 3.800348499228046*^9, 
   3.800814550726529*^9, 3.8008149297168217`*^9, 3.8008162615386972`*^9, 
   3.800828403379197*^9, 3.8008301966526833`*^9, 3.8008303407800503`*^9, 
   3.800869035737852*^9, 3.8008707888631363`*^9, 3.800870990817482*^9, 
   3.800897197778071*^9, 3.800900915582752*^9, 3.800901497238093*^9, 
   3.800902654812366*^9, 3.800905166477935*^9, 3.8009620458727922`*^9, 
   3.8009682012743073`*^9, 3.801330849991004*^9, 3.802709271337007*^9, {
   3.802710586587435*^9, 3.802710608294855*^9}, 3.802713468567358*^9, 
   3.802713590099819*^9, 3.802765249135251*^9, 3.802770726899974*^9, 
   3.80277136277103*^9, 3.802774643362307*^9, 3.803117755421195*^9, 
   3.803196876853634*^9, 3.803302303714271*^9, 3.8033026805955353`*^9, 
   3.803307831384818*^9, 3.803324088186376*^9, 3.803411608970999*^9, 
   3.8034121275956163`*^9, 3.803412167632708*^9, 3.8034747197083673`*^9, 
   3.8037293469408913`*^9, 3.803743242339939*^9, 3.803806382226632*^9, 
   3.803807928118516*^9, 3.803812047304928*^9, 3.803824856024108*^9, 
   3.8038297969319363`*^9, 3.803891455501196*^9, 3.803978843151079*^9, 
   3.804270163491341*^9, 3.8044462255056467`*^9, 3.8045984049100103`*^9, 
   3.80504488511664*^9, 3.8069378533002253`*^9, 3.807091806792676*^9, 
   3.807092491047522*^9, 3.825425047849348*^9, 3.825425163405251*^9, 
   3.825425205623662*^9, 3.828107412475809*^9, 3.828716500218948*^9, 
   3.828717660212244*^9, 3.832075131710102*^9, 3.83208538521185*^9, 
   3.8393247991643877`*^9, 3.8490212619908123`*^9, 3.852115138706119*^9, 
   3.852137008961547*^9, 3.852137753741675*^9, 3.852142761741828*^9, 
   3.8522846789026127`*^9, 3.852293242725418*^9, 3.852293910124103*^9, 
   3.852294204766453*^9, 3.852327486489098*^9, 3.8523281748365192`*^9, 
   3.852364094230255*^9, 3.852364783923567*^9, 3.8523664590068083`*^9, 
   3.853745737023019*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"1845be3f-a00a-46b3-b943-84d12129f6b2"]
}, Open  ]],

Cell["Part 3", "Text",
 CellChangeTimes->{{3.797881283720854*^9, 
  3.797881285534074*^9}},ExpressionUUID->"c4a0d137-bb0b-4834-bbff-\
a923b290f906"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq03", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"v03", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
   RowBox[{"v03", "[", "t", "]"}], "+", "I0", "+", 
   RowBox[{"va", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"\[Xi]", " ", "t"}], "]"}]}]}]}]], "Input",
 CellLabel->"In[20]:=",ExpressionUUID->"d27ab50d-56a0-4318-a299-99164c16b850"],

Cell[BoxData[
 RowBox[{"I0", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]], " ", "va"}], "-", 
  RowBox[{"v03", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v03", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.79776344891957*^9, 3.797763932273218*^9, 3.79776399216297*^9, 
   3.797764047069701*^9, 3.797764251289309*^9, 3.797764560937512*^9, 
   3.797765256030416*^9, 3.797765526959771*^9, 3.7977657788814173`*^9, 
   3.797766118973702*^9, 3.7977743071755877`*^9, 3.797788589242288*^9, 
   3.797794568518656*^9, 3.7977947035875196`*^9, 3.7977947362324543`*^9, 
   3.797794872342442*^9, 3.797794972289455*^9, 3.797843179861827*^9, 
   3.7978457507523413`*^9, 3.797846042332055*^9, 3.797847231328116*^9, 
   3.797849045108873*^9, 3.797849118757365*^9, 3.79784936269846*^9, 
   3.797849634921728*^9, 3.7978497240196667`*^9, 3.797849923788897*^9, 
   3.797850014434504*^9, 3.797854696483178*^9, 3.797858820821829*^9, 
   3.797859214995411*^9, 3.797859604994382*^9, 3.7978597469476013`*^9, 
   3.7978601921809196`*^9, 3.797860923735629*^9, 3.7978657778199368`*^9, 
   3.797865943987516*^9, 3.797866014613489*^9, 3.7978665190813427`*^9, 
   3.797874686481656*^9, 3.7978812909559402`*^9, 3.797881976265152*^9, 
   3.7979278020201683`*^9, 3.797928428389279*^9, 3.797929819947074*^9, 
   3.7979302621551123`*^9, 3.797930718325531*^9, 3.7979400100606737`*^9, 
   3.797940568297359*^9, 3.797940726653092*^9, 3.79794101250686*^9, 
   3.7981033039698257`*^9, 3.798111420090619*^9, 3.79832952919145*^9, 
   3.798381666025642*^9, 3.798477225350607*^9, 3.798795039209399*^9, 
   3.7988434407226057`*^9, 3.799059602651574*^9, 3.7990768297014713`*^9, 
   3.7996827448458*^9, 3.8003484992408524`*^9, 3.800814550744011*^9, 
   3.800814929736567*^9, 3.800816261562084*^9, 3.800828404279866*^9, 
   3.800830196668425*^9, 3.800830340973811*^9, 3.800869035756023*^9, 
   3.800870788876943*^9, 3.800870990831684*^9, 3.800897197791492*^9, 
   3.800900915594949*^9, 3.800901497250537*^9, 3.8009026548270197`*^9, 
   3.8009051664920397`*^9, 3.800962045885178*^9, 3.800968201287311*^9, 
   3.80133085000986*^9, 3.802709271360929*^9, {3.802710586600594*^9, 
   3.802710608311923*^9}, 3.8027134685811*^9, 3.802713590117043*^9, 
   3.802765249148018*^9, 3.8027707269141617`*^9, 3.8027713627991047`*^9, 
   3.8027746433760242`*^9, 3.8031177554354553`*^9, 3.803196876867652*^9, 
   3.803302303727322*^9, 3.803302681256091*^9, 3.803307831396522*^9, 
   3.80332408819809*^9, 3.803411608985001*^9, 3.8034121276449747`*^9, 
   3.8034121676471987`*^9, 3.803474719725009*^9, 3.803729346957965*^9, 
   3.803743242353423*^9, 3.8038063822388477`*^9, 3.803807928131781*^9, 
   3.803812047319359*^9, 3.803824856041559*^9, 3.803829796949936*^9, 
   3.803891455512807*^9, 3.803978843163733*^9, 3.804270163505018*^9, 
   3.8044462255182943`*^9, 3.804598404933434*^9, 3.805044885131233*^9, 
   3.806937853312611*^9, 3.807091806810623*^9, 3.8070924910634336`*^9, 
   3.825425047859404*^9, 3.825425163414461*^9, 3.825425205633893*^9, 
   3.828107412494135*^9, 3.828716500238955*^9, 3.828717660233314*^9, 
   3.832075131721202*^9, 3.832085385221998*^9, 3.839324799181637*^9, 
   3.8490212620167723`*^9, 3.852115138753682*^9, 3.85213700897747*^9, 
   3.852137753757847*^9, 3.852142761760274*^9, 3.852284682046557*^9, 
   3.852293242746118*^9, 3.8522939101467447`*^9, 3.852294204784006*^9, 
   3.852327486510767*^9, 3.852328174854993*^9, 3.852364094253022*^9, 
   3.852364783946042*^9, 3.852366459028091*^9, 3.8537457370496473`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"44bae80a-c1c1-48d9-a386-6efc03849327"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "continuity", " ", "condition", " ", "assumes", " ", "that",
       " ", "ts"}], "<", 
     RowBox[{"T", "-", "\[Phi]T"}]}], ",", " ", 
    RowBox[{
     RowBox[{"i", ".", "e", ".", " ", "segment"}], " ", "2", " ", "reaches", 
     " ", "spike", " ", "threshold", " ", "before", " ", "segment", " ", "1", 
     " ", "ends", " ", "its", " ", "spike"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"defv03d", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"deq03", "\[Equal]", "0"}], "}"}], ",", "v03", ",", "t"}], 
       "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"defIC03", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"v03", "[", "ts", "]"}], "\[Equal]", 
           RowBox[{"v02", "[", "ts", "]"}]}], "}"}], "/.", "defv03d"}], "/.", 
        "defv02"}], ",", 
       RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   
   RowBox[{"defv03", "=", 
    RowBox[{"defv03d", "/.", "defIC03"}]}]}]}]], "Input",
 CellChangeTimes->{{3.797763398635962*^9, 3.7977634314509687`*^9}, {
  3.804423280269411*^9, 3.804423345476082*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"226eab27-6842-4374-9195-3e2da6a6a8ed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v03", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "t"], " ", "I0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       TemplateBox[{"1"},
        "C"]}]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797763432126686*^9, 3.797763451185824*^9}, 
   3.797763932383679*^9, 3.797763992284377*^9, 3.797764047187402*^9, 
   3.797764251405716*^9, 3.797764561048348*^9, 3.797765256146646*^9, 
   3.797765527068449*^9, 3.797765778990271*^9, 3.7977661190851088`*^9, 
   3.7977743072948093`*^9, 3.7977885893152847`*^9, 3.797794568643297*^9, 
   3.797794703656815*^9, 3.797794736350237*^9, 3.7977948724525633`*^9, 
   3.797794972398164*^9, 3.797843180010244*^9, 3.797845750873942*^9, 
   3.7978460423889093`*^9, 3.7978472314593687`*^9, 3.79784904522234*^9, 
   3.797849118869598*^9, 3.797849362811796*^9, 3.797849635038395*^9, 
   3.797849724142501*^9, 3.797849923899145*^9, 3.797850014478168*^9, 
   3.797854696536385*^9, 3.797858820864097*^9, 3.7978592150498447`*^9, 
   3.7978596050347*^9, 3.797859746990818*^9, 3.797860192226371*^9, 
   3.7978609237873917`*^9, 3.797865778810155*^9, 3.797865944060143*^9, 
   3.797866014658936*^9, 3.797866519139865*^9, 3.797874686542088*^9, 
   3.7978812918405743`*^9, 3.7978819764561567`*^9, 3.797927802074431*^9, 
   3.797928428450698*^9, 3.797929820004951*^9, 3.7979302622142963`*^9, 
   3.797930718432769*^9, 3.797940010132489*^9, 3.797940568572926*^9, 
   3.7979407267074203`*^9, 3.79794101270175*^9, 3.7981033040151377`*^9, 
   3.798111420132913*^9, 3.798329529239274*^9, 3.798381666134903*^9, 
   3.798477225452767*^9, 3.798795039281993*^9, 3.7988434408008204`*^9, 
   3.7990596027087307`*^9, 3.799076829768573*^9, 3.799682744974988*^9, 
   3.80034849928872*^9, 3.8008145508098297`*^9, 3.8008149298092527`*^9, 
   3.800816261795023*^9, 3.80082840446848*^9, 3.800830196720587*^9, 
   3.800830341043819*^9, 3.800869035817734*^9, 3.800870788924077*^9, 
   3.8008709908818398`*^9, 3.800897197843157*^9, 3.800900915652014*^9, 
   3.800901497297161*^9, 3.8009026548728333`*^9, 3.800905166546632*^9, 
   3.800962045934854*^9, 3.800968201338788*^9, 3.8013308501020203`*^9, 
   3.8027092714323187`*^9, {3.802710586661562*^9, 3.8027106083788*^9}, 
   3.802713468621327*^9, 3.8027135901630077`*^9, 3.802765249191156*^9, 
   3.8027707269560747`*^9, 3.8027713628823137`*^9, 3.802774643416192*^9, 
   3.803117755490054*^9, 3.803196876915265*^9, 3.8033023037903957`*^9, 
   3.803302681528759*^9, 3.803307831441733*^9, 3.8033240882522306`*^9, 
   3.803411609029541*^9, 3.803412127690324*^9, 3.803412167702276*^9, 
   3.8034747197991753`*^9, 3.803729347021467*^9, 3.8037432423978786`*^9, 
   3.8038063822839127`*^9, 3.803807928175622*^9, 3.803812047365839*^9, 
   3.803824856097395*^9, 3.803829797035966*^9, 3.803891455557622*^9, 
   3.803978843212674*^9, 3.804270163549852*^9, 3.804446225573577*^9, 
   3.804598404993094*^9, 3.805044885202231*^9, 3.8069378533600187`*^9, 
   3.8070918069073057`*^9, 3.807092491123207*^9, 3.825425047934004*^9, 
   3.825425163484467*^9, 3.825425205727232*^9, 3.828107412582389*^9, 
   3.8287165003549643`*^9, 3.828717660329898*^9, 3.832075131818438*^9, 
   3.8320853853011723`*^9, 3.839324799266877*^9, 3.8490212621224403`*^9, 
   3.852115138839651*^9, 3.8521370090634413`*^9, 3.852137753835341*^9, 
   3.852142761835259*^9, 3.852284684802907*^9, 3.852293242818429*^9, 
   3.852293910228157*^9, 3.85229420485784*^9, 3.852327486595819*^9, 
   3.852328174929751*^9, 3.852364094332211*^9, 3.852364784029379*^9, 
   3.852366459117187*^9, 3.85374573715753*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"e560b660-e84e-4c06-b48e-099bbfeb0aa1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"1"},
    "C"], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
     RowBox[{"I0", " ", "\[Psi]"}], "+", 
     RowBox[{"V00", " ", "\[Psi]"}]}], "\[Psi]"]}], "}"}]], "Output",
 CellChangeTimes->{{3.797763432126686*^9, 3.797763451185824*^9}, 
   3.797763932383679*^9, 3.797763992284377*^9, 3.797764047187402*^9, 
   3.797764251405716*^9, 3.797764561048348*^9, 3.797765256146646*^9, 
   3.797765527068449*^9, 3.797765778990271*^9, 3.7977661190851088`*^9, 
   3.7977743072948093`*^9, 3.7977885893152847`*^9, 3.797794568643297*^9, 
   3.797794703656815*^9, 3.797794736350237*^9, 3.7977948724525633`*^9, 
   3.797794972398164*^9, 3.797843180010244*^9, 3.797845750873942*^9, 
   3.7978460423889093`*^9, 3.7978472314593687`*^9, 3.79784904522234*^9, 
   3.797849118869598*^9, 3.797849362811796*^9, 3.797849635038395*^9, 
   3.797849724142501*^9, 3.797849923899145*^9, 3.797850014478168*^9, 
   3.797854696536385*^9, 3.797858820864097*^9, 3.7978592150498447`*^9, 
   3.7978596050347*^9, 3.797859746990818*^9, 3.797860192226371*^9, 
   3.7978609237873917`*^9, 3.797865778810155*^9, 3.797865944060143*^9, 
   3.797866014658936*^9, 3.797866519139865*^9, 3.797874686542088*^9, 
   3.7978812918405743`*^9, 3.7978819764561567`*^9, 3.797927802074431*^9, 
   3.797928428450698*^9, 3.797929820004951*^9, 3.7979302622142963`*^9, 
   3.797930718432769*^9, 3.797940010132489*^9, 3.797940568572926*^9, 
   3.7979407267074203`*^9, 3.79794101270175*^9, 3.7981033040151377`*^9, 
   3.798111420132913*^9, 3.798329529239274*^9, 3.798381666134903*^9, 
   3.798477225452767*^9, 3.798795039281993*^9, 3.7988434408008204`*^9, 
   3.7990596027087307`*^9, 3.799076829768573*^9, 3.799682744974988*^9, 
   3.80034849928872*^9, 3.8008145508098297`*^9, 3.8008149298092527`*^9, 
   3.800816261795023*^9, 3.80082840446848*^9, 3.800830196720587*^9, 
   3.800830341043819*^9, 3.800869035817734*^9, 3.800870788924077*^9, 
   3.8008709908818398`*^9, 3.800897197843157*^9, 3.800900915652014*^9, 
   3.800901497297161*^9, 3.8009026548728333`*^9, 3.800905166546632*^9, 
   3.800962045934854*^9, 3.800968201338788*^9, 3.8013308501020203`*^9, 
   3.8027092714323187`*^9, {3.802710586661562*^9, 3.8027106083788*^9}, 
   3.802713468621327*^9, 3.8027135901630077`*^9, 3.802765249191156*^9, 
   3.8027707269560747`*^9, 3.8027713628823137`*^9, 3.802774643416192*^9, 
   3.803117755490054*^9, 3.803196876915265*^9, 3.8033023037903957`*^9, 
   3.803302681528759*^9, 3.803307831441733*^9, 3.8033240882522306`*^9, 
   3.803411609029541*^9, 3.803412127690324*^9, 3.803412167702276*^9, 
   3.8034747197991753`*^9, 3.803729347021467*^9, 3.8037432423978786`*^9, 
   3.8038063822839127`*^9, 3.803807928175622*^9, 3.803812047365839*^9, 
   3.803824856097395*^9, 3.803829797035966*^9, 3.803891455557622*^9, 
   3.803978843212674*^9, 3.804270163549852*^9, 3.804446225573577*^9, 
   3.804598404993094*^9, 3.805044885202231*^9, 3.8069378533600187`*^9, 
   3.8070918069073057`*^9, 3.807092491123207*^9, 3.825425047934004*^9, 
   3.825425163484467*^9, 3.825425205727232*^9, 3.828107412582389*^9, 
   3.8287165003549643`*^9, 3.828717660329898*^9, 3.832075131818438*^9, 
   3.8320853853011723`*^9, 3.839324799266877*^9, 3.8490212621224403`*^9, 
   3.852115138839651*^9, 3.8521370090634413`*^9, 3.852137753835341*^9, 
   3.852142761835259*^9, 3.852284684802907*^9, 3.852293242818429*^9, 
   3.852293910228157*^9, 3.85229420485784*^9, 3.852327486595819*^9, 
   3.852328174929751*^9, 3.852364094332211*^9, 3.852364784029379*^9, 
   3.852366459117187*^9, 3.85374573716003*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"a83675a6-01f3-4aea-b2fd-7ab3fe4b3b39"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v03", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "t"], " ", "I0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
      "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
          RowBox[{"I0", " ", "\[Psi]"}], "+", 
          RowBox[{"V00", " ", "\[Psi]"}]}], ")"}]}], "\[Psi]"]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.797763432126686*^9, 3.797763451185824*^9}, 
   3.797763932383679*^9, 3.797763992284377*^9, 3.797764047187402*^9, 
   3.797764251405716*^9, 3.797764561048348*^9, 3.797765256146646*^9, 
   3.797765527068449*^9, 3.797765778990271*^9, 3.7977661190851088`*^9, 
   3.7977743072948093`*^9, 3.7977885893152847`*^9, 3.797794568643297*^9, 
   3.797794703656815*^9, 3.797794736350237*^9, 3.7977948724525633`*^9, 
   3.797794972398164*^9, 3.797843180010244*^9, 3.797845750873942*^9, 
   3.7978460423889093`*^9, 3.7978472314593687`*^9, 3.79784904522234*^9, 
   3.797849118869598*^9, 3.797849362811796*^9, 3.797849635038395*^9, 
   3.797849724142501*^9, 3.797849923899145*^9, 3.797850014478168*^9, 
   3.797854696536385*^9, 3.797858820864097*^9, 3.7978592150498447`*^9, 
   3.7978596050347*^9, 3.797859746990818*^9, 3.797860192226371*^9, 
   3.7978609237873917`*^9, 3.797865778810155*^9, 3.797865944060143*^9, 
   3.797866014658936*^9, 3.797866519139865*^9, 3.797874686542088*^9, 
   3.7978812918405743`*^9, 3.7978819764561567`*^9, 3.797927802074431*^9, 
   3.797928428450698*^9, 3.797929820004951*^9, 3.7979302622142963`*^9, 
   3.797930718432769*^9, 3.797940010132489*^9, 3.797940568572926*^9, 
   3.7979407267074203`*^9, 3.79794101270175*^9, 3.7981033040151377`*^9, 
   3.798111420132913*^9, 3.798329529239274*^9, 3.798381666134903*^9, 
   3.798477225452767*^9, 3.798795039281993*^9, 3.7988434408008204`*^9, 
   3.7990596027087307`*^9, 3.799076829768573*^9, 3.799682744974988*^9, 
   3.80034849928872*^9, 3.8008145508098297`*^9, 3.8008149298092527`*^9, 
   3.800816261795023*^9, 3.80082840446848*^9, 3.800830196720587*^9, 
   3.800830341043819*^9, 3.800869035817734*^9, 3.800870788924077*^9, 
   3.8008709908818398`*^9, 3.800897197843157*^9, 3.800900915652014*^9, 
   3.800901497297161*^9, 3.8009026548728333`*^9, 3.800905166546632*^9, 
   3.800962045934854*^9, 3.800968201338788*^9, 3.8013308501020203`*^9, 
   3.8027092714323187`*^9, {3.802710586661562*^9, 3.8027106083788*^9}, 
   3.802713468621327*^9, 3.8027135901630077`*^9, 3.802765249191156*^9, 
   3.8027707269560747`*^9, 3.8027713628823137`*^9, 3.802774643416192*^9, 
   3.803117755490054*^9, 3.803196876915265*^9, 3.8033023037903957`*^9, 
   3.803302681528759*^9, 3.803307831441733*^9, 3.8033240882522306`*^9, 
   3.803411609029541*^9, 3.803412127690324*^9, 3.803412167702276*^9, 
   3.8034747197991753`*^9, 3.803729347021467*^9, 3.8037432423978786`*^9, 
   3.8038063822839127`*^9, 3.803807928175622*^9, 3.803812047365839*^9, 
   3.803824856097395*^9, 3.803829797035966*^9, 3.803891455557622*^9, 
   3.803978843212674*^9, 3.804270163549852*^9, 3.804446225573577*^9, 
   3.804598404993094*^9, 3.805044885202231*^9, 3.8069378533600187`*^9, 
   3.8070918069073057`*^9, 3.807092491123207*^9, 3.825425047934004*^9, 
   3.825425163484467*^9, 3.825425205727232*^9, 3.828107412582389*^9, 
   3.8287165003549643`*^9, 3.828717660329898*^9, 3.832075131818438*^9, 
   3.8320853853011723`*^9, 3.839324799266877*^9, 3.8490212621224403`*^9, 
   3.852115138839651*^9, 3.8521370090634413`*^9, 3.852137753835341*^9, 
   3.852142761835259*^9, 3.852284684802907*^9, 3.852293242818429*^9, 
   3.852293910228157*^9, 3.85229420485784*^9, 3.852327486595819*^9, 
   3.852328174929751*^9, 3.852364094332211*^9, 3.852364784029379*^9, 
   3.852366459117187*^9, 3.8537457371622868`*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"fbc1635b-fc05-4d82-9d77-30c8e6a7f802"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"v03", "[", "t", "]"}], "/.", "defv03"}], ",", 
   RowBox[{"{", 
    RowBox[{"I0", ",", "va"}], "}"}], ",", "Simplify"}], "]"}]], "Input",
 CellChangeTimes->{{3.828108354409998*^9, 3.828108364069118*^9}, {
  3.828108397980955*^9, 3.8281084430183163`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"3d2f2f06-c7f7-4c29-9067-705bc4d65d5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], ")"}], " ", "I0"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "t"}]], " ", "V00"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", "\[Psi]"}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"ts", " ", "\[Psi]"}]]}], ")"}], " ", "va"}], 
   "\[Psi]"]}]], "Output",
 CellChangeTimes->{
  3.828108364442299*^9, {3.82810840915224*^9, 3.828108443664193*^9}, 
   3.8287165004123*^9, 3.8287176603928003`*^9, 3.832075131866613*^9, 
   3.832085385347047*^9, 3.8393247993093643`*^9, 3.849021262210845*^9, 
   3.8521151388891563`*^9, 3.852137009110577*^9, 3.8521377538813553`*^9, 
   3.852142761885047*^9, 3.8522846866231203`*^9, 3.852293242865917*^9, 
   3.852293910279015*^9, 3.8522942049037123`*^9, 3.852327486652419*^9, 
   3.852328174977948*^9, 3.8523640943849*^9, 3.8523647840827303`*^9, 
   3.852366459183998*^9, 3.853745737194544*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"35b8ac6e-6a45-4252-a2cf-1101c1af47a2"]
}, Open  ]],

Cell["Part 4    ", "Text",
 CellChangeTimes->{{3.797764533848486*^9, 3.797764534805797*^9}, {
  3.797865780163349*^9, 3.797865780962679*^9}, {3.797881294437961*^9, 
  3.797881295355872*^9}, {3.804423267560033*^9, 
  3.8044232701195602`*^9}},ExpressionUUID->"020867d9-cd29-4cbc-91a2-\
c1c025895d50"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq04", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"v04", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
   RowBox[{"v04", "[", "t", "]"}], "+", "I0", "+", 
   RowBox[{"va", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"\[Xi]", " ", "t"}], "]"}]}]}]}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"2ec89a7a-d435-4177-a21f-713f348928b8"],

Cell[BoxData[
 RowBox[{"I0", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]], " ", "va"}], "-", 
  RowBox[{"v04", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v04", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.79776349578461*^9, 3.797763932397893*^9, 3.797763992744513*^9, 
   3.79776404720389*^9, 3.7977642514201317`*^9, 3.797764561063293*^9, 
   3.797765256162033*^9, 3.7977655270847607`*^9, 3.7977657790055656`*^9, 
   3.797766119100922*^9, 3.797774307310627*^9, 3.797788589329136*^9, 
   3.797794568658177*^9, 3.797794703671036*^9, 3.797794736364984*^9, 
   3.797794872466084*^9, 3.797794972411901*^9, 3.797843180026454*^9, 
   3.7978457508864822`*^9, 3.797846042402813*^9, 3.797847231474101*^9, 
   3.7978490452345743`*^9, 3.797849118884098*^9, 3.7978493628256702`*^9, 
   3.797849635052593*^9, 3.797849724157035*^9, 3.797849923943907*^9, 
   3.7978500144917803`*^9, 3.797854696552128*^9, 3.7978588208777933`*^9, 
   3.797859215067877*^9, 3.7978596050490103`*^9, 3.797859747008438*^9, 
   3.797860192241868*^9, 3.7978609238019047`*^9, 3.7978657821486883`*^9, 
   3.797865944076529*^9, 3.797866014674335*^9, 3.7978665191542664`*^9, 
   3.79787468655612*^9, 3.7978812967533827`*^9, 3.797881976475451*^9, 
   3.797927802743086*^9, 3.797928429069962*^9, 3.797929820021556*^9, 
   3.797930262234209*^9, 3.797930718451029*^9, 3.797940010149333*^9, 
   3.797940568591065*^9, 3.797940726725556*^9, 3.7979410127201433`*^9, 
   3.7981033040302896`*^9, 3.798111420145617*^9, 3.7983295292864237`*^9, 
   3.79838166615263*^9, 3.79847722547048*^9, 3.79879503930457*^9, 
   3.798843440814028*^9, 3.799059602720829*^9, 3.7990768297845697`*^9, 
   3.799682744988516*^9, 3.800348499301968*^9, 3.8008145508266983`*^9, 
   3.80081492982826*^9, 3.800816261820806*^9, 3.80082840450021*^9, 
   3.8008301967340403`*^9, 3.8008303410639277`*^9, 3.800869035834199*^9, 
   3.800870788936117*^9, 3.800870990895031*^9, 3.8008971978584137`*^9, 
   3.8009009156665087`*^9, 3.800901497311163*^9, 3.8009026548856983`*^9, 
   3.8009051665604553`*^9, 3.8009620459495897`*^9, 3.800968201351554*^9, 
   3.801330850121141*^9, 3.802709271457879*^9, {3.802710586677121*^9, 
   3.802710608396185*^9}, 3.802713468662002*^9, 3.8027135901779613`*^9, 
   3.8027652492036743`*^9, 3.8027707269702377`*^9, 3.80277136289821*^9, 
   3.80277464343021*^9, 3.80311775550465*^9, 3.803196876928771*^9, 
   3.8033023038081703`*^9, 3.803302681541423*^9, 3.8033078314548073`*^9, 
   3.8033240882639217`*^9, 3.803411609044568*^9, 3.803412127705311*^9, 
   3.803412167717918*^9, 3.8034747198159227`*^9, 3.803729347036954*^9, 
   3.803743242411806*^9, 3.803806382296619*^9, 3.803807928188064*^9, 
   3.803812047381181*^9, 3.803824856113806*^9, 3.803829797056199*^9, 
   3.803891455570216*^9, 3.803978843225114*^9, 3.8042701635625753`*^9, 
   3.804446225586608*^9, 3.804598405015625*^9, 3.805044885219552*^9, 
   3.8069378533727007`*^9, 3.8070918069262466`*^9, 3.8070924911430197`*^9, 
   3.825425047945386*^9, 3.825425163493931*^9, 3.825425205738199*^9, 
   3.828107412596978*^9, 3.828716500422073*^9, 3.828717660404026*^9, 
   3.832075131873954*^9, 3.8320853853536*^9, 3.8393247993179207`*^9, 
   3.849021262224722*^9, 3.852115138899418*^9, 3.852137009119791*^9, 
   3.852137753889901*^9, 3.8521427618962107`*^9, 3.852284688630499*^9, 
   3.852293242876199*^9, 3.8522939102900467`*^9, 3.85229420491402*^9, 
   3.8523274866639853`*^9, 3.852328174988247*^9, 3.8523640943954372`*^9, 
   3.852364784098001*^9, 3.852366459195158*^9, 3.853745737202585*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"97c378db-1be5-40ac-9e15-fd79ef2eb581"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "This", " ", "continuity", " ", "condition", " ", "assumes", " ", "that", 
     " ", "ts"}], "<", 
    RowBox[{"T", "-", "\[Phi]T"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"defv04d", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{"DSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"deq04", "\[Equal]", "0"}], "}"}], ",", "v04", ",", "t"}], 
       "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"defIC04", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"v04", "[", 
            RowBox[{"T", "-", 
             RowBox[{"\[Phi]", " ", "T"}]}], "]"}], "\[Equal]", 
           RowBox[{"v03", "[", 
            RowBox[{"T", "-", 
             RowBox[{"\[Phi]", " ", "T"}]}], "]"}]}], "}"}], "/.", 
         "defv04d"}], "/.", "defv03"}], ",", 
       RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   
   RowBox[{"defv04", "=", 
    RowBox[{"defv04d", "/.", "defIC04"}]}]}]}]], "Input",
 CellChangeTimes->{{3.797763513601418*^9, 3.7977635808152742`*^9}, {
  3.804423307001967*^9, 3.8044233073595343`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"ea944281-bc0f-43a5-9102-da85cfff3b0d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v04", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "t"], " ", "I0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       TemplateBox[{"1"},
        "C"]}]}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7977635817223463`*^9, 3.797763932445382*^9, 3.797763992902166*^9, 
   3.7977640472736197`*^9, 3.797764251476746*^9, 3.7977645611260643`*^9, 
   3.797765256220443*^9, 3.797765527135785*^9, 3.797765779052721*^9, 
   3.7977661191645327`*^9, 3.797774307351969*^9, 3.797788589366521*^9, 
   3.7977945693047447`*^9, 3.7977947037404337`*^9, 3.797794736403919*^9, 
   3.797794872530492*^9, 3.7977949724551*^9, 3.797843180074822*^9, 
   3.797845750922579*^9, 3.7978460424434633`*^9, 3.797847231513062*^9, 
   3.7978490452724657`*^9, 3.797849118949748*^9, 3.797849362860077*^9, 
   3.797849635091556*^9, 3.797849724217494*^9, 3.797849923984477*^9, 
   3.797850014532485*^9, 3.797854696600309*^9, 3.7978588209160423`*^9, 
   3.797859215106839*^9, 3.797859605079834*^9, 3.7978597470504713`*^9, 
   3.797860192280704*^9, 3.797860923849992*^9, 3.79786578319569*^9, 
   3.7978659441436367`*^9, 3.797866014721759*^9, 3.797866519203457*^9, 
   3.797874686619413*^9, 3.797881297864051*^9, 3.797881976650483*^9, 
   3.7979278029507627`*^9, 3.797928429316831*^9, 3.797929820078763*^9, 
   3.797930262296154*^9, 3.797930718573502*^9, 3.797940010219269*^9, 
   3.797940568658021*^9, 3.797940726779008*^9, 3.797941012772252*^9, 
   3.798103304077477*^9, 3.798111420189307*^9, 3.798329529327723*^9, 
   3.798381666213704*^9, 3.798477225582859*^9, 3.7987950393633623`*^9, 
   3.798843440898939*^9, 3.799059602778558*^9, 3.7990768298530293`*^9, 
   3.799682745114999*^9, 3.800348499348365*^9, 3.8008145508851013`*^9, 
   3.800814929920559*^9, 3.8008162619430723`*^9, 3.800828404596537*^9, 
   3.800830196782749*^9, 3.8008303411289263`*^9, 3.800869035892281*^9, 
   3.80087078898462*^9, 3.800870990942655*^9, 3.800897197909219*^9, 
   3.800900915725707*^9, 3.800901497356407*^9, 3.8009026549311533`*^9, 
   3.800905166615985*^9, 3.800962045999482*^9, 3.80096820140061*^9, 
   3.801330850226241*^9, 3.802709271542675*^9, {3.8027105867386913`*^9, 
   3.802710608456478*^9}, 3.802713468703196*^9, 3.802713590214828*^9, 
   3.8027652492392807`*^9, 3.802770727008978*^9, 3.80277136298166*^9, 
   3.8027746434661303`*^9, 3.803117755540791*^9, 3.803196876973154*^9, 
   3.8033023038648443`*^9, 3.803302681615651*^9, 3.803307831498619*^9, 
   3.803324088315555*^9, 3.803411609081249*^9, 3.803412127751912*^9, 
   3.803412167773261*^9, 3.803474719887623*^9, 3.80372934707235*^9, 
   3.803743242449774*^9, 3.803806382339644*^9, 3.803807928232503*^9, 
   3.8038120474179983`*^9, 3.803824856170458*^9, 3.8038297971576033`*^9, 
   3.803891455609558*^9, 3.8039788432695847`*^9, 3.804270163606729*^9, 
   3.804446225637024*^9, 3.80459840508156*^9, 3.805044885278245*^9, 
   3.806937853421831*^9, 3.8070918070241613`*^9, 3.807092491214849*^9, 
   3.8254250480016623`*^9, 3.825425163552231*^9, 3.8254252058129387`*^9, 
   3.828107412670319*^9, 3.828716500491518*^9, 3.828717660483156*^9, 
   3.83207513195299*^9, 3.8320853854143*^9, 3.839324799383444*^9, 
   3.8490212623134193`*^9, 3.852115138955921*^9, 3.852137009204356*^9, 
   3.852137753952242*^9, 3.852142761959251*^9, 3.85228469015272*^9, 
   3.852293242944861*^9, 3.852293910350376*^9, 3.852294204974704*^9, 
   3.852327486730383*^9, 3.852328175049602*^9, 3.85236409445592*^9, 
   3.8523647841614428`*^9, 3.8523664592583437`*^9, 3.853745737292055*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"a00b45e8-40f6-440b-8962-1c4afee647d8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{"1"},
    "C"], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
     RowBox[{"I0", " ", "\[Psi]"}], "+", 
     RowBox[{"V00", " ", "\[Psi]"}]}], "\[Psi]"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7977635817223463`*^9, 3.797763932445382*^9, 3.797763992902166*^9, 
   3.7977640472736197`*^9, 3.797764251476746*^9, 3.7977645611260643`*^9, 
   3.797765256220443*^9, 3.797765527135785*^9, 3.797765779052721*^9, 
   3.7977661191645327`*^9, 3.797774307351969*^9, 3.797788589366521*^9, 
   3.7977945693047447`*^9, 3.7977947037404337`*^9, 3.797794736403919*^9, 
   3.797794872530492*^9, 3.7977949724551*^9, 3.797843180074822*^9, 
   3.797845750922579*^9, 3.7978460424434633`*^9, 3.797847231513062*^9, 
   3.7978490452724657`*^9, 3.797849118949748*^9, 3.797849362860077*^9, 
   3.797849635091556*^9, 3.797849724217494*^9, 3.797849923984477*^9, 
   3.797850014532485*^9, 3.797854696600309*^9, 3.7978588209160423`*^9, 
   3.797859215106839*^9, 3.797859605079834*^9, 3.7978597470504713`*^9, 
   3.797860192280704*^9, 3.797860923849992*^9, 3.79786578319569*^9, 
   3.7978659441436367`*^9, 3.797866014721759*^9, 3.797866519203457*^9, 
   3.797874686619413*^9, 3.797881297864051*^9, 3.797881976650483*^9, 
   3.7979278029507627`*^9, 3.797928429316831*^9, 3.797929820078763*^9, 
   3.797930262296154*^9, 3.797930718573502*^9, 3.797940010219269*^9, 
   3.797940568658021*^9, 3.797940726779008*^9, 3.797941012772252*^9, 
   3.798103304077477*^9, 3.798111420189307*^9, 3.798329529327723*^9, 
   3.798381666213704*^9, 3.798477225582859*^9, 3.7987950393633623`*^9, 
   3.798843440898939*^9, 3.799059602778558*^9, 3.7990768298530293`*^9, 
   3.799682745114999*^9, 3.800348499348365*^9, 3.8008145508851013`*^9, 
   3.800814929920559*^9, 3.8008162619430723`*^9, 3.800828404596537*^9, 
   3.800830196782749*^9, 3.8008303411289263`*^9, 3.800869035892281*^9, 
   3.80087078898462*^9, 3.800870990942655*^9, 3.800897197909219*^9, 
   3.800900915725707*^9, 3.800901497356407*^9, 3.8009026549311533`*^9, 
   3.800905166615985*^9, 3.800962045999482*^9, 3.80096820140061*^9, 
   3.801330850226241*^9, 3.802709271542675*^9, {3.8027105867386913`*^9, 
   3.802710608456478*^9}, 3.802713468703196*^9, 3.802713590214828*^9, 
   3.8027652492392807`*^9, 3.802770727008978*^9, 3.80277136298166*^9, 
   3.8027746434661303`*^9, 3.803117755540791*^9, 3.803196876973154*^9, 
   3.8033023038648443`*^9, 3.803302681615651*^9, 3.803307831498619*^9, 
   3.803324088315555*^9, 3.803411609081249*^9, 3.803412127751912*^9, 
   3.803412167773261*^9, 3.803474719887623*^9, 3.80372934707235*^9, 
   3.803743242449774*^9, 3.803806382339644*^9, 3.803807928232503*^9, 
   3.8038120474179983`*^9, 3.803824856170458*^9, 3.8038297971576033`*^9, 
   3.803891455609558*^9, 3.8039788432695847`*^9, 3.804270163606729*^9, 
   3.804446225637024*^9, 3.80459840508156*^9, 3.805044885278245*^9, 
   3.806937853421831*^9, 3.8070918070241613`*^9, 3.807092491214849*^9, 
   3.8254250480016623`*^9, 3.825425163552231*^9, 3.8254252058129387`*^9, 
   3.828107412670319*^9, 3.828716500491518*^9, 3.828717660483156*^9, 
   3.83207513195299*^9, 3.8320853854143*^9, 3.839324799383444*^9, 
   3.8490212623134193`*^9, 3.852115138955921*^9, 3.852137009204356*^9, 
   3.852137753952242*^9, 3.852142761959251*^9, 3.85228469015272*^9, 
   3.852293242944861*^9, 3.852293910350376*^9, 3.852294204974704*^9, 
   3.852327486730383*^9, 3.852328175049602*^9, 3.85236409445592*^9, 
   3.8523647841614428`*^9, 3.8523664592583437`*^9, 3.853745737295178*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"bc3bbfdf-fa95-40a9-9398-01d0f30540ce"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v04", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "t"], " ", "I0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
      "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
          RowBox[{"I0", " ", "\[Psi]"}], "+", 
          RowBox[{"V00", " ", "\[Psi]"}]}], ")"}]}], "\[Psi]"]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7977635817223463`*^9, 3.797763932445382*^9, 3.797763992902166*^9, 
   3.7977640472736197`*^9, 3.797764251476746*^9, 3.7977645611260643`*^9, 
   3.797765256220443*^9, 3.797765527135785*^9, 3.797765779052721*^9, 
   3.7977661191645327`*^9, 3.797774307351969*^9, 3.797788589366521*^9, 
   3.7977945693047447`*^9, 3.7977947037404337`*^9, 3.797794736403919*^9, 
   3.797794872530492*^9, 3.7977949724551*^9, 3.797843180074822*^9, 
   3.797845750922579*^9, 3.7978460424434633`*^9, 3.797847231513062*^9, 
   3.7978490452724657`*^9, 3.797849118949748*^9, 3.797849362860077*^9, 
   3.797849635091556*^9, 3.797849724217494*^9, 3.797849923984477*^9, 
   3.797850014532485*^9, 3.797854696600309*^9, 3.7978588209160423`*^9, 
   3.797859215106839*^9, 3.797859605079834*^9, 3.7978597470504713`*^9, 
   3.797860192280704*^9, 3.797860923849992*^9, 3.79786578319569*^9, 
   3.7978659441436367`*^9, 3.797866014721759*^9, 3.797866519203457*^9, 
   3.797874686619413*^9, 3.797881297864051*^9, 3.797881976650483*^9, 
   3.7979278029507627`*^9, 3.797928429316831*^9, 3.797929820078763*^9, 
   3.797930262296154*^9, 3.797930718573502*^9, 3.797940010219269*^9, 
   3.797940568658021*^9, 3.797940726779008*^9, 3.797941012772252*^9, 
   3.798103304077477*^9, 3.798111420189307*^9, 3.798329529327723*^9, 
   3.798381666213704*^9, 3.798477225582859*^9, 3.7987950393633623`*^9, 
   3.798843440898939*^9, 3.799059602778558*^9, 3.7990768298530293`*^9, 
   3.799682745114999*^9, 3.800348499348365*^9, 3.8008145508851013`*^9, 
   3.800814929920559*^9, 3.8008162619430723`*^9, 3.800828404596537*^9, 
   3.800830196782749*^9, 3.8008303411289263`*^9, 3.800869035892281*^9, 
   3.80087078898462*^9, 3.800870990942655*^9, 3.800897197909219*^9, 
   3.800900915725707*^9, 3.800901497356407*^9, 3.8009026549311533`*^9, 
   3.800905166615985*^9, 3.800962045999482*^9, 3.80096820140061*^9, 
   3.801330850226241*^9, 3.802709271542675*^9, {3.8027105867386913`*^9, 
   3.802710608456478*^9}, 3.802713468703196*^9, 3.802713590214828*^9, 
   3.8027652492392807`*^9, 3.802770727008978*^9, 3.80277136298166*^9, 
   3.8027746434661303`*^9, 3.803117755540791*^9, 3.803196876973154*^9, 
   3.8033023038648443`*^9, 3.803302681615651*^9, 3.803307831498619*^9, 
   3.803324088315555*^9, 3.803411609081249*^9, 3.803412127751912*^9, 
   3.803412167773261*^9, 3.803474719887623*^9, 3.80372934707235*^9, 
   3.803743242449774*^9, 3.803806382339644*^9, 3.803807928232503*^9, 
   3.8038120474179983`*^9, 3.803824856170458*^9, 3.8038297971576033`*^9, 
   3.803891455609558*^9, 3.8039788432695847`*^9, 3.804270163606729*^9, 
   3.804446225637024*^9, 3.80459840508156*^9, 3.805044885278245*^9, 
   3.806937853421831*^9, 3.8070918070241613`*^9, 3.807092491214849*^9, 
   3.8254250480016623`*^9, 3.825425163552231*^9, 3.8254252058129387`*^9, 
   3.828107412670319*^9, 3.828716500491518*^9, 3.828717660483156*^9, 
   3.83207513195299*^9, 3.8320853854143*^9, 3.839324799383444*^9, 
   3.8490212623134193`*^9, 3.852115138955921*^9, 3.852137009204356*^9, 
   3.852137753952242*^9, 3.852142761959251*^9, 3.85228469015272*^9, 
   3.852293242944861*^9, 3.852293910350376*^9, 3.852294204974704*^9, 
   3.852327486730383*^9, 3.852328175049602*^9, 3.85236409445592*^9, 
   3.8523647841614428`*^9, 3.8523664592583437`*^9, 3.853745737297782*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"e4ce2c42-2738-4a82-8cde-1028fc47f5f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"v04", "[", "t", "]"}], "/.", "defv04"}], "/.", 
    RowBox[{"\[Psi]", "\[Rule]", 
     RowBox[{"xi", "+", "1"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"va", ",", "I0"}], "}"}], ",", "Simplify"}], "]"}]], "Input",
 CellChangeTimes->{{3.828108962939456*^9, 3.828108991100978*^9}, {
  3.8320750998342123`*^9, 3.832075113558427*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"f96bdcc7-09d4-45d2-9cf3-e45eae7a9090"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], ")"}], " ", "I0"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "t"}]], " ", "V00"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "xi"}], ")"}]}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"ts", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "xi"}], ")"}]}]]}], ")"}], " ", "va"}], 
   RowBox[{"1", "+", "xi"}]]}]], "Output",
 CellChangeTimes->{{3.828108968746662*^9, 3.828108991768744*^9}, 
   3.828716500513805*^9, 3.828717660503418*^9, 3.8320751320027637`*^9, 
   3.832085385463915*^9, 3.839324799421814*^9, 3.849021262409397*^9, 
   3.852115139005147*^9, 3.852137009262106*^9, 3.8521377539987383`*^9, 
   3.852142762007886*^9, 3.85228469167701*^9, 3.852293242996323*^9, 
   3.852293910399714*^9, 3.852294205026474*^9, 3.8523274867884817`*^9, 
   3.852328175108857*^9, 3.852364094509046*^9, 3.852364784213222*^9, 
   3.852366459320058*^9, 3.853745737329588*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"1604c65f-4c7a-4f3f-b255-2a7d70760a4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"v04", "[", "t", "]"}], ",", "t"}], "]"}], "+", 
     RowBox[{"v04", "[", "t", "]"}]}], "/.", "defv04"}], "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"xi", "+", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8490232574189463`*^9, 3.849023312116901*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"d8829b46-2169-4d11-9cc0-ff89de2c58ea"],

Cell[BoxData[
 RowBox[{"I0", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t", " ", "xi"}]], " ", "va"}]}]], "Output",
 CellChangeTimes->{{3.849023271843507*^9, 3.849023312638064*^9}, 
   3.8521151390511303`*^9, 3.8521370093038673`*^9, 3.852137754039051*^9, 
   3.852142762048608*^9, 3.8522846927086067`*^9, 3.852293243010542*^9, 
   3.85229391041315*^9, 3.852294205064152*^9, 3.8523274868384027`*^9, 
   3.852328175167693*^9, 3.852364094570385*^9, 3.852364784265131*^9, 
   3.852366459383019*^9, 3.8537457374091167`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"92f8b49c-bd1d-4c13-bfa1-02a8f04955d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vck", "=", 
  RowBox[{"1", "+", 
   RowBox[{"I0", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", "t"}], "]"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"va", "/", 
     RowBox[{"(", 
      RowBox[{"1", "+", "xi"}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{"xi", " ", "t"}], "]"}], "-", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", "t"}], "]"}]}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8490229222259274`*^9, 3.849022957601447*^9}, {
  3.849022995947874*^9, 3.849022998471962*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"2a524f92-f72e-4c44-a805-7ad6cb4f56e5"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], ")"}], " ", "I0"}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", "xi"}]]}], ")"}], " ", "va"}], 
   RowBox[{"1", "+", "xi"}]]}]], "Output",
 CellChangeTimes->{3.849022999094358*^9, 3.852115139096437*^9, 
  3.852137009348638*^9, 3.852137754047318*^9, 3.852142762058032*^9, 
  3.852284693819442*^9, 3.852293243050242*^9, 3.8522939104527903`*^9, 
  3.85229420507474*^9, 3.852327486850445*^9, 3.852328175208902*^9, 
  3.852364094612032*^9, 3.852364784278698*^9, 3.8523664593963737`*^9, 
  3.853745737422065*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"edfa5492-4ce4-4aa0-a3a6-5609061848a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"vck", ",", "t"}], "]"}], "+", "vck"}], "]"}]], "Input",
 CellChangeTimes->{{3.849022983739312*^9, 3.849023023590814*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"d6bf6256-0a24-4ccb-a269-d7e478be1a45"],

Cell[BoxData[
 RowBox[{"1", "+", "I0", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t", " ", "xi"}]], " ", "va"}]}]], "Output",
 CellChangeTimes->{{3.849022986720739*^9, 3.84902302396001*^9}, 
   3.85211513910373*^9, 3.852137009360073*^9, 3.8521377540847807`*^9, 
   3.8521427620985947`*^9, 3.85228469477312*^9, 3.852293243060781*^9, 
   3.85229391046419*^9, 3.8522942051119003`*^9, 3.8523274869048433`*^9, 
   3.8523281752193613`*^9, 3.8523640946225643`*^9, 3.852364784318008*^9, 
   3.8523664594509687`*^9, 3.853745737459587*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"96f3f77a-f7af-4bbf-8be4-926c3e31ffb3"]
}, Open  ]],

Cell[TextData[StyleBox["O(g)", "Section"]], "Text",
 CellChangeTimes->{{3.7977636241235313`*^9, 
  3.797763625017826*^9}},ExpressionUUID->"2953cdb4-9adc-4cf2-b170-\
2a8aea13e68d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"v11", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
    RowBox[{"v11", "[", "t", "]"}], "+", "I1", "+", 
    RowBox[{"g0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"v01", "[", 
        RowBox[{"t", "+", 
         RowBox[{"\[Phi]", " ", "T"}]}], "]"}], "-", 
       RowBox[{"v01", "[", "t", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Vr", "-", 
       RowBox[{"v01", "[", "t", "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gc1", "[", "t", "]"}], " ", "+", " ", 
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", "T"}], "]"}]}], "+", 
       RowBox[{"\[Gamma]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "-", "T"}], "]"}]}], "+", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", " ", 
          RowBox[{"2", " ", "T"}]}], "]"}]}]}], ")"}]}]}], "/.", 
   "def\[Alpha]\[Beta]\[Gamma]"}]}]], "Input",
 CellChangeTimes->{{3.797858795281617*^9, 3.797858797065117*^9}, {
   3.7978608368016577`*^9, 3.7978608413658323`*^9}, {3.797874240780525*^9, 
   3.797874245591886*^9}, {3.797874294483693*^9, 3.797874295936932*^9}, {
   3.797874681033622*^9, 3.797874681417547*^9}, {3.797884065416066*^9, 
   3.7978840860777607`*^9}, {3.797929593335774*^9, 3.797929597367584*^9}, {
   3.798843924807014*^9, 3.798843949940065*^9}, {3.798844007772253*^9, 
   3.7988440085723743`*^9}, 3.798844180034779*^9, {3.798844224074522*^9, 
   3.798844268913597*^9}, {3.798844462057341*^9, 3.7988444671561403`*^9}, {
   3.800897278827667*^9, 3.8008973055866137`*^9}, {3.800900875553278*^9, 
   3.80090088471837*^9}, 3.800902198055628*^9, {3.800904772855517*^9, 
   3.8009047798118687`*^9}, {3.852294102464006*^9, 3.852294103531411*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"50482738-96ce-4929-8e08-f939d04ed38e"],

Cell[BoxData[
 RowBox[{"I1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], ")"}]}]], 
        "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], ")"}]}]]}],
        ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]f"}], ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]r"}], ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", 
        RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"Vr", "-", 
     RowBox[{"v01", "[", "t", "]"}]}], ")"}]}], "+", 
  RowBox[{"g0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"v01", "[", "t", "]"}]}], "+", 
     RowBox[{"v01", "[", 
      RowBox[{"t", "+", 
       RowBox[{"T", " ", "\[Phi]"}]}], "]"}]}], ")"}]}], "-", 
  RowBox[{"v11", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v11", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.79776399322929*^9, 3.7977640478145437`*^9, 3.7977642514942837`*^9, 
   3.7977645611409693`*^9, 3.7977652562371597`*^9, 3.7977655271542387`*^9, 
   3.797765779068994*^9, 3.797766119180173*^9, 3.797774307369794*^9, 
   3.797788589415626*^9, 3.797794569634918*^9, 3.797794703833983*^9, 
   3.7977947365697203`*^9, 3.797794872546085*^9, 3.797794972469636*^9, 
   3.7978431800876904`*^9, 3.797845750934699*^9, 3.797846042455504*^9, 
   3.79784723156833*^9, 3.7978490452847347`*^9, 3.797849118963661*^9, 
   3.797849362872991*^9, 3.797849635105186*^9, 3.797849724232798*^9, 
   3.79784992399823*^9, 3.7978500145456457`*^9, 3.7978546966180468`*^9, {
   3.797858798861679*^9, 3.7978588209315853`*^9}, 3.797859215125675*^9, 
   3.797859605095624*^9, 3.797859747069314*^9, 3.797860192295834*^9, 
   3.797860923864544*^9, 3.7978609688573303`*^9, 3.797865785635214*^9, 
   3.797865944782176*^9, 3.79786601473708*^9, 3.797866054268303*^9, 
   3.797866519220188*^9, 3.797874686635025*^9, 3.797881300092457*^9, 
   3.797881976691318*^9, 3.7978842272161617`*^9, 3.797927802972199*^9, 
   3.797928429337439*^9, 3.797929820700989*^9, 3.7979302623193808`*^9, 
   3.7979307185986156`*^9, 3.797940010237486*^9, 3.797940568676611*^9, 
   3.797940726796489*^9, 3.797941012790238*^9, 3.798103304092701*^9, 
   3.798111420203395*^9, 3.798329529340528*^9, 3.798381666230435*^9, 
   3.798477225600541*^9, 3.7987950393919907`*^9, 3.7988434409165487`*^9, 
   3.798843960267301*^9, 3.798844020878648*^9, 3.798844196776763*^9, 
   3.798844233517428*^9, {3.7988442647571363`*^9, 3.7988442694756308`*^9}, 
   3.798844468292225*^9, 3.799059602790638*^9, 3.7990768298772907`*^9, 
   3.799682745131812*^9, 3.800348499367056*^9, 3.8008145509058743`*^9, 
   3.8008149299935513`*^9, 3.800816261968706*^9, 3.8008284046191683`*^9, 
   3.800830196797875*^9, 3.800830341147354*^9, 3.800869035907638*^9, 
   3.800870788997724*^9, 3.800870990958065*^9, 3.8008971979261312`*^9, 
   3.800900915740247*^9, 3.800901497370043*^9, 3.800902233939921*^9, 
   3.800902654944919*^9, 3.8009051666301117`*^9, 3.800962046015799*^9, 
   3.800968201416997*^9, 3.801330850246711*^9, 3.8027092716142883`*^9, {
   3.802710586755807*^9, 3.802710608474675*^9}, 3.802713468716098*^9, 
   3.802713590228468*^9, 3.802765249253271*^9, 3.8027707270232143`*^9, 
   3.802771362998557*^9, 3.8027746434808064`*^9, 3.803117755558312*^9, 
   3.803196876989497*^9, 3.803302303881578*^9, 3.803302681630436*^9, 
   3.803307831511121*^9, 3.8033240883310013`*^9, 3.803411609098875*^9, 
   3.80341212776807*^9, 3.803412167789103*^9, 3.803474719962843*^9, 
   3.8037293470893917`*^9, 3.803743242465814*^9, 3.8038063823538857`*^9, 
   3.803807928247159*^9, 3.803812047435164*^9, 3.803824856188106*^9, 
   3.80382979717554*^9, 3.8038914556245823`*^9, 3.803978843284774*^9, 
   3.8042701636234083`*^9, 3.804446225652678*^9, 3.804598405106669*^9, 
   3.805044885299474*^9, 3.806937853437117*^9, 3.807091807046369*^9, 
   3.80709249123641*^9, 3.82542504801475*^9, 3.825425163598106*^9, 
   3.8254252058236437`*^9, 3.828107412688623*^9, 3.828716500566662*^9, 
   3.828717660552905*^9, 3.8320751320098877`*^9, 3.832085385471184*^9, 
   3.839324799456543*^9, 3.849021262421829*^9, 3.852115139149132*^9, 
   3.852137009400703*^9, 3.852137754093573*^9, 3.8521427621090107`*^9, 
   3.852293243103774*^9, 3.852293910507018*^9, 3.852294205128587*^9, 
   3.852327486919434*^9, 3.8523281752690496`*^9, 3.852364094675215*^9, 
   3.852364784366485*^9, 3.8523664595140676`*^9, 3.853745737518764*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"9620880d-0e6f-4e18-a3b6-b5b0854c3203"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"defv11d", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"deq11", "\[Equal]", "0"}], "}"}], "/.", "defv01"}], ",", 
       "v11", ",", "t"}], "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defIC11", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"v11", "[", "0", "]"}], "/.", "defv11d"}], "}"}], "\[Equal]",
        "V10"}], ",", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv11a", "=", 
   RowBox[{"defv11d", "/.", "defIC11"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"defv11", "=", 
  RowBox[{"v11", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"v11", "[", "t", "]"}], "/.", "defv11a"}], ",", 
        RowBox[{"{", 
         RowBox[{"gc01", ",", "g0", ",", 
          RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
       "]"}], "]"}]}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.797858467214547*^9, 3.797858486222324*^9}, {
  3.797866569657089*^9, 3.797866572961953*^9}, {3.797866605404522*^9, 
  3.797866608391829*^9}, {3.797883912261697*^9, 3.797883921709103*^9}, {
  3.797883955395887*^9, 3.797884036131733*^9}, {3.7988443109440117`*^9, 
  3.7988443223986473`*^9}, {3.798844357086327*^9, 3.7988443600942698`*^9}, {
  3.7988444766253643`*^9, 3.798844481808105*^9}, {3.798844517992799*^9, 
  3.798844550077572*^9}, {3.798844796007888*^9, 3.798844807407208*^9}, {
  3.798844849609737*^9, 3.798844900781246*^9}, {3.7988449524679193`*^9, 
  3.798844982937867*^9}, {3.798845092327977*^9, 3.798845111781035*^9}, {
  3.7988451436807013`*^9, 3.798845149173403*^9}, {3.798845250906489*^9, 
  3.798845273262026*^9}, {3.800868169536718*^9, 3.800868182211035*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"047d3352-a18f-49b6-9aac-c0fbe711aa24"],

Cell[BoxData[
 RowBox[{"v11", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", "t", "}"}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "-", 
        RowBox[{"T", " ", "\[Phi]"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", "\[Phi]"}]]}], ")"}], " ", "g0", " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{"I0", "-", "V00"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[ExponentialE]", "t"]}], ")"}], " ", "I1"}], "+", 
        "V10"}], ")"}]}], "+", 
     RowBox[{"gc01", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", "t"}]]}], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]f"}], "+", 
               RowBox[{"Tc1", " ", "\[Sigma]f"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]f"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "t"}], "+", "Tc1"}], ")"}], " ", "\[Sigma]f"}]],
              " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}]}], "\[Sigma]f"], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]r"}], "+", 
               RowBox[{"Tc1", " ", "\[Sigma]r"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]r"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "Vr"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "t"}], "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]],
              " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "\[Sigma]r"], "+", 
           
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{"\[Sigma]f", " ", "\[Sigma]r"}]]}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{"t", "-", "Tc1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", "t"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Vr", " ", "\[Sigma]f", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]]}], 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"T", "+", "Tc1"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]f"}]], 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]}], ")"}], 
              " ", "\[Sigma]r"}], "+", 
             RowBox[{"V00", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]]}], 
                  ")"}], " ", "\[Sigma]f"}], "+", "\[Sigma]r", "-", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]f"}]], 
                 " ", "\[Sigma]r"}]}], ")"}]}], "+", 
             RowBox[{"I0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]f"}]]}], 
                    ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
                   "\[Sigma]r"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[Sigma]f", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]], 
                   "+", "\[Sigma]r", "-", 
                   RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"T", "+", "Tc1"}]], " ", "\[Sigma]r"}]}], ")"}]}],
                 "-", 
                RowBox[{"\[Sigma]f", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]], 
                   "+", 
                   SuperscriptBox["\[Sigma]r", "2"], "-", 
                   RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"T", "+", "Tc1"}]], " ", 
                    SuperscriptBox["\[Sigma]r", "2"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"UnitStep", "[", 
            RowBox[{
             RowBox[{"-", "T"}], "-", "Tc1"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", "\[Sigma]f", 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
           "\[Sigma]r"}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]f"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]f"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]f"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "t"}], "+", "T", "+", "Tc1"}], ")"}], " ", 
               "\[Sigma]f"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}]}], "\[Sigma]f"], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]r"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"T", "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]r"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"T", "+", "Tc1"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "t"}], "+", "T", "+", "Tc1"}], ")"}], " ", 
               "\[Sigma]r"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "\[Sigma]r"], "+", 
           
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{"\[Sigma]f", " ", "\[Sigma]r"}]]}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{"t", "-", "T", "-", "Tc1"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "T"}], "+", "Tc1"}], ")"}], " ", "\[Sigma]f"}]],
              " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "V00", "-", 
               RowBox[{"V00", " ", "\[Sigma]f"}], "+", 
               RowBox[{"Vr", " ", "\[Sigma]f"}]}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             "\[Sigma]f"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "T"}], "+", "Tc1"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{"\[Sigma]f", " ", "\[Sigma]r"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "T"}], "+", "Tc1"}], ")"}], " ", "\[Sigma]r"}]],
              " ", 
             RowBox[{"(", 
              RowBox[{"I0", "+", 
               RowBox[{"V00", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}], "-", 
               RowBox[{"Vr", " ", "\[Sigma]r"}]}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
             "\[Sigma]r"}]]}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{"T", "-", "Tc1"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]f"}], "-", 
               RowBox[{"T", " ", "\[Sigma]f"}], "+", 
               RowBox[{"Tc1", " ", "\[Sigma]f"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]f"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", 
                 "\[Sigma]f"}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "\[Sigma]f"], "+", 
           
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]r"}], "-", 
               RowBox[{"T", " ", "\[Sigma]r"}], "+", 
               RowBox[{"Tc1", " ", "\[Sigma]r"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]r"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"-", "T"}], "+", "Tc1"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", 
                 "\[Sigma]r"}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}]}], "\[Sigma]r"], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{"\[Sigma]f", " ", "\[Sigma]r"}]]}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{"t", "+", "T", "-", "Tc1"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}], ")"}], " ", 
               "\[Sigma]f"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "V00", "-", 
               RowBox[{"V00", " ", "\[Sigma]f"}], "+", 
               RowBox[{"Vr", " ", "\[Sigma]f"}]}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             "\[Sigma]f"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{"\[Sigma]f", " ", "\[Sigma]r"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}], ")"}], " ", 
               "\[Sigma]r"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "+", 
               RowBox[{"V00", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}], "-", 
               RowBox[{"Vr", " ", "\[Sigma]r"}]}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
             "\[Sigma]r"}]]}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]f"}], "-", 
               RowBox[{"2", " ", "T", " ", "\[Sigma]f"}], "+", 
               RowBox[{"Tc1", " ", "\[Sigma]f"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]f"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"t", "+", 
                   RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
                 "\[Sigma]f"}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "\[Sigma]f"], "+", 
           
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"t", "-", 
               RowBox[{"t", " ", "\[Sigma]r"}], "-", 
               RowBox[{"2", " ", "T", " ", "\[Sigma]r"}], "+", 
               RowBox[{"Tc1", " ", "\[Sigma]r"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]r"}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"t", "+", 
                   RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
                 "\[Sigma]r"}], ")"}]}]], " ", 
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}]}], "\[Sigma]r"], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"I0", "-", "V00"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], 
            RowBox[{"\[Sigma]f", " ", "\[Sigma]r"}]]}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{"t", "+", 
           RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", "t"}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Vr", " ", "\[Sigma]f", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"Tc1", " ", "\[Sigma]r"}]]}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Sigma]f", "-", "\[Sigma]r"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Tc1", " ", "\[Sigma]f"}]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}]}]}], ")"}], 
              " ", "\[Sigma]r"}], "+", 
             RowBox[{"V00", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Tc1", " ", "\[Sigma]r"}]]}], ")"}], " ", 
                 "\[Sigma]f"}], "+", "\[Sigma]r", "-", 
                RowBox[{
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Tc1", " ", "\[Sigma]f"}]], " ", "\[Sigma]r"}]}], 
               ")"}]}], "+", 
             RowBox[{"I0", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Tc1", " ", "\[Sigma]f"}]]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
                   "\[Sigma]r"}], ")"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[Sigma]f", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Tc1", " ", "\[Sigma]r"}]], "+", "\[Sigma]r", "-", 
                   RowBox[{
                    SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
                    "\[Sigma]r"}]}], ")"}]}], "-", 
                RowBox[{"\[Sigma]f", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Tc1", " ", "\[Sigma]r"}]], "+", 
                   SuperscriptBox["\[Sigma]r", "2"], "-", 
                   RowBox[{
                    SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
                    SuperscriptBox["\[Sigma]r", "2"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}], " ", 
           RowBox[{"UnitStep", "[", 
            RowBox[{"-", "Tc1"}], "]"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]f"}], ")"}], " ", "\[Sigma]f", 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Sigma]r"}], ")"}], " ", 
           "\[Sigma]r"}], ")"}]}]}], ")"}]}]}]}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.797763618530171*^9, 3.7977639325668497`*^9, 3.797763993292551*^9, 
   3.79776404808215*^9, 3.797764251621045*^9, 3.797764561264592*^9, 
   3.7977652563294353`*^9, 3.797765527237067*^9, 3.797765779146824*^9, 
   3.797766121080986*^9, 3.79777430744944*^9, 3.797788589496188*^9, 
   3.7977945697124977`*^9, 3.797794703913817*^9, 3.79779473857436*^9, 
   3.797794874946142*^9, 3.7977949725482397`*^9, 3.797843180170002*^9, 
   3.797845752158471*^9, 3.797846043669043*^9, 3.79784723447545*^9, 
   3.797849045361384*^9, 3.797849119040642*^9, 3.7978493640740128`*^9, 
   3.7978496363322144`*^9, 3.7978497262957*^9, 3.797849924075642*^9, 
   3.7978500146260977`*^9, 3.797854698703224*^9, 3.797858509004445*^9, 
   3.7978588219329243`*^9, 3.7978592162514753`*^9, 3.797859606062356*^9, 
   3.797859748218898*^9, 3.7978602118393793`*^9, 3.7978609510866127`*^9, 
   3.79786099943204*^9, 3.797861296563896*^9, 3.797865947212935*^9, {
   3.797865978101615*^9, 3.797865983921854*^9}, 3.7978660155502243`*^9, 
   3.797866057716467*^9, 3.797866520612605*^9, 3.7978665744684553`*^9, 
   3.7978666091023083`*^9, 3.797874690016179*^9, 3.797881305904316*^9, 
   3.797881979783326*^9, 3.797883924995462*^9, {3.797883959330658*^9, 
   3.797883972752109*^9}, 3.7978840396612988`*^9, 3.7978842326757183`*^9, 
   3.7979278079473467`*^9, 3.797928433854247*^9, 3.797929825866149*^9, 
   3.797930264973873*^9, 3.7979307230809593`*^9, 3.7979400137835608`*^9, 
   3.797940573320096*^9, 3.7979407312087*^9, 3.797941016770733*^9, 
   3.7981033130459948`*^9, 3.798111429737607*^9, 3.798329537702058*^9, 
   3.798381676997838*^9, 3.798477238939831*^9, 3.798795049511753*^9, 
   3.798843450327775*^9, 3.7988439844838953`*^9, 3.79884403261618*^9, 
   3.798844204180903*^9, 3.798844238129902*^9, 3.7988442943639708`*^9, 
   3.798844370776329*^9, 3.798844499866871*^9, 3.798844562083252*^9, 
   3.798844821271934*^9, {3.79884488668782*^9, 3.798844911176313*^9}, {
   3.7988449714812193`*^9, 3.7988449923313932`*^9}, {3.798845104527287*^9, 
   3.798845122393877*^9}, 3.7988451590666533`*^9, {3.798845264627931*^9, 
   3.798845284253172*^9}, 3.799059620124815*^9, 3.799076851331007*^9, 
   3.799682764287405*^9, 3.800348517400477*^9, 3.800814570539709*^9, 
   3.8008149573186007`*^9, 3.800816268880356*^9, 3.80082841132421*^9, 
   3.800830202082162*^9, 3.8008303600165043`*^9, 3.800869041513104*^9, 
   3.800870794593178*^9, 3.800871010962798*^9, 3.800897203523871*^9, 
   3.8009014717657833`*^9, 3.8009015886796827`*^9, 3.800902242424159*^9, 
   3.800902672720965*^9, 3.80090518506284*^9, 3.800962064043879*^9, 
   3.800968230968402*^9, 3.8013308859711323`*^9, 3.802709304745944*^9, {
   3.802710587934392*^9, 3.8027106086191998`*^9}, 3.802713468810987*^9, 
   3.802713590323737*^9, 3.802765249344864*^9, 3.802770727117305*^9, 
   3.802771363116081*^9, 3.8027746753972263`*^9, 3.803117786804042*^9, 
   3.8031969081489067`*^9, 3.803302335251547*^9, 3.803302712920467*^9, 
   3.803307863775097*^9, 3.803324120896578*^9, 3.8034116412202387`*^9, 
   3.8034121478623543`*^9, 3.803412197440652*^9, 3.8034747531364117`*^9, 
   3.803729381865653*^9, 3.803743273389489*^9, 3.803806412400469*^9, 
   3.8038079577252493`*^9, 3.803812076994882*^9, 3.8038248963029118`*^9, 
   3.803829840428688*^9, 3.8038914844299307`*^9, 3.8039788741566467`*^9, 
   3.804270195986849*^9, 3.804446255507712*^9, 3.804598438947711*^9, 
   3.8050449281024837`*^9, 3.806937882868544*^9, 3.80709184386928*^9, 
   3.8070925227655487`*^9, 3.8254251068957357`*^9, 3.825425163785281*^9, 
   3.825425206029961*^9, 3.828107412921829*^9, 3.828716575875375*^9, 
   3.82871766514478*^9, 3.832075135842658*^9, 3.83208538935929*^9, 
   3.839324803328084*^9, 3.8490213477498617`*^9, 3.8521152017889767`*^9, 
   3.8521370689816*^9, 3.852137815982257*^9, 3.85214282304814*^9, 
   3.8522932468297777`*^9, 3.8522939703414183`*^9, 3.852294208701343*^9, 
   3.852327490914589*^9, 3.852328178800173*^9, 3.852364098309236*^9, 
   3.8523648501243877`*^9, 3.8523665198468122`*^9, 3.853745806684998*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"5e1cd10f-8f0b-4f8d-b252-1f253803d509"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq12", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"v12", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
    RowBox[{"v12", "[", "t", "]"}], "+", "I1", "+", 
    RowBox[{"g0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"v03", "[", 
        RowBox[{"t", "+", 
         RowBox[{"\[Phi]", " ", "T"}]}], "]"}], "-", 
       RowBox[{"v02", "[", "t", "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Vr", "-", 
       RowBox[{"v02", "[", "t", "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gc1", "[", "t", "]"}], " ", "+", 
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", "T"}], "]"}]}], "+", 
       RowBox[{"\[Gamma]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "-", "T"}], "]"}]}], "+", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", " ", 
          RowBox[{"2", " ", "T"}]}], "]"}]}]}], ")"}]}]}], "/.", 
   "def\[Alpha]\[Beta]\[Gamma]"}]}]], "Input",
 CellChangeTimes->{{3.797763734950828*^9, 3.797763738385425*^9}, {
   3.79776397635437*^9, 3.797763978397764*^9}, {3.7978588025350113`*^9, 
   3.7978588026470118`*^9}, {3.797860889052706*^9, 3.7978608925264997`*^9}, {
   3.797874302323955*^9, 3.79787430610357*^9}, {3.7978746773009644`*^9, 
   3.7978746780361013`*^9}, {3.797929603773313*^9, 3.797929608511915*^9}, {
   3.7988458007152367`*^9, 3.798845818933119*^9}, {3.800897344025506*^9, 
   3.8008973655144653`*^9}, 3.8009008998129253`*^9, 3.8009022029629917`*^9, {
   3.8009047874705343`*^9, 3.800904791577866*^9}, 3.800904912697426*^9, {
   3.852294159210258*^9, 3.852294160108069*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"dda52fc4-7d9d-40c6-91c6-fe7e1b06e9b7"],

Cell[BoxData[
 RowBox[{"I1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], ")"}]}]], 
        "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], ")"}]}]]}],
        ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]f"}], ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]r"}], ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", 
        RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"Vr", "-", 
     RowBox[{"v02", "[", "t", "]"}]}], ")"}]}], "+", 
  RowBox[{"g0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"v02", "[", "t", "]"}]}], "+", 
     RowBox[{"v03", "[", 
      RowBox[{"t", "+", 
       RowBox[{"T", " ", "\[Phi]"}]}], "]"}]}], ")"}]}], "-", 
  RowBox[{"v12", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v12", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.797763739754841*^9, 3.7977639325804157`*^9, 3.797763993307069*^9, 
   3.797764048097143*^9, 3.7977642516370773`*^9, 3.79776456127985*^9, 
   3.797765256345985*^9, 3.7977655272525463`*^9, 3.797765779162994*^9, 
   3.797766121769751*^9, 3.79777430746691*^9, 3.797788589510618*^9, 
   3.797794569726574*^9, 3.797794703927582*^9, 3.797794738810814*^9, 
   3.7977948752294273`*^9, 3.797794972563018*^9, 3.7978431801819887`*^9, 
   3.797845753920224*^9, 3.797846043759837*^9, 3.797847234693144*^9, 
   3.7978490453739977`*^9, 3.797849119054089*^9, 3.797849364189992*^9, 
   3.797849637034466*^9, 3.797849726558689*^9, 3.7978499240900183`*^9, 
   3.797850014640036*^9, 3.7978546995986977`*^9, {3.7978588035053988`*^9, 
   3.7978588220294724`*^9}, 3.7978592163496113`*^9, 3.797859606162154*^9, 
   3.797859748329228*^9, 3.797860212066877*^9, 3.797866016908696*^9, 
   3.7978660814725313`*^9, 3.7978665207261467`*^9, 3.797874690388743*^9, 
   3.797881980250421*^9, 3.7978843030211687`*^9, 3.797927809708831*^9, 
   3.7979284356112957`*^9, 3.7979298278330173`*^9, 3.797930265258514*^9, 
   3.797930724935343*^9, 3.7979400156799726`*^9, 3.797940575176099*^9, 
   3.797940733910952*^9, 3.797941018810054*^9, 3.798103320419456*^9, 
   3.79811143630865*^9, 3.798329544376334*^9, 3.7983816845011177`*^9, 
   3.798477244660096*^9, 3.798795057614122*^9, 3.7988434574216146`*^9, 
   3.798845819682068*^9, 3.799059621537035*^9, 3.799076853338187*^9, 
   3.79968276599684*^9, 3.8003485189498663`*^9, 3.800814572078793*^9, 
   3.800814959909066*^9, 3.8008162695327263`*^9, 3.800828412065634*^9, 
   3.80083020272357*^9, 3.8008303615080233`*^9, 3.800869041767263*^9, 
   3.8008707946621017`*^9, 3.80087101105134*^9, 3.800897203655903*^9, 
   3.800901588837268*^9, 3.800902244150751*^9, 3.800902672869912*^9, 
   3.800905185294581*^9, 3.8009620641328287`*^9, 3.800968231115672*^9, 
   3.801330886250599*^9, 3.802709305023676*^9, {3.802710588043579*^9, 
   3.802710608630069*^9}, 3.802713468819847*^9, 3.802713590333337*^9, 
   3.802765249353745*^9, 3.802770727126534*^9, 3.802771363126896*^9, 
   3.8027746756172943`*^9, 3.803117787066124*^9, 3.8031969083343353`*^9, 
   3.80330233540028*^9, 3.80330271311726*^9, 3.803307863962338*^9, 
   3.803324121049407*^9, 3.8034116413972588`*^9, 3.803412197552878*^9, 
   3.803474753248077*^9, 3.803729382021125*^9, 3.803743273508691*^9, 
   3.803806412543934*^9, 3.803807957866503*^9, 3.803812077111513*^9, 
   3.803824896378751*^9, 3.8038298405374947`*^9, 3.803891484526453*^9, 
   3.803978874284622*^9, 3.804270196071033*^9, 3.804446255584165*^9, 
   3.8045984391093607`*^9, 3.805044928254623*^9, 3.806937883150756*^9, 
   3.807091843991275*^9, 3.807092522927956*^9, 3.825425106988523*^9, 
   3.8254251637918777`*^9, 3.8254252060381308`*^9, 3.828107412934495*^9, 
   3.82871657642369*^9, 3.828717665250551*^9, 3.832075135981081*^9, 
   3.83208538945544*^9, 3.8393248034177523`*^9, 3.849021347921858*^9, 
   3.852115201929125*^9, 3.852137069123666*^9, 3.852137816138639*^9, 
   3.8521428231336937`*^9, 3.852293246938779*^9, 3.852293970472521*^9, 
   3.8522942087994823`*^9, 3.8523274909897127`*^9, 3.852328178941209*^9, 
   3.85236409849587*^9, 3.852364850327702*^9, 3.852366520133099*^9, 
   3.853745806837611*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"0f46d1f8-624a-4c07-a9f0-fff153288e6f"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"defv12d", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"deq12", "\[Equal]", "0"}], "}"}], "/.", "defv02"}], "/.", 
        "defv03"}], ",", "v12", ",", "t"}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defIC12", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"v12", "[", 
           RowBox[{"ts", "-", 
            RowBox[{"\[Phi]", " ", "T"}]}], "]"}], "\[Equal]", 
          RowBox[{"v11", "[", 
           RowBox[{"ts", "-", 
            RowBox[{"\[Phi]", " ", "T"}]}], "]"}]}], "}"}], "/.", "defv11"}], 
       "/.", "defv12d"}], ",", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv12a", "=", 
   RowBox[{"defv12d", "/.", "defIC12"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv12", "=", 
   RowBox[{"v12", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", 
      RowBox[{"Evaluate", "[", 
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"v12", "[", "t", "]"}], "/.", "defv12a"}], ",", 
         RowBox[{"{", 
          RowBox[{"gc01", ",", "g0", ",", 
           RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
        "]"}], "]"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.797763325757218*^9, 3.797763343174431*^9}, {
   3.797763653509934*^9, 3.797763712062213*^9}, {3.797763745437608*^9, 
   3.79776374678153*^9}, {3.797763784378627*^9, 3.79776387566947*^9}, {
   3.797866616760035*^9, 3.797866628562134*^9}, {3.79793013666525*^9, 
   3.7979301453614273`*^9}, {3.79793074497059*^9, 3.7979307464491987`*^9}, {
   3.797930797023532*^9, 3.797930800007175*^9}, {3.798845295544623*^9, 
   3.798845334285084*^9}, {3.800868187127962*^9, 3.8008681886448793`*^9}, 
   3.8034580765524187`*^9},
 CellLabel->"In[39]:=",ExpressionUUID->"08266c2f-9642-4160-99eb-c147cd098500"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq13", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"v13", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
    RowBox[{"v13", "[", "t", "]"}], "+", "I1", "+", 
    RowBox[{"g0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"v04", "[", 
        RowBox[{"t", "+", 
         RowBox[{"\[Phi]", " ", "T"}]}], "]"}], "-", 
       RowBox[{"v03", "[", "t", "]"}]}], ")"}]}], "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Vr", "-", 
       RowBox[{"v03", "[", "t", "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gc1", "[", "t", "]"}], " ", "+", " ", 
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", "T"}], "]"}]}], "+", " ", 
       RowBox[{"\[Gamma]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "-", "T"}], "]"}]}], "+", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", " ", 
          RowBox[{"2", " ", "T"}]}], "]"}]}]}], ")"}]}]}], "/.", 
   "def\[Alpha]\[Beta]\[Gamma]"}]}]], "Input",
 CellChangeTimes->{{3.797847165776713*^9, 3.797847167858079*^9}, {
   3.797858806867413*^9, 3.797858806989266*^9}, {3.797860898375794*^9, 
   3.797860901389285*^9}, {3.797874311534561*^9, 3.797874316008157*^9}, {
   3.7978746724432783`*^9, 3.7978746729309053`*^9}, {3.797929611681048*^9, 
   3.797929615756836*^9}, {3.798845855011042*^9, 3.798845869628252*^9}, {
   3.800897409368973*^9, 3.800897414039596*^9}, 3.800900904421072*^9, 
   3.800902206134857*^9, {3.800904918084935*^9, 3.8009049258236303`*^9}, {
   3.8522941707410307`*^9, 3.8522941711453247`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"aae63640-282d-4530-a862-7fafd9b768c9"],

Cell[BoxData[
 RowBox[{"I1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], ")"}]}]], 
        "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], ")"}]}]]}],
        ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]f"}], ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]r"}], ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", 
        RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"Vr", "-", 
     RowBox[{"v03", "[", "t", "]"}]}], ")"}]}], "+", 
  RowBox[{"g0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"v03", "[", "t", "]"}]}], "+", 
     RowBox[{"v04", "[", 
      RowBox[{"t", "+", 
       RowBox[{"T", " ", "\[Phi]"}]}], "]"}]}], ")"}]}], "-", 
  RowBox[{"v13", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v13", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7977642235060883`*^9, 3.797764252168768*^9}, 
   3.797764561753599*^9, 3.7977652568380127`*^9, 3.79776552775673*^9, 
   3.797765779509041*^9, 3.797766123454709*^9, 3.797774307890862*^9, 
   3.7977885897885303`*^9, 3.7977945709049463`*^9, 3.797794704271997*^9, 
   3.797794740334367*^9, 3.797794876537695*^9, 3.797794973564951*^9, 
   3.797843180547967*^9, 3.797845755429069*^9, 3.797846045002736*^9, 
   3.7978472361683197`*^9, 3.7978490456581583`*^9, 3.797849119490122*^9, 
   3.7978493663307753`*^9, 3.7978496387493773`*^9, 3.797849728181559*^9, 
   3.797849924465769*^9, 3.797850014913043*^9, 3.7978547020726147`*^9, {
   3.797858807323174*^9, 3.797858823953004*^9}, 3.797859217479684*^9, 
   3.797859608153597*^9, 3.797859749485963*^9, 3.797860251042932*^9, 
   3.797866019019799*^9, 3.79786609297521*^9, 3.797866522286968*^9, 
   3.797874696794813*^9, 3.797881986029393*^9, 3.7979278123273067`*^9, 
   3.797928438235087*^9, 3.797929890750115*^9, 3.797930321051436*^9, 
   3.7979308168058443`*^9, 3.797940018829687*^9, 3.797940577683263*^9, 
   3.797940736338326*^9, 3.79794102284721*^9, 3.798103335517643*^9, 
   3.7981114473927383`*^9, 3.798329555716037*^9, 3.798381697479168*^9, 
   3.7984772619735622`*^9, 3.798795072266673*^9, 3.798843468804453*^9, 
   3.798845741720243*^9, 3.79884587024807*^9, 3.799059642281576*^9, 
   3.799076884660427*^9, 3.7996827934092627`*^9, 3.800348541660697*^9, 
   3.800814594484926*^9, 3.800814992389391*^9, 3.800816277951376*^9, 
   3.8008284187777033`*^9, 3.800830209388762*^9, 3.800830384471603*^9, 
   3.800869047734374*^9, 3.8008708007021513`*^9, 3.800871038617166*^9, 
   3.800897210400895*^9, 3.8009017581829147`*^9, 3.800902252932282*^9, 
   3.800902691743635*^9, 3.80090520519658*^9, 3.8009620855776873`*^9, 
   3.800968264099186*^9, 3.8013309308729258`*^9, 3.8027093453884153`*^9, {
   3.802710590669754*^9, 3.802710609272231*^9}, 3.802713469361504*^9, 
   3.802713590669673*^9, 3.802765249719492*^9, 3.802770727500409*^9, 
   3.80277136362845*^9, 3.802774715149434*^9, 3.803117823706255*^9, 
   3.803196948534994*^9, 3.803302375145047*^9, 3.8033027530705214`*^9, 
   3.803307902935321*^9, 3.803324156336685*^9, 3.803411676113388*^9, 
   3.8034122412412024`*^9, 3.803474786293634*^9, 3.803729421616864*^9, 
   3.8037433070769*^9, 3.803806447020403*^9, 3.803807993764625*^9, 
   3.8038121107407084`*^9, 3.8038249425116587`*^9, 3.803829886557135*^9, 
   3.803891518533988*^9, 3.803978922067244*^9, 3.804270234210273*^9, 
   3.8044462887446632`*^9, 3.8045984827215147`*^9, 3.805044977464118*^9, 
   3.806937917065209*^9, 3.807091877603176*^9, 3.8070925583424892`*^9, 
   3.82542516460209*^9, 3.825425206814187*^9, 3.828107413760466*^9, 
   3.8287166658668623`*^9, 3.8287176702931128`*^9, 3.8320751403074083`*^9, 
   3.832085393874968*^9, 3.839324808503841*^9, 3.849021454447254*^9, 
   3.852115278238782*^9, 3.8521371417195063`*^9, 3.852137898675318*^9, 
   3.852142901670251*^9, 3.852293250895694*^9, 3.852294049847253*^9, 
   3.852294213132388*^9, 3.852327495691389*^9, 3.85232818298363*^9, 
   3.852364102907552*^9, 3.852364932518908*^9, 3.852366594430749*^9, 
   3.853745889217558*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"59160e79-5dd6-4333-939b-82c338407c59"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"defv13d", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"deq13", "\[Equal]", "0"}], "}"}], "/.", "defv03"}], "/.", 
       "defv04"}], ",", "v13", ",", "t"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defIC13", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"v13", "[", "ts", "]"}], "\[Equal]", 
          RowBox[{"v12", "[", "ts", "]"}]}], "}"}], "/.", "defv12"}], "/.", 
       "defv13d"}], ",", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv13a", "=", 
   RowBox[{"defv13d", "/.", "defIC13"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv13", "=", 
   RowBox[{"v13", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", 
      RowBox[{"Evaluate", "[", 
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"v13", "[", "t", "]"}], "/.", "defv13a"}], ",", 
         RowBox[{"{", 
          RowBox[{"gc01", ",", "g0", ",", 
           RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
        "]"}], "]"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7977642842806787`*^9, 3.797764350494256*^9}, {
   3.797847632725458*^9, 3.797847654521101*^9}, {3.7978666360116253`*^9, 
   3.7978666445355473`*^9}, {3.797866681053569*^9, 3.7978666819925833`*^9}, {
   3.797930244614354*^9, 3.79793024767435*^9}, {3.797930659461693*^9, 
   3.7979306627045918`*^9}, {3.797930693935295*^9, 3.797930697051758*^9}, {
   3.798845345272333*^9, 3.798845359474745*^9}, 3.798845403364105*^9, {
   3.800868196175722*^9, 3.800868197718472*^9}, 3.803458072773432*^9},
 CellLabel->"In[44]:=",ExpressionUUID->"06f997ec-7c92-4a21-9a2b-07d18a6b0934"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deq14", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"v14", "[", "t", "]"}], ",", "t"}], "]"}]}], "-", 
    RowBox[{"v14", "[", "t", "]"}], "+", "I1", "+", 
    RowBox[{"g0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"v01", "[", 
        RowBox[{"t", "+", 
         RowBox[{"\[Phi]", " ", "T"}], "-", "T"}], "]"}], "-", 
       RowBox[{"v04", "[", "t", "]"}]}], ")"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Vr", "-", 
       RowBox[{"v04", "[", "t", "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"gc1", "[", "t", "]"}], " ", "+", 
       RowBox[{"\[Alpha]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", "T"}], "]"}]}], "+", 
       RowBox[{"\[Gamma]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "-", "T"}], "]"}]}], "+", 
       RowBox[{"\[Beta]", " ", 
        RowBox[{"gc1", "[", 
         RowBox[{"t", "+", 
          RowBox[{"2", " ", "T"}]}], "]"}]}]}], ")"}]}]}], "/.", 
   "def\[Alpha]\[Beta]\[Gamma]"}]}]], "Input",
 CellChangeTimes->{{3.7978471946061573`*^9, 3.797847199194894*^9}, {
   3.797860909185253*^9, 3.797860913029243*^9}, {3.797874320424387*^9, 
   3.797874322335677*^9}, {3.797874670317974*^9, 3.79787467063717*^9}, {
   3.797929620171833*^9, 3.7979296237720118`*^9}, {3.798845967367676*^9, 
   3.79884597880295*^9}, {3.800897421718889*^9, 3.800897426803253*^9}, 
   3.800900909676805*^9, 3.800902210458797*^9, {3.8009049333029537`*^9, 
   3.800904946059149*^9}, {3.852294175404338*^9, 3.85229417583204*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"3eb07f67-d163-418e-bbfb-0f3d34e96ae6"],

Cell[BoxData[
 RowBox[{"I1", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], ")"}]}]], 
        "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], ")"}]}]]}],
        ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "-", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "-", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], 
           ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], 
           ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", "T", "-", "Tc1"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]f"}], ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
            "\[Sigma]r"}], ")"}]}]]}], ")"}], " ", "gc01", " ", 
      RowBox[{"UnitStep", "[", 
       RowBox[{"t", "+", 
        RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"Vr", "-", 
     RowBox[{"v04", "[", "t", "]"}]}], ")"}]}], "+", 
  RowBox[{"g0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"v01", "[", 
      RowBox[{"t", "-", "T", "+", 
       RowBox[{"T", " ", "\[Phi]"}]}], "]"}], "-", 
     RowBox[{"v04", "[", "t", "]"}]}], ")"}]}], "-", 
  RowBox[{"v14", "[", "t", "]"}], "-", 
  RowBox[{
   SuperscriptBox["v14", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.797764392428191*^9, 3.797764563569808*^9, 3.797765257365283*^9, 
   3.797765528251302*^9, 3.797765780109593*^9, 3.7977661244600677`*^9, 
   3.797774308380784*^9, 3.79778859029536*^9, 3.797794571504368*^9, 
   3.797794704730502*^9, 3.797794741338504*^9, 3.7977948774376497`*^9, 
   3.797794974705009*^9, 3.797843181057588*^9, 3.797845756431669*^9, 
   3.7978460457803383`*^9, 3.797847238931926*^9, 3.7978490462433023`*^9, 
   3.797849120000424*^9, 3.797849369087919*^9, 3.79784964162633*^9, 
   3.797849731291429*^9, 3.797849925024022*^9, 3.797850015466501*^9, 
   3.797854703978024*^9, 3.7978588254005823`*^9, 3.797859218742148*^9, 
   3.797859609687962*^9, 3.797859750724172*^9, 3.797860309409943*^9, 
   3.797866023237637*^9, 3.797866099567349*^9, 3.7978665253641376`*^9, 
   3.797866692073283*^9, 3.797874721616417*^9, 3.797882008206859*^9, 
   3.797927823738092*^9, 3.797928449756937*^9, 3.797930622469874*^9, 
   3.7979308316066647`*^9, 3.797940023888485*^9, 3.797940582123871*^9, 
   3.7979407406634903`*^9, 3.797941030207841*^9, 3.798103369203081*^9, 
   3.798111480069787*^9, 3.7983295881855497`*^9, 3.798381719388857*^9, 
   3.798477287167924*^9, 3.798795095392766*^9, 3.798843490763207*^9, 
   3.798845777824901*^9, 3.798845979248706*^9, 3.79905968124625*^9, 
   3.7990769413426*^9, 3.7996828367034607`*^9, 3.800348582734565*^9, 
   3.8008146374634523`*^9, 3.8008150379650497`*^9, 3.800816299827442*^9, 
   3.800828437930504*^9, 3.8008302271034517`*^9, 3.800830424854517*^9, 
   3.800869064817461*^9, 3.800870817458251*^9, 3.8008710827478447`*^9, 
   3.800897228400003*^9, 3.800901844920809*^9, 3.800902269610023*^9, 
   3.800902728773595*^9, 3.800905243232836*^9, 3.800962125964485*^9, 
   3.800968318321126*^9, 3.801330987651218*^9, 3.8027093996207647`*^9, {
   3.802710594938265*^9, 3.802710609840609*^9}, 3.802713469825529*^9, 
   3.8027135911445103`*^9, 3.802765250330613*^9, 3.802770727997328*^9, 
   3.80277136411442*^9, 3.802774772379665*^9, 3.80311788161804*^9, 
   3.8031970071721497`*^9, 3.803302432111026*^9, 3.803302806214883*^9, 
   3.803307959274098*^9, 3.803324208220077*^9, 3.803411731595456*^9, 
   3.803412302111624*^9, 3.803474841000532*^9, 3.803729481050084*^9, 
   3.803743362418515*^9, 3.803806503063808*^9, 3.8038080500776653`*^9, 
   3.803812165298608*^9, 3.803825009132613*^9, 3.803829955658695*^9, 
   3.8038915739247*^9, 3.803978978595056*^9, 3.804270290399715*^9, 
   3.804446342960601*^9, 3.804598546629696*^9, 3.805045039081064*^9, 
   3.806937972020399*^9, 3.80709193376727*^9, 3.807092613125162*^9, 
   3.825425165608164*^9, 3.825425207738899*^9, 3.828107414852037*^9, 
   3.828716785145452*^9, 3.828717685771678*^9, 3.832075151285739*^9, 
   3.832085404910287*^9, 3.83932481962127*^9, 3.8490215981117563`*^9, 
   3.852115383348296*^9, 3.852137245814932*^9, 3.852138007457041*^9, 
   3.852143009488976*^9, 3.852293261439958*^9, 3.85229422370273*^9, 
   3.852327506716568*^9, 3.8523281931594667`*^9, 3.85236411339298*^9, 
   3.852365044196349*^9, 3.852366702544379*^9, 3.853746004140901*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"169d2849-b1c1-4da9-8f7c-f4f1c713925f"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"defv14d", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"deq14", "\[Equal]", "0"}], "}"}], "/.", "defv03"}], "/.", 
        "defv04"}], "/.", "defv01"}], ",", "v14", ",", "t"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defIC14", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"v14", "[", 
           RowBox[{"T", "-", 
            RowBox[{"\[Phi]", " ", "T"}]}], "]"}], "\[Equal]", 
          RowBox[{"v13", "[", 
           RowBox[{"T", "-", 
            RowBox[{"\[Phi]", " ", "T"}]}], "]"}]}], "}"}], "/.", "defv13"}], 
       "/.", "defv14d"}], ",", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv14a", "=", 
   RowBox[{"defv14d", "/.", "defIC14"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defv14", "=", 
   RowBox[{"v14", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", 
      RowBox[{"Evaluate", "[", 
       RowBox[{"Collect", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"v14", "[", "t", "]"}], "/.", "defv14a"}], ",", 
         RowBox[{"{", 
          RowBox[{"gc01", ",", "g0", ",", 
           RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
        "]"}], "]"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7977644055294657`*^9, 3.797764460354257*^9}, {
   3.797765345592619*^9, 3.7977653466122723`*^9}, {3.7978666539178743`*^9, 
   3.797866662831133*^9}, {3.797930251030974*^9, 3.7979302543648643`*^9}, {
   3.7979306683173647`*^9, 3.797930703856132*^9}, {3.7979326905098457`*^9, 
   3.797932722407358*^9}, {3.798845434806292*^9, 3.798845456231691*^9}, 
   3.798846120584505*^9, 3.800868204573929*^9, 3.803458068471777*^9},
 CellLabel->"In[49]:=",ExpressionUUID->"b42c13be-259c-41aa-81bf-26d2aa560f63"],

Cell[TextData[StyleBox["Threshold and Periodicity", "Section"]], "Text",
 CellChangeTimes->{{3.782758960690819*^9, 3.782758966386352*^9}, 
   3.782760752655848*^9, {3.797596277254568*^9, 3.7975962893624773`*^9}, {
   3.797596388394362*^9, 3.797596393444175*^9}, {3.797764645715692*^9, 
   3.797764650533165*^9}},ExpressionUUID->"3833bfd4-d706-4e73-866c-\
e8a298e84907"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "set", " ", "the", " ", "voltage", " ", "threshold", " ", "to", " ", "1"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.852280377423419*^9, 3.852280388161831*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"7ca10a5b-d270-4e81-89f8-3366635f9a00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thresh0", "=", 
  RowBox[{
   RowBox[{"v02", "[", "ts", "]"}], "\[Equal]", "1"}]}]], "Input",
 CellChangeTimes->{{3.7977647467930317`*^9, 3.7977647493849916`*^9}, {
  3.797764916204215*^9, 3.797764918989402*^9}, {3.8521369273310223`*^9, 
  3.852136928397903*^9}, {3.852137734067253*^9, 3.852137734946252*^9}, {
  3.852142746764007*^9, 3.852142748144844*^9}, {3.852280231287531*^9, 
  3.852280232237892*^9}, {3.852284714762261*^9, 3.8522847156178083`*^9}, {
  3.852293040457955*^9, 3.8522930409060926`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"47385cd9-161e-4f52-9690-1a66d77b054a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v02", "[", "ts", "]"}], "\[Equal]", "1"}]], "Output",
 CellChangeTimes->{
  3.797764749991046*^9, 3.797764920053083*^9, 3.797765258784773*^9, 
   3.7977653635306883`*^9, 3.797765529495152*^9, 3.797765781690077*^9, 
   3.797766125339445*^9, 3.797774308716621*^9, 3.797788590621111*^9, 
   3.797794571993099*^9, 3.797794705033375*^9, 3.797794742183486*^9, 
   3.7977948783690042`*^9, 3.797794975121561*^9, 3.7978431813781633`*^9, 
   3.797845757266367*^9, 3.797846046438321*^9, 3.797847242094926*^9, 
   3.7978490466268272`*^9, 3.797849120345655*^9, 3.797849372070306*^9, 
   3.7978496448201647`*^9, 3.797849734378399*^9, 3.797849925476594*^9, 
   3.797850016122139*^9, 3.797854705787231*^9, 3.797858826869586*^9, 
   3.797859220131864*^9, 3.7978596110815372`*^9, 3.797859752117647*^9, 
   3.797860368186075*^9, 3.797866026551268*^9, 3.797866105558052*^9, 
   3.7978665278883533`*^9, 3.797866708924986*^9, 3.7978747419582453`*^9, 
   3.79788202513583*^9, 3.797927826982069*^9, 3.797928453408668*^9, 
   3.797930846662958*^9, 3.797940024938534*^9, 3.797940583055393*^9, 
   3.797940741504106*^9, 3.797941036109535*^9, 3.7981033899810534`*^9, 
   3.798111499773685*^9, 3.798329608352124*^9, 3.798381744721223*^9, 
   3.798477311049474*^9, 3.798795128515354*^9, 3.798843515206193*^9, 
   3.798845512163445*^9, 3.798846126761806*^9, 3.799059705104093*^9, 
   3.799076973174033*^9, 3.7996828619771433`*^9, 3.80034860765371*^9, 
   3.8008146631933928`*^9, 3.8008150663394613`*^9, 3.80081631769345*^9, 
   3.800828453913834*^9, 3.8008302416386423`*^9, 3.8008304489708138`*^9, 
   3.800869078676445*^9, 3.8008708318541937`*^9, 3.80087110931824*^9, 
   3.800897243191724*^9, 3.800901921647656*^9, 3.8009022880506907`*^9, 
   3.800902764561845*^9, 3.800905278561139*^9, 3.800962161586117*^9, 
   3.8009683648738213`*^9, 3.8013310410621977`*^9, 3.802709452380583*^9, {
   3.802710597068967*^9, 3.8027106103606663`*^9}, 3.802713471441029*^9, 
   3.8027135915130444`*^9, 3.80276525068291*^9, 3.802770728352743*^9, 
   3.8027713645209208`*^9, 3.8027748218334627`*^9, 3.80311793059124*^9, 
   3.803197058182143*^9, 3.8033024830591917`*^9, 3.803302852848428*^9, 
   3.8033080027199917`*^9, 3.803324257438834*^9, 3.803411779327188*^9, 
   3.803412365233823*^9, 3.803474889017425*^9, 3.8037295423187237`*^9, 
   3.803743409412738*^9, 3.803806550065423*^9, 3.803808097875902*^9, 
   3.8038122118209887`*^9, 3.803825074887033*^9, 3.80383001770776*^9, 
   3.803891621695822*^9, 3.8039790249727993`*^9, 3.804270341447694*^9, 
   3.8044463906715603`*^9, 3.804598595817813*^9, 3.805045089323395*^9, 
   3.8069380203605423`*^9, 3.807091983845337*^9, 3.807092662260522*^9, 
   3.8254251662143517`*^9, 3.825425208259202*^9, 3.8281074154635143`*^9, 
   3.8287169068450212`*^9, 3.828717695138199*^9, 3.8320751575421*^9, 
   3.832085411210682*^9, 3.8393248262333384`*^9, 3.849021721792275*^9, 
   3.8490218752992697`*^9, 3.852115487530472*^9, 3.852136965139166*^9, 
   3.852137346192293*^9, 3.852138113001749*^9, 3.852142749138462*^9, 
   3.852143113607979*^9, {3.852284707700732*^9, 3.852284716055372*^9}, 
   3.8522932675198936`*^9, 3.852294229609955*^9, 3.852327512589505*^9, 
   3.852328199202334*^9, 3.852364119438984*^9, 3.85236515605329*^9, 
   3.85236680455888*^9, 3.853746120281435*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"4c03f43b-5ec8-43d4-abf1-10f066f09f35"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thresh0", "/.", "defv02"}]], "Input",
 CellChangeTimes->{{3.797764752272303*^9, 3.797764754222602*^9}, {
  3.797764921408593*^9, 3.797764922786233*^9}},
 CellLabel->"In[55]:=",ExpressionUUID->"2608d2c2-be49-4e96-89d9-c2c5f47a38d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"I0", "+", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "ts"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}]}], "\[Equal]", 
  "1"}]], "Output",
 CellChangeTimes->{
  3.797764755393111*^9, 3.797764923499473*^9, 3.79776525879617*^9, 
   3.797765364389646*^9, 3.797765529512619*^9, 3.797765781753825*^9, 
   3.797766125394885*^9, 3.797774308772106*^9, 3.7977885906482983`*^9, 
   3.797794572054496*^9, 3.797794705102037*^9, 3.797794742229537*^9, 
   3.797794878381434*^9, 3.797794975169591*^9, 3.797843181422112*^9, 
   3.797845757320774*^9, 3.797846046446147*^9, 3.797847242126964*^9, 
   3.797849046684391*^9, 3.797849120408695*^9, 3.797849372078953*^9, 
   3.7978496448786592`*^9, 3.797849734391222*^9, 3.797849925486567*^9, 
   3.797850016162772*^9, 3.797854705800074*^9, 3.797858826878997*^9, 
   3.797859220141946*^9, 3.797859611091207*^9, 3.797859752129471*^9, 
   3.797860368227384*^9, 3.797866026561729*^9, 3.797866106973588*^9, 
   3.7978665278991537`*^9, 3.79786670988028*^9, 3.797874742017304*^9, 
   3.7978820251469393`*^9, 3.797927826994073*^9, 3.7979284534203157`*^9, 
   3.79793084770455*^9, 3.7979400249535933`*^9, 3.797940583117277*^9, 
   3.797940741561818*^9, 3.797941036122594*^9, 3.798103389995*^9, 
   3.798111499813192*^9, 3.798329608363669*^9, 3.798381744765925*^9, 
   3.798477311059455*^9, 3.798795128534099*^9, 3.7988435152165403`*^9, 
   3.798845513155401*^9, 3.798846127812046*^9, 3.799059705122568*^9, 
   3.79907697329021*^9, 3.799682861988887*^9, 3.800348607702289*^9, 
   3.800814663202614*^9, 3.800815066353476*^9, 3.800816317705271*^9, 
   3.80082845392726*^9, 3.800830241692533*^9, 3.800830449022838*^9, 
   3.800869078741322*^9, 3.800870831917163*^9, 3.800871109486669*^9, 
   3.800897243203641*^9, 3.800901921714167*^9, 3.800902288139925*^9, 
   3.800902764571965*^9, 3.800905278572185*^9, 3.800962161670045*^9, 
   3.8009683648878727`*^9, 3.801331041072585*^9, 3.8027094526318703`*^9, {
   3.802710597080562*^9, 3.802710610420266*^9}, 3.802713471454266*^9, 
   3.80271359154467*^9, 3.8027652507181187`*^9, 3.802770728390726*^9, 
   3.8027713646029053`*^9, 3.802774821844273*^9, 3.80311793060143*^9, 
   3.80319705819174*^9, 3.803302483102799*^9, 3.803302852860031*^9, 
   3.8033080027278433`*^9, 3.803324257493429*^9, 3.8034117793413553`*^9, 
   3.803412365247533*^9, 3.80347488902808*^9, 3.803729542327774*^9, 
   3.8037434094203978`*^9, 3.8038065500744867`*^9, 3.8038080978842278`*^9, 
   3.803812211861308*^9, 3.803825074941284*^9, 3.803830017716819*^9, 
   3.803891621703706*^9, 3.803979024989352*^9, 3.804270341497102*^9, 
   3.804446390683034*^9, 3.804598595828144*^9, 3.8050450893381557`*^9, 
   3.806938020415215*^9, 3.80709198393924*^9, 3.807092662269928*^9, 
   3.825425166220653*^9, 3.825425208266551*^9, 3.828107415497617*^9, 
   3.82871690690265*^9, 3.82871769514859*^9, 3.832075157549838*^9, 
   3.832085411218186*^9, 3.839324826242387*^9, 3.849021722099139*^9, 
   3.849021876162364*^9, 3.852115487537507*^9, 3.852137346204008*^9, 
   3.852138113030527*^9, 3.85214275061506*^9, 3.852143113616243*^9, {
   3.8522847093052397`*^9, 3.852284717286207*^9}, 3.852293267529415*^9, 
   3.852294229656383*^9, 3.852327512640444*^9, 3.852328199212102*^9, 
   3.852364119489532*^9, 3.852365156064468*^9, 3.852366804627411*^9, 
   3.853746120295426*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"f8b96837-ee61-434c-a94e-de367a284378"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defV00d", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{"%", ",", "V00"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.797764761633342*^9, 3.797764772954816*^9}, 
   3.797849555692992*^9},
 CellLabel->"In[56]:=",ExpressionUUID->"da9dbef9-ff78-44f3-bd41-4cf285f57484"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"V00", "\[Rule]", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "ts"], "+", "I0", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "ts"], " ", "I0"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.797764773639819*^9, 3.797764924854727*^9, 3.7977652588673143`*^9, 
   3.7977653651174593`*^9, 3.7977655295777597`*^9, 3.797765781769884*^9, 
   3.797766125461102*^9, 3.797774308862495*^9, 3.797788590658677*^9, 
   3.797794572068717*^9, 3.7977947051118183`*^9, 3.797794742239821*^9, 
   3.7977948784220657`*^9, 3.797794975182247*^9, 3.797843181430698*^9, 
   3.7978457573290043`*^9, 3.797846046486148*^9, 3.797847242135874*^9, 
   3.797849046693571*^9, 3.797849120503126*^9, 3.7978493721133013`*^9, 
   3.797849644886982*^9, 3.797849734426154*^9, 3.797849925530386*^9, 
   3.79785001617327*^9, 3.797854705846511*^9, 3.797858826910248*^9, 
   3.7978592201796207`*^9, 3.7978596111221533`*^9, 3.7978597521644297`*^9, 
   3.797860368280616*^9, 3.7978660266294823`*^9, 3.797866107917128*^9, 
   3.797866527961008*^9, 3.797866710730467*^9, 3.797874742027713*^9, 
   3.797882025331807*^9, 3.797927827050098*^9, 3.797928453477545*^9, 
   3.7979308485555067`*^9, 3.7979400250162163`*^9, 3.797940583164102*^9, 
   3.79794074157444*^9, 3.797941036173833*^9, 3.798103390071052*^9, 
   3.798111499822784*^9, 3.798329608422089*^9, 3.7983817447750587`*^9, 
   3.798477311128393*^9, 3.798795128623708*^9, 3.798843515269301*^9, 
   3.798845514004427*^9, 3.7988461286348333`*^9, 3.799059705172739*^9, 
   3.799076973301659*^9, 3.799682862109219*^9, 3.8003486077104187`*^9, 
   3.800814663270269*^9, 3.8008150664423513`*^9, 3.800816317763884*^9, 
   3.800828454005601*^9, 3.80083024170186*^9, 3.800830449032466*^9, 
   3.800869078757732*^9, 3.800870831935272*^9, 3.800871109498054*^9, 
   3.800897243264226*^9, 3.800901921724557*^9, 3.8009022882245483`*^9, 
   3.80090276462426*^9, 3.8009052786233063`*^9, 3.800962161752927*^9, 
   3.800968364933728*^9, 3.8013310411424522`*^9, 3.802709452683876*^9, {
   3.8027105971452436`*^9, 3.802710610430477*^9}, 3.8027134715584583`*^9, 
   3.8027135915542088`*^9, 3.802765250726488*^9, 3.802770728399722*^9, 
   3.802771364711966*^9, 3.802774821889011*^9, 3.803117930651884*^9, 
   3.8031970582428713`*^9, 3.803302483419282*^9, 3.803302853115924*^9, 
   3.803308002766139*^9, 3.803324257502428*^9, 3.803411779391828*^9, 
   3.8034123653279753`*^9, 3.8034748891025352`*^9, 3.803729542382628*^9, 
   3.803743409484111*^9, 3.803806550135041*^9, 3.803808097952078*^9, 
   3.803812211869891*^9, 3.8038250752420483`*^9, 3.803830017759746*^9, 
   3.80389162174896*^9, 3.803979025057856*^9, 3.804270341651979*^9, 
   3.804446390755579*^9, 3.8045985958793*^9, 3.805045089451929*^9, 
   3.806938020811921*^9, 3.807091983947578*^9, 3.807092662362472*^9, 
   3.8254251662525873`*^9, 3.825425208309984*^9, 3.8281074155047913`*^9, 
   3.828716906914157*^9, 3.82871769520868*^9, 3.83207515760036*^9, 
   3.832085411260146*^9, 3.839324826322386*^9, 3.849021722146618*^9, 
   3.849021876874238*^9, 3.852115487579872*^9, 3.852137346242893*^9, 
   3.8521381131625853`*^9, 3.852143113664926*^9, 3.8522847188704443`*^9, 
   3.852293267573119*^9, 3.8522942296692677`*^9, 3.852327512652658*^9, 
   3.852328199248955*^9, 3.852364119499455*^9, 3.8523651561155663`*^9, 
   3.852366804644978*^9, 3.853746120399693*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"c61afa6e-1b0b-4ee5-9c60-bf687db139a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"v04", "[", "T", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"v01", "[", "0", "]"}], "+", "\[CapitalDelta]V"}]}]], "Input",
 CellChangeTimes->{{3.7976192946843843`*^9, 3.7976193227110023`*^9}, {
  3.797760295278344*^9, 3.7977602986856003`*^9}},
 CellLabel->"In[57]:=",ExpressionUUID->"aa7e92ae-3287-4f13-ae3e-1a67202078fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v04", "[", "T", "]"}], "\[Equal]", 
  RowBox[{"\[CapitalDelta]V", "+", 
   RowBox[{"v01", "[", "0", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.797619316320225*^9, 3.7976193231962433`*^9}, 
   3.797619751076*^9, 3.797619828244774*^9, 3.797619916899588*^9, {
   3.7976199561354647`*^9, 3.797619981609577*^9}, 3.797620302526075*^9, 
   3.797620363836616*^9, 3.7977602995519953`*^9, 3.797763937145811*^9, 
   3.7977639977273417`*^9, 3.797764052555129*^9, 3.7977642542399063`*^9, 
   3.797764565259781*^9, 3.7977648020884237`*^9, 3.797764840270442*^9, 
   3.797764925730719*^9, 3.79776525888655*^9, 3.797765366038221*^9, 
   3.797765529592182*^9, 3.797765781831461*^9, 3.797766125476396*^9, 
   3.797774308873925*^9, 3.797788590685676*^9, 3.797794572126441*^9, 
   3.7977947051793833`*^9, 3.797794742283886*^9, 3.7977948784341908`*^9, 
   3.7977949752455597`*^9, 3.797843181472947*^9, 3.7978457573864603`*^9, 
   3.797846046494204*^9, 3.797847242165964*^9, 3.7978490467523537`*^9, 
   3.797849120512535*^9, 3.797849372124028*^9, 3.797849644949676*^9, 
   3.797849734437222*^9, 3.797849925542156*^9, 3.7978500162291393`*^9, 
   3.797854705857851*^9, 3.7978588269215727`*^9, 3.797859220197482*^9, 
   3.797859611132135*^9, 3.797859752174911*^9, 3.7978603682908154`*^9, 
   3.797866026641019*^9, 3.797866108987821*^9, 3.797866527972032*^9, 
   3.797866711796072*^9, 3.797874742083858*^9, 3.7978820253431797`*^9, 
   3.797927827061461*^9, 3.797928453489114*^9, 3.797930849386361*^9, 
   3.797940025028611*^9, 3.79794058318388*^9, 3.797940741631668*^9, 
   3.797941036186887*^9, 3.798103390083832*^9, 3.798111499864171*^9, 
   3.798329608432136*^9, 3.7983817448211803`*^9, 3.798477311143211*^9, 
   3.798795128639676*^9, 3.79884351528159*^9, 3.798845514902711*^9, 
   3.7988461294619427`*^9, 3.799059705183902*^9, 3.799076973418885*^9, 
   3.799682862119132*^9, 3.800348607757456*^9, 3.800814663278112*^9, 
   3.8008150664588842`*^9, 3.80081631777628*^9, 3.800828454017845*^9, 
   3.800830241754785*^9, 3.8008304490839148`*^9, 3.800869078806731*^9, 
   3.800870831984799*^9, 3.8008711096581163`*^9, 3.800897243278718*^9, 
   3.800901921774716*^9, 3.800902288308041*^9, 3.800902764633071*^9, 
   3.800905278632218*^9, 3.8009621617649717`*^9, 3.8009683649422007`*^9, 
   3.801331041159725*^9, 3.802709452930633*^9, {3.8027105971547823`*^9, 
   3.802710610490451*^9}, 3.802713471571892*^9, 3.802713591588139*^9, 
   3.802765250764721*^9, 3.802770728439028*^9, 3.8027713647226477`*^9, 
   3.8027748218978367`*^9, 3.803117930663396*^9, 3.803197058250407*^9, 
   3.80330248346425*^9, 3.8033028531502123`*^9, 3.80330800277771*^9, 
   3.803324257565815*^9, 3.803411779401881*^9, 3.80341236533884*^9, 
   3.803474889110228*^9, 3.803729542392074*^9, 3.803743409491634*^9, 
   3.803806550143218*^9, 3.803808097959654*^9, 3.8038122119143953`*^9, 
   3.803825075292406*^9, 3.803830017767404*^9, 3.803891621755972*^9, 
   3.803979025068864*^9, 3.80427034170273*^9, 3.804446390763146*^9, 
   3.804598595889839*^9, 3.80504508946241*^9, 3.806938020908888*^9, 
   3.8070919840126877`*^9, 3.807092662369953*^9, 3.8254251662594843`*^9, 
   3.825425208316584*^9, 3.8281074155405693`*^9, 3.828108803258628*^9, 
   3.828716906966008*^9, 3.828717695218112*^9, 3.83207515760723*^9, 
   3.8320854112659607`*^9, 3.839324826337528*^9, 3.849021722440222*^9, 
   3.849021877643853*^9, 3.852115487586526*^9, 3.852137346251721*^9, 
   3.852138113193243*^9, 3.8521431136801558`*^9, 3.8522847207860394`*^9, 
   3.852293267582584*^9, 3.852294229709416*^9, 3.852327512703198*^9, 
   3.8523281992599154`*^9, 3.852364119550502*^9, 3.852365156128744*^9, 
   3.852366804710102*^9, 3.8537461204311323`*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"f5e1fe67-f2ea-4185-86f4-49efe5b896d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", "defv01"}], "/.", "defv04"}], "/.", 
  "defV00d"}]], "Input",
 CellChangeTimes->{{3.797619340017191*^9, 3.797619348629655*^9}, {
   3.797619928238173*^9, 3.7976199295667048`*^9}, {3.797619975685134*^9, 
   3.797619977059725*^9}, {3.797620299066341*^9, 3.797620300156334*^9}, {
   3.797620373403577*^9, 3.797620374656663*^9}, {3.7977648089511423`*^9, 
   3.7977648374316607`*^9}, 3.7978495573496037`*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"003b6122-9dcd-42e7-9783-098b78282ae7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "T"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "T"], " ", "I0"}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
   "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "T"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
       RowBox[{"I0", " ", "\[Psi]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "ts"], "+", "I0", "-", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", "ts"], " ", "I0"}]}], ")"}], " ",
         "\[Psi]"}]}], ")"}]}], "\[Psi]"]}], "\[Equal]", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "ts"], "+", "I0", "-", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "ts"], " ", "I0"}], "+", 
   "\[CapitalDelta]V"}]}]], "Output",
 CellChangeTimes->{{3.7976193327337093`*^9, 3.797619349141329*^9}, 
   3.797619751116597*^9, 3.797619828323203*^9, {3.797619919904725*^9, 
   3.797619982387278*^9}, 3.797620304063739*^9, {3.797620365347622*^9, 
   3.7976203757821703`*^9}, 3.797763937179104*^9, 3.797763997763736*^9, 
   3.797764052627763*^9, 3.797764254357168*^9, 3.7977645653372707`*^9, {
   3.7977648139675303`*^9, 3.7977648413379*^9}, 3.7977652589801683`*^9, 
   3.7977653684392223`*^9, 3.7977655296488028`*^9, 3.797765781843587*^9, 
   3.797766125522745*^9, 3.797774308928885*^9, 3.797788590695402*^9, 
   3.79779457213798*^9, 3.797794705193033*^9, 3.797794742294992*^9, 
   3.7977948784760513`*^9, 3.7977949752600403`*^9, 3.797843181529996*^9, 
   3.797845757461049*^9, 3.797846046532755*^9, 3.797847242176553*^9, 
   3.797849046761849*^9, 3.797849120582238*^9, 3.7978493721594143`*^9, 
   3.7978496449582253`*^9, 3.797849734475451*^9, 3.7978499256017227`*^9, 
   3.797850016246427*^9, 3.7978547059057827`*^9, 3.797858826953478*^9, 
   3.797859220236499*^9, 3.797859611161903*^9, 3.797859752210393*^9, 
   3.797860368326631*^9, 3.7978660267120247`*^9, 3.797866110396291*^9, 
   3.797866528033104*^9, 3.7978667127655582`*^9, 3.7978747421021767`*^9, 
   3.79788202551422*^9, 3.797927827121489*^9, 3.797928453548012*^9, 
   3.797930850396551*^9, 3.797940025089341*^9, 3.797940583232545*^9, 
   3.797940741703079*^9, 3.797941036239005*^9, 3.798103390148426*^9, 
   3.7981114998739223`*^9, 3.798329608493546*^9, 3.798381744829726*^9, 
   3.798477311231943*^9, 3.7987951286995153`*^9, 3.7988435153308277`*^9, 
   3.798845515666691*^9, 3.798846130257062*^9, 3.799059705236994*^9, 
   3.799076973432393*^9, 3.799682862235551*^9, 3.800348607765489*^9, 
   3.8008146633484163`*^9, 3.800815066538865*^9, 3.800816317840467*^9, 
   3.80082845409313*^9, 3.800830241764757*^9, 3.8008304490955763`*^9, 
   3.80086907881663*^9, 3.800870831994706*^9, 3.8008711096676598`*^9, 
   3.800897243332787*^9, 3.800901921783784*^9, 3.800902288391171*^9, 
   3.800902764677058*^9, 3.8009052786842403`*^9, 3.800962161841655*^9, 
   3.800968364991346*^9, 3.801331041221813*^9, 3.802709452983876*^9, {
   3.8027105972124157`*^9, 3.802710610501103*^9}, 3.802713471669718*^9, 
   3.802713591596471*^9, 3.802765250774549*^9, 3.802770728449102*^9, 
   3.802771364808269*^9, 3.802774821934567*^9, 3.803117930699168*^9, 
   3.803197058298237*^9, 3.8033024838066063`*^9, 3.803302853352333*^9, 
   3.803308002815336*^9, 3.8033242575779543`*^9, 3.8034117794372396`*^9, 
   3.80341236540283*^9, 3.803474889185163*^9, 3.803729542444642*^9, 
   3.803743409538146*^9, 3.8038065502298937`*^9, 3.803808098027969*^9, 
   3.803812211925004*^9, 3.803825075546309*^9, 3.803830017811902*^9, 
   3.8038916217639923`*^9, 3.803979025138894*^9, 3.804270341947472*^9, 
   3.8044463908326893`*^9, 3.804598595942195*^9, 3.8050450895298843`*^9, 
   3.8069380213179092`*^9, 3.807091984021804*^9, 3.807092662461637*^9, 
   3.825425166291092*^9, 3.825425208358398*^9, 3.8281074155485077`*^9, 
   3.8281088053169603`*^9, 3.828716906978527*^9, 3.828717695274634*^9, 
   3.832075157657073*^9, 3.832085411306304*^9, 3.839324826397511*^9, 
   3.849021722490671*^9, 3.849021878364337*^9, 3.852115487593141*^9, 
   3.852137346289239*^9, 3.852138113336323*^9, 3.852143113725815*^9, 
   3.8522847225682364`*^9, 3.8522932676253777`*^9, 3.852294229721283*^9, 
   3.852327512714519*^9, 3.85232819929732*^9, 3.852364119560564*^9, 
   3.852365156178277*^9, 3.852366804729672*^9, 3.8537461206545*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"49478ab7-4fa2-4c50-b423-b2a030386cf4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defI0", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", "I0"}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.797619932170478*^9, 3.797619952112978*^9}, {
  3.797620399650991*^9, 3.7976204058670387`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"28d31074-4f4a-4e2d-9208-308b71fd10c2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"I0", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "ts"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"T", " ", "\[Psi]"}]]}], " ", "va"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", " ", "\[Psi]"}]], " ", "va"}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "ts"], " ", "\[Psi]"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", "+", "ts"}]], " ", "\[Psi]"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "T"], " ", "\[CapitalDelta]V", " ", 
        "\[Psi]"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", "\[Psi]"}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.797619946843274*^9, 3.7976199833139*^9}, 
   3.797620305732596*^9, 3.797620406246867*^9, 3.797763937320395*^9, 
   3.797763997828446*^9, 3.7977640527656403`*^9, 3.7977642544714613`*^9, 
   3.797764565548463*^9, {3.7977648219459*^9, 3.7977648423051157`*^9}, 
   3.797765259073209*^9, 3.797765370427452*^9, 3.7977655297210903`*^9, 
   3.797765781926063*^9, 3.797766125585741*^9, 3.7977743089887133`*^9, 
   3.797788590725398*^9, 3.797794572196025*^9, 3.797794705260223*^9, 
   3.7977947423874187`*^9, 3.797794878527413*^9, 3.797794975326729*^9, 
   3.7978431815761423`*^9, 3.797845757519848*^9, 3.797846046573029*^9, 
   3.797847242227996*^9, 3.797849046823722*^9, 3.797849120648547*^9, 
   3.797849372203017*^9, 3.797849645022171*^9, 3.797849734528311*^9, 
   3.797849925661621*^9, 3.7978500165429487`*^9, 3.7978547059577837`*^9, 
   3.797858826992199*^9, 3.797859220276153*^9, 3.7978596111958103`*^9, 
   3.7978597522494926`*^9, 3.797860368362665*^9, 3.79786602678865*^9, 
   3.797866115002933*^9, 3.797866528099298*^9, 3.797866714374473*^9, 
   3.797874742177759*^9, 3.797882025702421*^9, 3.7979278271822643`*^9, 
   3.7979284536301928`*^9, 3.797930851374707*^9, 3.797940025156151*^9, 
   3.7979405832828293`*^9, 3.797940741788682*^9, 3.79794103629389*^9, 
   3.798103390212494*^9, 3.798111499914997*^9, 3.7983296086669893`*^9, 
   3.798381744876749*^9, 3.798477311324748*^9, 3.798795128764371*^9, 
   3.798843515401668*^9, 3.7988455164412518`*^9, 3.79884613155305*^9, 
   3.799059705293132*^9, 3.799076973543638*^9, 3.799682862356518*^9, 
   3.800348607815175*^9, 3.800814663418255*^9, 3.800815066628901*^9, 
   3.800816317905733*^9, 3.800828454168644*^9, 3.800830241817247*^9, 
   3.800830449151113*^9, 3.800869078868474*^9, 3.800870832042882*^9, 
   3.8008711098242083`*^9, 3.800897243386652*^9, 3.8009019218322287`*^9, 
   3.8009022885135517`*^9, 3.80090276472302*^9, 3.8009052787362127`*^9, 
   3.800962161924732*^9, 3.8009683650479527`*^9, 3.801331041293152*^9, 
   3.802709453187543*^9, {3.802710597279385*^9, 3.802710610558372*^9}, 
   3.8027134717646303`*^9, 3.802713591630804*^9, 3.802765250812057*^9, 
   3.8027707284875*^9, 3.802771364893791*^9, 3.8027748219746437`*^9, 
   3.803117930737406*^9, 3.803197058346642*^9, 3.803302484150877*^9, 
   3.8033028535978737`*^9, 3.803308002858663*^9, 3.803324257633123*^9, 
   3.803411779478141*^9, 3.8034123654698477`*^9, 3.803474889255117*^9, 
   3.803729542493722*^9, 3.803743409576385*^9, 3.803806550277565*^9, 
   3.8038080981*^9, 3.803812211958438*^9, 3.803825075843134*^9, 
   3.8038300178446417`*^9, 3.803891621815329*^9, 3.803979025200699*^9, 
   3.804270342106763*^9, 3.804446390906068*^9, 3.804598595977138*^9, 
   3.805045089603804*^9, 3.806938021669071*^9, 3.807091984091249*^9, 
   3.807092662536612*^9, 3.825425166333556*^9, 3.825425208405645*^9, 
   3.828107415586441*^9, 3.828108806970537*^9, 3.828716907039584*^9, 
   3.828717695337335*^9, 3.832075157708632*^9, 3.832085411345892*^9, 
   3.839324826454018*^9, 3.849021722749505*^9, 3.849021879094583*^9, 
   3.852115487631651*^9, 3.852137346328306*^9, 3.852138113403595*^9, 
   3.8521431137747927`*^9, 3.8522847237087803`*^9, 3.852293267668324*^9, 
   3.852294229761046*^9, 3.852327512773582*^9, 3.852328199335741*^9, 
   3.852364119611857*^9, 3.8523651562282763`*^9, 3.852366804787671*^9, 
   3.8537461207423964`*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"4382f131-76de-4bcd-84bc-852ebbd23687"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Collect", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"va", ",", "\[CapitalDelta]V"}], "}"}], ",", "Simplify"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.828108087050366*^9, 3.828108095781468*^9}, {
  3.82810882654589*^9, 3.828108830211568*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"42777a7e-1e61-4635-b770-c8df2eaea8d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"I0", "\[Rule]", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"T", "-", "ts"}]], " ", "\[CapitalDelta]V"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", "T"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "ts"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"T", " ", "\[Psi]"}]]}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", " ", "\[Psi]"}]]}], ")"}], " ", "va"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", "\[Psi]"}]]}]}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.8281080963843718`*^9, {3.828108809421515*^9, 3.828108831439588*^9}, 
   3.828716907097495*^9, 3.828717695399218*^9, 3.8320751577575417`*^9, 
   3.832085411386201*^9, 3.839324826513482*^9, 3.849021723239162*^9, 
   3.849021879715527*^9, 3.852115487669693*^9, 3.852137346365281*^9, 
   3.8521381134292994`*^9, 3.852143113788331*^9, 3.852284724710177*^9, 
   3.8522932677088346`*^9, 3.85229422980056*^9, 3.852327512822445*^9, 
   3.852328199374833*^9, 3.852364119663892*^9, 3.8523651562964497`*^9, 
   3.852366804839525*^9, 3.853746120844496*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"6af764f1-1a5c-470d-965a-5411cb3cc86d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"defV00d", "/.", "defI0"}], "]"}]], "Input",
 CellChangeTimes->{{3.8254302536441927`*^9, 3.8254302628188562`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"91cd6d3e-a035-4c92-a28f-3e8bfd1a8d78"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"V00", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "ts"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"T", " ", "\[Psi]"}]]}], " ", "va"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", " ", "\[Psi]"}]], " ", "va"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", "+", 
          RowBox[{"T", " ", "\[Psi]"}]}]], " ", "va"}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", "+", 
          RowBox[{"ts", " ", "\[Psi]"}]}]], " ", "va"}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "ts"], " ", "\[Psi]"}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", "+", "ts"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[CapitalDelta]V"}], ")"}], " ", 
        "\[Psi]"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "T"], " ", "\[CapitalDelta]V", " ", 
        "\[Psi]"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", "\[Psi]"}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8254302636615343`*^9, 3.828107415624783*^9, 
  3.8281085904883547`*^9, 3.828108741897348*^9, 3.828716907154997*^9, 
  3.828717695462669*^9, 3.832075157805182*^9, 3.832076102580545*^9, 
  3.832076210750142*^9, 3.8320762556418056`*^9, 3.832085372752461*^9, 
  3.832085411428534*^9, 3.832085445757948*^9, 3.839324826587099*^9, 
  3.849021723287046*^9, 3.849021880499687*^9, 3.8521154877100153`*^9, 
  3.852137346405219*^9, 3.8521381134859123`*^9, 3.8521431138332567`*^9, 
  3.8522847261044607`*^9, 3.85229326775364*^9, 3.852294229841709*^9, 
  3.85232751287156*^9, 3.8523281994142933`*^9, 3.852364119719018*^9, 
  3.852365156367721*^9, 3.852366804892235*^9, 3.8537461210501213`*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"20501c8b-af81-4012-aa73-3cb96084f780"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"va", ",", "\[CapitalDelta]V"}], "}"}], ",", "Simplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.828108587026662*^9, 3.828108635748939*^9}, {
  3.828108738152701*^9, 3.828108746989098*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"aa5b9fc9-3db1-45c7-b21f-600f4b8fb097"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"V00", "\[Rule]", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "T"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "ts"}]]}], ")"}], " ", "\[CapitalDelta]V"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", "T"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "ts"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", "ts"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", "\[Psi]"}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", " ", "\[Psi]"}]]}], ")"}], " ", "va"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", "\[Psi]"}]]}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.832076104535304*^9, 3.832076211617773*^9, 
  3.8320762568379183`*^9, 3.832085411459429*^9, 3.8320854477126303`*^9, 
  3.839324826656804*^9, 3.849021723540341*^9, 3.849021881238059*^9, 
  3.85211548774675*^9, 3.852137346446608*^9, 3.852138113543542*^9, 
  3.8521431138784924`*^9, 3.852284727573929*^9, 3.852293267798736*^9, 
  3.852294229880556*^9, 3.852327512919457*^9, 3.8523281994538097`*^9, 
  3.852364119768454*^9, 3.8523651564344273`*^9, 3.8523668049427433`*^9, 
  3.853746122024728*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"4ad8428c-8c64-4a70-ae09-1f6b776f3541"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defv00", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"\[Psi]", "\[Rule]", 
       RowBox[{"xi", "+", "1"}]}]}], "/.", 
     RowBox[{"ts", "\[Rule]", 
      RowBox[{"T", "-", "\[CapitalDelta]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"va", ",", "\[CapitalDelta]V"}], "}"}], ",", "FullSimplify"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.832076038186995*^9, 3.832076095646453*^9}, {
  3.832076214600197*^9, 3.832076248606759*^9}, {3.832085436829721*^9, 
  3.832085530121698*^9}, {3.8320855786581383`*^9, 3.832085587221822*^9}, {
  3.849021886086405*^9, 3.8490218877217503`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"2fcfb9d3-d71f-4eff-a759-800035f4d8e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"V00", "\[Rule]", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "T"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "xi"}], ")"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "xi"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"T", "-", "\[CapitalDelta]"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "T"], "-", 
        SuperscriptBox["\[ExponentialE]", "\[CapitalDelta]"]}], ")"}], " ", 
      "va"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "xi"}], ")"}]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", "T"]}], "+", 
        SuperscriptBox["\[ExponentialE]", "\[CapitalDelta]"]}], ")"}], " ", 
      "\[CapitalDelta]V"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", "T"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.83207609819179*^9, 3.8320761154230003`*^9}, {
   3.832076250772793*^9, 3.832076258331215*^9}, 3.832085369295759*^9, 
   3.832085411500482*^9, 3.832085449319109*^9, 3.832085533662898*^9, {
   3.832085580216794*^9, 3.832085587862822*^9}, 3.839324827028277*^9, 
   3.849021724040173*^9, {3.849021882113977*^9, 3.84902188901936*^9}, 
   3.852115488049922*^9, 3.8521373467643213`*^9, 3.852138113879965*^9, 
   3.852143114180826*^9, 3.852284729743814*^9, 3.852293267844961*^9, 
   3.852294230189065*^9, 3.8523275132491493`*^9, 3.852328199731607*^9, 
   3.852364120056077*^9, 3.85236515680832*^9, 3.85236680526539*^9, 
   3.853746122389751*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"3293ebb2-4f47-4dd5-8c0e-6f5cfc357b4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"v04", "[", "t", "]"}], "/.", "defv04"}], "/.", 
    RowBox[{"\[Psi]", "\[Rule]", 
     RowBox[{"xi", "+", "1"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"va", ",", "I0"}], "}"}], ",", "Simplify"}], "]"}]], "Input",
 CellLabel->"In[64]:=",ExpressionUUID->"c02698be-b555-4742-9805-e947541c8515"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], ")"}], " ", "I0"}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "t"}]], " ", "V00"}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "xi"}], ")"}]}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"ts", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "xi"}], ")"}]}]]}], ")"}], " ", "va"}], 
   RowBox[{"1", "+", "xi"}]]}]], "Output",
 CellChangeTimes->{3.8490218608149767`*^9, 3.849021892888101*^9, 
  3.849022250747758*^9, 3.852115488088657*^9, 3.85211555181644*^9, 
  3.852137346803177*^9, 3.852138114003645*^9, 3.852143114225337*^9, 
  3.8522847308254623`*^9, 3.852293267891653*^9, 3.852294230199527*^9, 
  3.852327513262371*^9, 3.852328199777234*^9, 3.852364120112876*^9, 
  3.8523651568649*^9, 3.852366805324212*^9, 3.853746122499206*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"f299228b-80d9-49b0-9786-856c682536cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "v04", "  ", "agrees", " ", "with", " ", "referee", " ", "result", " ", 
    "once", " ", "va", " ", "is", " ", "rescaled", " ", "by", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "xi"}], " ", "ts"}], "]"}]}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v04", "[", "t", "]"}], "/.", "defv04"}], "/.", 
        RowBox[{"\[Psi]", "\[Rule]", 
         RowBox[{"xi", "+", "1"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"va", ",", "I0"}], "}"}], ",", "Simplify"}], "]"}], "/.", 
     RowBox[{"va", "->", 
      RowBox[{"va", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "xi"}], " ", "ts"}], "]"}]}]}]}], "/.", 
    RowBox[{"I0", "->", "0"}]}], "/.", 
   RowBox[{"V00", "->", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.852115611936862*^9, 3.8521156261858387`*^9}, {
  3.852115684287689*^9, 3.852115692123269*^9}, {3.852284740750012*^9, 
  3.852284741876974*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"349635be-57a6-4535-9f8d-c820512f4007"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "t"}], "-", 
     RowBox[{"ts", " ", "xi"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]], "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"ts", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]]}], ")"}], " ", "va"}], 
  RowBox[{"1", "+", "xi"}]]], "Output",
 CellChangeTimes->{
  3.8521156433539333`*^9, 3.8521156927312803`*^9, 3.8521373468686647`*^9, 
   3.852138114093389*^9, 3.85214311427717*^9, {3.8522847338581448`*^9, 
   3.852284747810791*^9}, 3.852293267902096*^9, 3.852294230238097*^9, 
   3.852327513313651*^9, 3.852328199814817*^9, 3.852364120162339*^9, 
   3.852365156964879*^9, 3.8523668053925953`*^9, 3.8537461226077147`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"bf7cf17e-ce78-4507-ae6f-01466826629b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.8521156976675377`*^9, 3.852115699352293*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"3f7b239e-9bbe-45ae-9150-6a2fa67244dd"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "t"}], "-", 
      RowBox[{"ts", " ", "xi"}], "+", 
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]}]], " ", "va"}], 
   RowBox[{"1", "+", "xi"}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "t"}], "-", 
      RowBox[{"ts", " ", "xi"}], "+", 
      RowBox[{"ts", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]}]], " ", "va"}], 
   RowBox[{"1", "+", "xi"}]]}]], "Output",
 CellChangeTimes->{3.852115700262198*^9, 3.852137346915226*^9, 
  3.852138114101845*^9, 3.8521431143290243`*^9, 3.852284749068152*^9, 
  3.852293267947825*^9, 3.852294230249213*^9, 3.852327513326993*^9, 
  3.852328199828459*^9, 3.852364120172893*^9, 3.85236515697773*^9, 
  3.852366805416319*^9, 3.853746122644669*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"1ffae74c-1901-4de3-bb63-d10dfac1a906"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.852115647605218*^9, 3.852115649819269*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"1499267e-4996-4dca-8062-d46aa5a4e45f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "t"}], "-", 
     RowBox[{"ts", " ", "xi"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]], "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"ts", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]]}], ")"}], " ", "va"}], 
  RowBox[{"1", "+", "xi"}]]], "Output",
 CellChangeTimes->{3.852115650350355*^9, 3.85211574207211*^9, 
  3.8521373469573793`*^9, 3.852138114163321*^9, 3.852143114374805*^9, 
  3.852284750039277*^9, 3.852293267996159*^9, 3.852294230289576*^9, 
  3.8523275133798103`*^9, 3.852328199866894*^9, 3.852364120225095*^9, 
  3.852365157028262*^9, 3.852366805494581*^9, 3.853746122735057*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"c01b20d9-4c37-4945-8375-445c5ff85e6a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Testing", " ", "V00"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"defv00", "/.", 
         RowBox[{"va", "->", 
          RowBox[{"va", " ", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "xi"}], " ", "ts"}], "]"}]}]}]}], "/.", 
        RowBox[{"\[CapitalDelta]V", "->", "0"}]}], "/.", 
       RowBox[{"vth", "->", "0"}]}], "/.", 
      RowBox[{"ts", "->", 
       RowBox[{"T", "-", "\[CapitalDelta]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"va", ",", "I0"}], "}"}], ",", "Expand"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.852284581940515*^9, 3.852284588658305*^9}, {
  3.8522847529831963`*^9, 3.8522848408255*^9}, {3.852284878505666*^9, 
  3.852284926539897*^9}, {3.85228496793959*^9, 3.852284985508358*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"c7a2c5a5-48d4-433b-9f85-6a602c20670e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"V00", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"1", "-", "va", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"T", "-", "\[CapitalDelta]"}]], " ", "va"}], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"T", "+", 
         RowBox[{"xi", " ", "\[CapitalDelta]"}]}]], " ", "va"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[CapitalDelta]", "+", 
         RowBox[{"xi", " ", "\[CapitalDelta]"}]}]], " ", "va"}], "+", "xi", 
      "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "T"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "xi"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8522848019280577`*^9, 3.852284841693297*^9}, {
   3.852284901482647*^9, 3.852284908187554*^9}, 3.8522849429572573`*^9, {
   3.8522849742854013`*^9, 3.852284986163745*^9}, 3.852293268188517*^9, 
   3.8522942304919558`*^9, 3.852327513579369*^9, 3.852328200059564*^9, 
   3.85236412043722*^9, 3.852365157254599*^9, 3.852366805805122*^9, 
   3.853746122977035*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"cfd2f44b-d0c1-44f7-be9c-d4d0498eb64b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerExpand", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.8522853412303467`*^9, 3.852285343854127*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"2e88868d-87d9-4057-9959-26d246d5e5d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"V00", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"1", "-", "va", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"T", "-", "\[CapitalDelta]"}]], " ", "va"}], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"T", "+", 
         RowBox[{"xi", " ", "\[CapitalDelta]"}]}]], " ", "va"}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[CapitalDelta]", "+", 
         RowBox[{"xi", " ", "\[CapitalDelta]"}]}]], " ", "va"}], "+", "xi", 
      "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "T"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "xi"}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "xi"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.852285344341875*^9, 3.852293268198224*^9, 
  3.852294230503048*^9, 3.852327513676714*^9, 3.852328200069186*^9, 
  3.852364120503725*^9, 3.852365157267568*^9, 3.8523668059016*^9, 
  3.85374612298997*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"8d60960d-27ef-4e31-ad6f-8345264aa545"]
}, Open  ]],

Cell["Test O(1) periodicity and threshold condition", "Text",
 CellChangeTimes->{{3.797794843412053*^9, 3.797794850920965*^9}, {
  3.798845517438517*^9, 
  3.798845518229889*^9}},ExpressionUUID->"45e62339-fa1a-4989-aea3-\
36bdddd2b500"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"v01", "[", "0", "]"}], "}"}], "/.", "defv01"}], "/.", "defI0"}],
   "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"v02", "[", 
           RowBox[{"ts", "-", "\[Phi]"}], "]"}], "-", 
          RowBox[{"v01", "[", 
           RowBox[{"ts", "-", "\[Phi]"}], "]"}]}], ",", 
         RowBox[{"v02", "[", "ts", "]"}]}], "}"}], "/.", "defv02"}], "/.", 
      "defv01"}], "/.", "defI0"}], "/.", "defV00d"}], "/.", "defI0"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"v03", "[", "ts", "]"}], ",", 
         RowBox[{
          RowBox[{"v04", "[", 
           RowBox[{"T", "-", "\[Phi]"}], "]"}], "-", 
          RowBox[{"v03", "[", 
           RowBox[{"T", "-", "\[Phi]"}], "]"}]}]}], "}"}], "/.", "defv03"}], "/.",
       "defv04"}], "/.", "defI0"}], "/.", "defV00d"}], "/.", "defI0"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"v04", "[", "T", "]"}], "-", 
         RowBox[{"v01", "[", "0", "]"}]}], "}"}], "/.", "defv01"}], "/.", 
      "defv04"}], "/.", "defI0"}], "/.", "defV00d"}], "/.", "defI0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.797849656666389*^9, 3.797849679024588*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"66e4a244-31b3-4d77-a9d5-ca0fdf43a22a"],

Cell[BoxData[
 RowBox[{"{", "V00", "}"}]], "Output",
 CellChangeTimes->{
  3.797794837517726*^9, 3.797794878540906*^9, 3.7977949753388042`*^9, 
   3.797843181586781*^9, 3.7978457575300617`*^9, 3.797846046581986*^9, 
   3.7978472422389708`*^9, 3.797849046833168*^9, 3.7978491206593027`*^9, 
   3.797849372212488*^9, 3.7978496450325117`*^9, 3.79784973453915*^9, 
   3.797849925671357*^9, 3.797850016627439*^9, 3.7978547059703283`*^9, 
   3.7978588270031557`*^9, 3.797859220287758*^9, 3.797859611206963*^9, 
   3.797859752262224*^9, 3.797860368375313*^9, 3.797866026800881*^9, 
   3.7978661175422173`*^9, 3.797866528110791*^9, 3.7978667166501713`*^9, 
   3.797874742189724*^9, 3.797882025719192*^9, 3.797927827194875*^9, 
   3.797928453643701*^9, 3.797930854151939*^9, 3.797940025172134*^9, 
   3.79794058329537*^9, 3.797940741804047*^9, 3.797941036307078*^9, 
   3.798103390223675*^9, 3.798111499924591*^9, 3.798329608677096*^9, 
   3.798381744885779*^9, 3.798477311342938*^9, 3.79879512878036*^9, 
   3.7988435154162817`*^9, 3.7988455193433*^9, 3.798846133546674*^9, 
   3.799059705305238*^9, 3.799076973555483*^9, 3.7996828623698673`*^9, 
   3.800348607824232*^9, 3.8008146634286118`*^9, 3.800815066645371*^9, 
   3.800816317920495*^9, 3.800828454186762*^9, 3.8008302418265142`*^9, 
   3.80083044916322*^9, 3.8008690788785887`*^9, 3.8008708320526857`*^9, 
   3.8008711098336143`*^9, 3.8008972433970957`*^9, 3.800901921841721*^9, 
   3.800902290105791*^9, 3.800902764733239*^9, 3.8009052787455473`*^9, 
   3.800962161936699*^9, 3.800968365056953*^9, 3.801331041310113*^9, 
   3.802709453475153*^9, {3.802710597289678*^9, 3.802710610570092*^9}, 
   3.802713471780232*^9, 3.80271359164113*^9, 3.8027652508215647`*^9, 
   3.8027707284979258`*^9, 3.802771364905778*^9, 3.802774821986011*^9, 
   3.803117930748061*^9, 3.8031970583545713`*^9, 3.8033024841681557`*^9, 
   3.8033028536137333`*^9, 3.803308002870303*^9, 3.803324257644526*^9, 
   3.8034117794879293`*^9, 3.803412365481933*^9, 3.803474889261938*^9, 
   3.8037295425039186`*^9, 3.8037434095835743`*^9, 3.803806550289288*^9, 
   3.803808098107128*^9, 3.803812211969233*^9, 3.8038250761004133`*^9, 
   3.803830017853039*^9, 3.803891621823246*^9, 3.803979025216833*^9, 
   3.8042703421540327`*^9, 3.8044463909139357`*^9, 3.804598595987011*^9, 
   3.805045089612464*^9, 3.806938021760674*^9, 3.807091984104177*^9, 
   3.807092662545455*^9, 3.8254251663439407`*^9, 3.825425208413251*^9, 
   3.828107415635387*^9, 3.828716907233541*^9, 3.82871769553471*^9, 
   3.832075157865687*^9, 3.832085411506546*^9, 3.8393248270378942`*^9, 
   3.849021724685981*^9, 3.852115488233289*^9, 3.852137346968652*^9, 
   3.852138114188367*^9, 3.852143114385998*^9, 3.8522932682420387`*^9, 
   3.852294230540044*^9, 3.852327513689432*^9, 3.8523282001177797`*^9, 
   3.852364120568718*^9, 3.8523651573308697`*^9, 3.8523668059606113`*^9, 
   3.8537461231062813`*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"e9f9f753-5fbf-474c-827c-2b0a4ff5171f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{
  3.797794837517726*^9, 3.797794878540906*^9, 3.7977949753388042`*^9, 
   3.797843181586781*^9, 3.7978457575300617`*^9, 3.797846046581986*^9, 
   3.7978472422389708`*^9, 3.797849046833168*^9, 3.7978491206593027`*^9, 
   3.797849372212488*^9, 3.7978496450325117`*^9, 3.79784973453915*^9, 
   3.797849925671357*^9, 3.797850016627439*^9, 3.7978547059703283`*^9, 
   3.7978588270031557`*^9, 3.797859220287758*^9, 3.797859611206963*^9, 
   3.797859752262224*^9, 3.797860368375313*^9, 3.797866026800881*^9, 
   3.7978661175422173`*^9, 3.797866528110791*^9, 3.7978667166501713`*^9, 
   3.797874742189724*^9, 3.797882025719192*^9, 3.797927827194875*^9, 
   3.797928453643701*^9, 3.797930854151939*^9, 3.797940025172134*^9, 
   3.79794058329537*^9, 3.797940741804047*^9, 3.797941036307078*^9, 
   3.798103390223675*^9, 3.798111499924591*^9, 3.798329608677096*^9, 
   3.798381744885779*^9, 3.798477311342938*^9, 3.79879512878036*^9, 
   3.7988435154162817`*^9, 3.7988455193433*^9, 3.798846133546674*^9, 
   3.799059705305238*^9, 3.799076973555483*^9, 3.7996828623698673`*^9, 
   3.800348607824232*^9, 3.8008146634286118`*^9, 3.800815066645371*^9, 
   3.800816317920495*^9, 3.800828454186762*^9, 3.8008302418265142`*^9, 
   3.80083044916322*^9, 3.8008690788785887`*^9, 3.8008708320526857`*^9, 
   3.8008711098336143`*^9, 3.8008972433970957`*^9, 3.800901921841721*^9, 
   3.800902290105791*^9, 3.800902764733239*^9, 3.8009052787455473`*^9, 
   3.800962161936699*^9, 3.800968365056953*^9, 3.801331041310113*^9, 
   3.802709453475153*^9, {3.802710597289678*^9, 3.802710610570092*^9}, 
   3.802713471780232*^9, 3.80271359164113*^9, 3.8027652508215647`*^9, 
   3.8027707284979258`*^9, 3.802771364905778*^9, 3.802774821986011*^9, 
   3.803117930748061*^9, 3.8031970583545713`*^9, 3.8033024841681557`*^9, 
   3.8033028536137333`*^9, 3.803308002870303*^9, 3.803324257644526*^9, 
   3.8034117794879293`*^9, 3.803412365481933*^9, 3.803474889261938*^9, 
   3.8037295425039186`*^9, 3.8037434095835743`*^9, 3.803806550289288*^9, 
   3.803808098107128*^9, 3.803812211969233*^9, 3.8038250761004133`*^9, 
   3.803830017853039*^9, 3.803891621823246*^9, 3.803979025216833*^9, 
   3.8042703421540327`*^9, 3.8044463909139357`*^9, 3.804598595987011*^9, 
   3.805045089612464*^9, 3.806938021760674*^9, 3.807091984104177*^9, 
   3.807092662545455*^9, 3.8254251663439407`*^9, 3.825425208413251*^9, 
   3.828107415635387*^9, 3.828716907233541*^9, 3.82871769553471*^9, 
   3.832075157865687*^9, 3.832085411506546*^9, 3.8393248270378942`*^9, 
   3.849021724685981*^9, 3.852115488233289*^9, 3.852137346968652*^9, 
   3.852138114188367*^9, 3.852143114385998*^9, 3.8522932682420387`*^9, 
   3.852294230540044*^9, 3.852327513689432*^9, 3.8523282001177797`*^9, 
   3.852364120568718*^9, 3.8523651573308697`*^9, 3.8523668059606113`*^9, 
   3.8537461231093893`*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"70aac965-f01b-4b74-aec6-d00806c9e9f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.797794837517726*^9, 3.797794878540906*^9, 3.7977949753388042`*^9, 
   3.797843181586781*^9, 3.7978457575300617`*^9, 3.797846046581986*^9, 
   3.7978472422389708`*^9, 3.797849046833168*^9, 3.7978491206593027`*^9, 
   3.797849372212488*^9, 3.7978496450325117`*^9, 3.79784973453915*^9, 
   3.797849925671357*^9, 3.797850016627439*^9, 3.7978547059703283`*^9, 
   3.7978588270031557`*^9, 3.797859220287758*^9, 3.797859611206963*^9, 
   3.797859752262224*^9, 3.797860368375313*^9, 3.797866026800881*^9, 
   3.7978661175422173`*^9, 3.797866528110791*^9, 3.7978667166501713`*^9, 
   3.797874742189724*^9, 3.797882025719192*^9, 3.797927827194875*^9, 
   3.797928453643701*^9, 3.797930854151939*^9, 3.797940025172134*^9, 
   3.79794058329537*^9, 3.797940741804047*^9, 3.797941036307078*^9, 
   3.798103390223675*^9, 3.798111499924591*^9, 3.798329608677096*^9, 
   3.798381744885779*^9, 3.798477311342938*^9, 3.79879512878036*^9, 
   3.7988435154162817`*^9, 3.7988455193433*^9, 3.798846133546674*^9, 
   3.799059705305238*^9, 3.799076973555483*^9, 3.7996828623698673`*^9, 
   3.800348607824232*^9, 3.8008146634286118`*^9, 3.800815066645371*^9, 
   3.800816317920495*^9, 3.800828454186762*^9, 3.8008302418265142`*^9, 
   3.80083044916322*^9, 3.8008690788785887`*^9, 3.8008708320526857`*^9, 
   3.8008711098336143`*^9, 3.8008972433970957`*^9, 3.800901921841721*^9, 
   3.800902290105791*^9, 3.800902764733239*^9, 3.8009052787455473`*^9, 
   3.800962161936699*^9, 3.800968365056953*^9, 3.801331041310113*^9, 
   3.802709453475153*^9, {3.802710597289678*^9, 3.802710610570092*^9}, 
   3.802713471780232*^9, 3.80271359164113*^9, 3.8027652508215647`*^9, 
   3.8027707284979258`*^9, 3.802771364905778*^9, 3.802774821986011*^9, 
   3.803117930748061*^9, 3.8031970583545713`*^9, 3.8033024841681557`*^9, 
   3.8033028536137333`*^9, 3.803308002870303*^9, 3.803324257644526*^9, 
   3.8034117794879293`*^9, 3.803412365481933*^9, 3.803474889261938*^9, 
   3.8037295425039186`*^9, 3.8037434095835743`*^9, 3.803806550289288*^9, 
   3.803808098107128*^9, 3.803812211969233*^9, 3.8038250761004133`*^9, 
   3.803830017853039*^9, 3.803891621823246*^9, 3.803979025216833*^9, 
   3.8042703421540327`*^9, 3.8044463909139357`*^9, 3.804598595987011*^9, 
   3.805045089612464*^9, 3.806938021760674*^9, 3.807091984104177*^9, 
   3.807092662545455*^9, 3.8254251663439407`*^9, 3.825425208413251*^9, 
   3.828107415635387*^9, 3.828716907233541*^9, 3.82871769553471*^9, 
   3.832075157865687*^9, 3.832085411506546*^9, 3.8393248270378942`*^9, 
   3.849021724685981*^9, 3.852115488233289*^9, 3.852137346968652*^9, 
   3.852138114188367*^9, 3.852143114385998*^9, 3.8522932682420387`*^9, 
   3.852294230540044*^9, 3.852327513689432*^9, 3.8523282001177797`*^9, 
   3.852364120568718*^9, 3.8523651573308697`*^9, 3.8523668059606113`*^9, 
   3.853746123128439*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"f268474d-7c25-4145-b607-004f67beb788"],

Cell[BoxData[
 RowBox[{"{", "\[CapitalDelta]V", "}"}]], "Output",
 CellChangeTimes->{
  3.797794837517726*^9, 3.797794878540906*^9, 3.7977949753388042`*^9, 
   3.797843181586781*^9, 3.7978457575300617`*^9, 3.797846046581986*^9, 
   3.7978472422389708`*^9, 3.797849046833168*^9, 3.7978491206593027`*^9, 
   3.797849372212488*^9, 3.7978496450325117`*^9, 3.79784973453915*^9, 
   3.797849925671357*^9, 3.797850016627439*^9, 3.7978547059703283`*^9, 
   3.7978588270031557`*^9, 3.797859220287758*^9, 3.797859611206963*^9, 
   3.797859752262224*^9, 3.797860368375313*^9, 3.797866026800881*^9, 
   3.7978661175422173`*^9, 3.797866528110791*^9, 3.7978667166501713`*^9, 
   3.797874742189724*^9, 3.797882025719192*^9, 3.797927827194875*^9, 
   3.797928453643701*^9, 3.797930854151939*^9, 3.797940025172134*^9, 
   3.79794058329537*^9, 3.797940741804047*^9, 3.797941036307078*^9, 
   3.798103390223675*^9, 3.798111499924591*^9, 3.798329608677096*^9, 
   3.798381744885779*^9, 3.798477311342938*^9, 3.79879512878036*^9, 
   3.7988435154162817`*^9, 3.7988455193433*^9, 3.798846133546674*^9, 
   3.799059705305238*^9, 3.799076973555483*^9, 3.7996828623698673`*^9, 
   3.800348607824232*^9, 3.8008146634286118`*^9, 3.800815066645371*^9, 
   3.800816317920495*^9, 3.800828454186762*^9, 3.8008302418265142`*^9, 
   3.80083044916322*^9, 3.8008690788785887`*^9, 3.8008708320526857`*^9, 
   3.8008711098336143`*^9, 3.8008972433970957`*^9, 3.800901921841721*^9, 
   3.800902290105791*^9, 3.800902764733239*^9, 3.8009052787455473`*^9, 
   3.800962161936699*^9, 3.800968365056953*^9, 3.801331041310113*^9, 
   3.802709453475153*^9, {3.802710597289678*^9, 3.802710610570092*^9}, 
   3.802713471780232*^9, 3.80271359164113*^9, 3.8027652508215647`*^9, 
   3.8027707284979258`*^9, 3.802771364905778*^9, 3.802774821986011*^9, 
   3.803117930748061*^9, 3.8031970583545713`*^9, 3.8033024841681557`*^9, 
   3.8033028536137333`*^9, 3.803308002870303*^9, 3.803324257644526*^9, 
   3.8034117794879293`*^9, 3.803412365481933*^9, 3.803474889261938*^9, 
   3.8037295425039186`*^9, 3.8037434095835743`*^9, 3.803806550289288*^9, 
   3.803808098107128*^9, 3.803812211969233*^9, 3.8038250761004133`*^9, 
   3.803830017853039*^9, 3.803891621823246*^9, 3.803979025216833*^9, 
   3.8042703421540327`*^9, 3.8044463909139357`*^9, 3.804598595987011*^9, 
   3.805045089612464*^9, 3.806938021760674*^9, 3.807091984104177*^9, 
   3.807092662545455*^9, 3.8254251663439407`*^9, 3.825425208413251*^9, 
   3.828107415635387*^9, 3.828716907233541*^9, 3.82871769553471*^9, 
   3.832075157865687*^9, 3.832085411506546*^9, 3.8393248270378942`*^9, 
   3.849021724685981*^9, 3.852115488233289*^9, 3.852137346968652*^9, 
   3.852138114188367*^9, 3.852143114385998*^9, 3.8522932682420387`*^9, 
   3.852294230540044*^9, 3.852327513689432*^9, 3.8523282001177797`*^9, 
   3.852364120568718*^9, 3.8523651573308697`*^9, 3.8523668059606113`*^9, 
   3.8537461231341047`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"9d777167-192c-4244-a48c-1fff3818961d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v01", "[", "t", "]"}], "/.", "defv01"}], "/.", "defv04"}], 
        "/.", "defI0"}], "/.", "defV00d"}], "/.", "defI0"}], "/.", 
     RowBox[{"ts", "\[Rule]", 
      RowBox[{"T", "-", "\[CapitalDelta]"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"va", ",", "\[CapitalDelta]V"}], "}"}], ",", "Simplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8254311868130093`*^9, 3.825431186926057*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"d0fe302e-daee-4687-af0f-81f603d1e7ad"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", "T"}]], "-", 
      SuperscriptBox["\[ExponentialE]", "\[CapitalDelta]"]}], ")"}], " ", 
    "\[CapitalDelta]V"}], 
   RowBox[{"1", "-", 
    SuperscriptBox["\[ExponentialE]", "T"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "t"}], "+", 
      RowBox[{"T", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}], "-", 
      RowBox[{"\[CapitalDelta]", " ", "\[Psi]"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "T"], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", "+", "\[CapitalDelta]"}]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[CapitalDelta]", " ", "\[Psi]"}]]}], ")"}], " ", "va"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", 
    "\[Psi]"}]]}]], "Output",
 CellChangeTimes->{3.8254311881775913`*^9, 3.825432527974622*^9, 
  3.8281074159132147`*^9, 3.828716907568531*^9, 3.8287176958913183`*^9, 
  3.832075158152419*^9, 3.832085411781666*^9, 3.839324828102209*^9, 
  3.8490217251035233`*^9, 3.8521154885112886`*^9, 3.852137347242466*^9, 
  3.8521381145053587`*^9, 3.852143114682067*^9, 3.8522932684985123`*^9, 
  3.8522942307946243`*^9, 3.852327513947555*^9, 3.852328200405142*^9, 
  3.8523641208299522`*^9, 3.852365157630989*^9, 3.8523668062207527`*^9, 
  3.853746123437872*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"15f325a7-49ee-4766-928f-b1489817e31d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v04", "[", "t", "]"}], "/.", "defv01"}], "/.", "defv04"}], 
        "/.", "defI0"}], "/.", "defV00d"}], "/.", "defI0"}], "/.", 
     RowBox[{"ts", "\[Rule]", 
      RowBox[{"T", "-", "\[CapitalDelta]"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"va", ",", "\[CapitalDelta]V"}], "}"}], ",", "Simplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.825430730487327*^9, 3.825430734315507*^9}, {
  3.8254307872146797`*^9, 3.825430870906773*^9}, {3.825431047079598*^9, 
  3.825431061157858*^9}, {3.825431121853016*^9, 3.825431122200054*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"31813d3a-0c1b-4633-9275-b8f0c43e5d9d"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", "T"}]], "-", 
      SuperscriptBox["\[ExponentialE]", "\[CapitalDelta]"]}], ")"}], " ", 
    "\[CapitalDelta]V"}], 
   RowBox[{"1", "-", 
    SuperscriptBox["\[ExponentialE]", "T"]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"T", "+", 
         RowBox[{"t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[CapitalDelta]", "+", 
        RowBox[{"T", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"T", "-", "\[CapitalDelta]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", 
        RowBox[{"T", " ", "\[Psi]"}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", "T", "+", 
        RowBox[{"T", " ", "\[Psi]"}], "-", 
        RowBox[{"\[CapitalDelta]", " ", "\[Psi]"}]}]]}], ")"}], " ", "va"}], 
   RowBox[{"\[Psi]", "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "T"], " ", "\[Psi]"}]}]]}]], "Output",
 CellChangeTimes->{
  3.825430736303835*^9, {3.825430810946414*^9, 3.825430817758711*^9}, 
   3.825430872546225*^9, {3.825431048647747*^9, 3.8254310684948463`*^9}, 
   3.8254311236506853`*^9, 3.825432405993464*^9, 3.825432528852611*^9, 
   3.828107416352951*^9, 3.828716908052497*^9, 3.828717696398505*^9, 
   3.832075158513926*^9, 3.832085412150276*^9, 3.8393248287542267`*^9, 
   3.849021725779085*^9, 3.852115488908215*^9, 3.852137347714242*^9, 
   3.8521381149106483`*^9, 3.852143115149665*^9, 3.8522932688976793`*^9, 
   3.852294231232471*^9, 3.852327514346808*^9, 3.8523282007578993`*^9, 
   3.85236412122621*^9, 3.85236515801054*^9, 3.8523668066646843`*^9, 
   3.853746123982139*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"f8276c83-58be-4044-9f07-bbf069de3629"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"xi", "+", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.825432388343398*^9, 3.825432398341837*^9}, {
  3.825432523708643*^9, 3.825432541990861*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"df3860b4-e702-4adf-8f77-17cfef5ea08f"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t", " ", "xi"}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"T", "+", 
        RowBox[{"t", " ", "xi"}]}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", "T", "+", 
        RowBox[{"T", " ", "xi"}]}]], "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"xi", " ", 
        RowBox[{"(", 
         RowBox[{"T", "-", "\[CapitalDelta]"}], ")"}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"T", " ", "xi"}], "+", "\[CapitalDelta]"}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", 
        RowBox[{"T", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", "xi"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "xi"}], ")"}], " ", "\[CapitalDelta]"}]}]]}], 
     ")"}], " ", "va"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "xi"}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "+", "T"}]], "-", 
      SuperscriptBox["\[ExponentialE]", "\[CapitalDelta]"]}], ")"}], " ", 
    "\[CapitalDelta]V"}], 
   RowBox[{"1", "-", 
    SuperscriptBox["\[ExponentialE]", "T"]}]]}]], "Output",
 CellChangeTimes->{{3.82543239932514*^9, 3.825432406869711*^9}, {
   3.825432530292696*^9, 3.825432542908525*^9}, 3.828107416898278*^9, 
   3.8287169087470617`*^9, 3.8287176971982727`*^9, 3.832075159042968*^9, 
   3.832085412683033*^9, 3.839324829475868*^9, 3.849021726605734*^9, 
   3.852115489424809*^9, 3.852137348677052*^9, 3.852138115596994*^9, 
   3.852143116235018*^9, 3.852293269386035*^9, 3.85229423178524*^9, 
   3.852327514894683*^9, 3.852328201257799*^9, 3.852364121781753*^9, 
   3.852365158587728*^9, 3.8523668072404833`*^9, 3.8537461245764713`*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"0bd0191f-6b5e-4d4c-8539-24c75da32128"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initial Conditions and Continuity Conditions at O(g)", "Section",
 CellChangeTimes->{{3.797596403737562*^9, 
  3.797596405890576*^9}},ExpressionUUID->"657d70d2-f37c-4724-9f19-\
6d870b655bd9"],

Cell["\<\
the gap junction can change the voltage right after the spike if the reset is \
by a fixed amount in the voltage\
\>", "Text",
 CellChangeTimes->{{3.797599902779127*^9, 3.797599939001829*^9}, {
  3.8522929871817207`*^9, 
  3.8522929951822147`*^9}},ExpressionUUID->"8aca3365-0534-40ad-85fb-\
f6756cc2c34b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"thresh1", "=", 
  RowBox[{
   RowBox[{"v12", "[", "ts", "]"}], "\[Equal]", "0"}]}]], "Input",
 CellChangeTimes->{{3.782759526887414*^9, 3.7827595612959538`*^9}, {
  3.782760074805735*^9, 3.7827600750731163`*^9}, {3.7827608123987417`*^9, 
  3.782760830433523*^9}, {3.7976000649172173`*^9, 3.797600077752081*^9}, {
  3.7976001386503897`*^9, 3.797600139864071*^9}, {3.797602282594666*^9, 
  3.797602283531076*^9}, {3.797764894990349*^9, 3.797764898387485*^9}, {
  3.797764932512699*^9, 3.797764934010166*^9}},
 CellLabel->"In[77]:=",ExpressionUUID->"361989b0-5e04-4d76-905c-2274a750bdaf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v12", "[", "ts", "]"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.782759529189836*^9, 3.7827595618682013`*^9}, 
   3.782760075785551*^9, 3.7827607461033983`*^9, {3.782760814077407*^9, 
   3.782760837634713*^9}, 3.797587888789641*^9, 3.79759645619411*^9, {
   3.7976000616411343`*^9, 3.7976000784934673`*^9}, 3.7976001427260427`*^9, 
   3.797600764013751*^9, 3.7976007959988623`*^9, 3.797601424900569*^9, 
   3.797602101452078*^9, 3.797602145870943*^9, 3.7976022146631536`*^9, {
   3.797602267817354*^9, 3.7976022862745934`*^9}, {3.797602328229501*^9, 
   3.797602354217174*^9}, 3.7976187472136707`*^9, 3.797619210535283*^9, 
   3.7976197526171083`*^9, 3.7976198286328897`*^9, 3.797620450355958*^9, 
   3.7977639413063374`*^9, 3.79776399828507*^9, 3.797764056667795*^9, 
   3.797764255270843*^9, 3.7977645659248247`*^9, 3.797764898903123*^9, 
   3.797764935823709*^9, 3.7977650873039722`*^9, 3.797765154178334*^9, 
   3.797765259089686*^9, 3.79776537641462*^9, 3.7977655297351713`*^9, 
   3.797765781940093*^9, 3.79776612559834*^9, 3.7977743090000267`*^9, 
   3.7977885907361298`*^9, 3.797794572209064*^9, 3.797794705349813*^9, 
   3.797794742398077*^9, 3.797794878605214*^9, 3.797794975424405*^9, 
   3.7978431816400433`*^9, 3.797845757596545*^9, 3.797846046629736*^9, 
   3.7978472422839613`*^9, 3.797849046897428*^9, 3.797849120736755*^9, 
   3.797849372257934*^9, 3.797849645381925*^9, 3.7978497345908413`*^9, 
   3.797849925745219*^9, 3.797850016731019*^9, 3.7978547060281887`*^9, 
   3.797858827042769*^9, 3.797859220331764*^9, 3.7978596112477407`*^9, 
   3.7978597523085747`*^9, 3.797860368422306*^9, 3.797866026881502*^9, 
   3.7978661222279367`*^9, 3.797866528184239*^9, 3.7978667196605873`*^9, 
   3.797874742258314*^9, 3.797882025915002*^9, 3.7979278272662277`*^9, 
   3.797928453719089*^9, 3.797930856826199*^9, 3.797940025247596*^9, 
   3.797940583356284*^9, 3.797940741898123*^9, 3.797941036378355*^9, 
   3.798103390296961*^9, 3.798111499971011*^9, 3.7983296088051567`*^9, 
   3.798381744945887*^9, 3.798477311453174*^9, 3.798795128840221*^9, 
   3.798843515467721*^9, 3.798845522493149*^9, 3.7988461362812643`*^9, 
   3.799059705360454*^9, 3.799076973686708*^9, 3.799682862497201*^9, 
   3.800348607884392*^9, 3.80081466350569*^9, 3.8008150667439327`*^9, 
   3.8008163179882317`*^9, 3.8008284542603703`*^9, 3.80083024188447*^9, 
   3.800830449221644*^9, 3.80086907893355*^9, 3.8008708321118193`*^9, 
   3.800871109995027*^9, 3.80089724345212*^9, 3.800901921906749*^9, 
   3.800902292831716*^9, 3.800902764783798*^9, 3.800905278802724*^9, 
   3.800962162024826*^9, 3.800968365115796*^9, 3.801331041359179*^9, 
   3.802709453587722*^9, {3.802710597358218*^9, 3.802710610639123*^9}, 
   3.802713471894712*^9, 3.80271359168427*^9, 3.8027652508645144`*^9, 
   3.8027707285435877`*^9, 3.8027713650016747`*^9, 3.802774822037013*^9, 
   3.803117930811645*^9, 3.8031970584058523`*^9, 3.803302484500108*^9, 
   3.803302853908309*^9, 3.803308002915951*^9, 3.8033242577122602`*^9, 
   3.803411779528434*^9, 3.8034123655567827`*^9, 3.803474889331003*^9, 
   3.8037295425573273`*^9, 3.803743409630835*^9, 3.803806550335544*^9, 
   3.8038080981849422`*^9, 3.803812212010503*^9, 3.803825076396079*^9, 
   3.8038300178931017`*^9, 3.803891621865459*^9, 3.8039790252833633`*^9, 
   3.8042703423505*^9, 3.804446390991353*^9, 3.804598596033692*^9, 
   3.805045089701038*^9, 3.806938022120269*^9, 3.8070919841790323`*^9, 
   3.8070926626195393`*^9, 3.825425166387295*^9, 3.825425208458355*^9, 
   3.828107416906549*^9, 3.8287169087625103`*^9, 3.8287176972093287`*^9, 
   3.832075159099174*^9, 3.832085412727726*^9, 3.8393248295380087`*^9, 
   3.849021726703807*^9, 3.852115489434292*^9, 3.85213734874177*^9, 
   3.8521381156309834`*^9, 3.852143116300311*^9, 3.852293269395769*^9, 
   3.8522942317954884`*^9, 3.8523275149524803`*^9, 3.852328201311305*^9, 
   3.852364121884522*^9, 3.852365158598737*^9, 3.852366807307753*^9, 
   3.853746124678019*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"5825e59f-9f20-475f-9234-08e175af7aac"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"thresh1", "/.", "defv12"}], "/.", "defV00d"}], "/.", "defI0"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.797764900769586*^9, 3.7977649030291023`*^9}, {
   3.797764937437396*^9, 3.797764938573093*^9}, {3.797765027313141*^9, 
   3.797765028974771*^9}, {3.7977651251846933`*^9, 3.797765126143248*^9}, {
   3.79776628165346*^9, 3.7977662945747766`*^9}, 3.797849689342474*^9, {
   3.797930883014895*^9, 3.797930885514426*^9}, 3.800350429773382*^9},
 CellLabel->"In[78]:=",ExpressionUUID->"c5486be1-b1b6-48ae-bace-de710f169382"],

Cell[BoxData[
 RowBox[{
  RowBox[{"defV10d", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{"%", ",", "V10"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", "va", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.782760841915472*^9, 3.7827608514573927`*^9}, {
   3.7976001168829327`*^9, 3.7976001316190987`*^9}, {3.79760025761578*^9, 
   3.797600263037442*^9}, 3.797602095385242*^9, {3.797602733807457*^9, 
   3.7976027346905603`*^9}, {3.797620460427436*^9, 3.797620467443242*^9}, 
   3.797764945811364*^9, {3.797765083532558*^9, 3.79776508514579*^9}, 
   3.797765150789513*^9, 3.797765516629915*^9, 3.7978495465879498`*^9, {
   3.7978586045326157`*^9, 3.7978586606331453`*^9}, {3.797930906204166*^9, 
   3.797930931717474*^9}, {3.797930990054158*^9, 3.797930991488454*^9}, {
   3.7979310586515512`*^9, 3.797931059817322*^9}, {3.798845542184684*^9, 
   3.798845547864201*^9}, {3.798846148870763*^9, 3.79884616616252*^9}, 
   3.800350490605534*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"9b64d72b-2a86-4502-9f7d-dcc5d16da8cc"],

Cell["\<\
If the reset is by a fixed voltage change then the change in voltage at O(g) \
at t=T must be V10, which is V(0) at O(g)\
\>", "Text",
 CellChangeTimes->{{3.7976029030769567`*^9, 
  3.797602955655779*^9}},ExpressionUUID->"a226dfe2-4055-4445-95e0-\
bd4c4611c7bb"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"v14", "[", "T", "]"}], "==", "V10"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flatten", "[", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"%", "/.", "defv14"}], "/.", "defV10d"}], "/.", "defV00d"}], 
       "/.", "defI0"}], "}"}], ",", "I1"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defI1", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"g0", ",", "\[CapitalDelta]V", ",", "gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.797600721329771*^9, 3.7976007477350283`*^9}, {
   3.7977666426414557`*^9, 3.7977666636989307`*^9}, {3.797771350465578*^9, 
   3.797771352870713*^9}, {3.797849591698049*^9, 3.797849593123085*^9}, {
   3.797849982421501*^9, 3.797849998018785*^9}, {3.79793110750846*^9, 
   3.797931120520019*^9}, {3.798846198439188*^9, 3.79884626343462*^9}, {
   3.798846312627421*^9, 3.798846313810655*^9}, {3.8008696564829903`*^9, 
   3.800869656927239*^9}, {3.802710680864683*^9, 3.8027107026720963`*^9}, 
   3.85232680736161*^9},
 CellLabel->"In[80]:=",ExpressionUUID->"7335208d-ced6-4bb6-a342-7a2e03b04abc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"v14", "[", "T", "]"}], "\[Equal]", "V10"}]], "Output",
 CellChangeTimes->{{3.797766648409864*^9, 3.797766677676382*^9}, 
   3.797771354296444*^9, 3.797774309755611*^9, 3.797788591528336*^9, 
   3.79779457308703*^9, 3.797794706133719*^9, 3.797794756323532*^9, 
   3.797794892714962*^9, 3.797794976421867*^9, 3.797843182621726*^9, 
   3.7978440485956717`*^9, 3.797845771946624*^9, 3.7978460594802732`*^9, 
   3.797847256853217*^9, 3.79784904779399*^9, 3.7978491215661583`*^9, 
   3.7978493865742817`*^9, 3.797849693870805*^9, 3.797849749142769*^9, 
   3.797849926611886*^9, 3.797850019105876*^9, 3.7978547149530573`*^9, 
   3.797858831115615*^9, 3.797859224364545*^9, 3.797859615154954*^9, 
   3.797859756211528*^9, 3.797860416440061*^9, 3.797866038928446*^9, 
   3.797866156585556*^9, 3.797866544498221*^9, 3.797866742492028*^9, 
   3.797874788129534*^9, 3.7978820743322268`*^9, 3.797927846147709*^9, 
   3.797928472934058*^9, 3.79793107340423*^9, {3.797931109130835*^9, 
   3.797931122303103*^9}, 3.7979400255218897`*^9, 3.797940583588085*^9, 
   3.797940742213718*^9, 3.797941036617557*^9, 3.798103390590824*^9, 
   3.7981115002088623`*^9, 3.798329609175775*^9, 3.798381745160726*^9, 
   3.7984773117974873`*^9, 3.798795129164124*^9, 3.798843515643693*^9, {
   3.79884619185753*^9, 3.798846263969133*^9}, 3.798846314209524*^9, 
   3.799059711876513*^9, 3.799076984584656*^9, 3.799682871620174*^9, 
   3.800348614537595*^9, 3.8008146705999327`*^9, 3.800815078002933*^9, 
   3.800816322130576*^9, 3.8008284581284513`*^9, 3.800830244705374*^9, 
   3.8008304555735197`*^9, 3.800869081669735*^9, {3.800869660267359*^9, 
   3.800869665318303*^9}, 3.800870834853711*^9, 3.800871118268749*^9, 
   3.800897246191547*^9, 3.800901933285347*^9, 3.800902297552938*^9, 
   3.800902769730698*^9, 3.80090528425881*^9, 3.800962167708027*^9, 
   3.800968372461712*^9, 3.801331050714563*^9, 3.8027094620254393`*^9, 
   3.802710610967964*^9, 3.802710687902843*^9, 3.802713472503051*^9, 
   3.8027135919250517`*^9, 3.802765251116663*^9, 3.8027707288379374`*^9, 
   3.8027713654117517`*^9, 3.8027748301652184`*^9, 3.803117938828794*^9, 
   3.8031970660529747`*^9, 3.803302492800067*^9, 3.803302863223156*^9, 
   3.803308011307691*^9, 3.803324265558288*^9, 3.803411787007959*^9, 
   3.803412373956472*^9, 3.803474896816697*^9, 3.803729550839003*^9, 
   3.8037434170923023`*^9, 3.8038065576807833`*^9, 3.8038081060416403`*^9, 
   3.803812219531954*^9, 3.803825084797297*^9, 3.803830026718986*^9, 
   3.803891629246554*^9, 3.803979035450193*^9, 3.804270351358531*^9, 
   3.804446398656283*^9, 3.804598603764855*^9, 3.805045099788903*^9, 
   3.806938029707821*^9, 3.807091992430414*^9, 3.807092670196027*^9, 
   3.825425166751663*^9, 3.8254252087367363`*^9, 3.828107417262878*^9, 
   3.828716919657546*^9, 3.828717699556861*^9, 3.832075160838091*^9, 
   3.8320854144681387`*^9, 3.839324831439481*^9, 3.852115496867793*^9, 
   3.852137356641124*^9, 3.852138123197192*^9, 3.8521431242027597`*^9, 
   3.8522932711090717`*^9, 3.8522942334566717`*^9, 3.852327516470874*^9, 
   3.8523282029692698`*^9, 3.852364123618349*^9, 3.8523651664304123`*^9, 
   3.852366815125628*^9, 3.853746133138829*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"890fe186-e69b-424c-b8c8-7a0ae7961fad"]
}, Open  ]],

Cell["Define V00 and V10 with I0 and I1 replaced", "Text",
 CellChangeTimes->{{3.797849482892913*^9, 3.797849499504055*^9}, 
   3.7978497610465107`*^9},ExpressionUUID->"593fee1b-a173-4669-8453-\
45a47c32557b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"defV00", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"defV00d", "/.", "defI0"}], ",", 
     RowBox[{"{", 
      RowBox[{"va", ",", "gc01"}], "}"}], ",", "Simplify"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defV10", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"defV10d", "/.", "defI0"}], "/.", "defI1"}], ",", 
     RowBox[{"{", 
      RowBox[{"va", ",", "gc01"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7978495030103693`*^9, 3.7978495044187737`*^9}, {
   3.7978495984008017`*^9, 3.797849623358243*^9}, {3.797849862463654*^9, 
   3.797849892667695*^9}, {3.7978500755563097`*^9, 3.79785008486843*^9}, 
   3.7978729477854767`*^9, {3.797928393979108*^9, 3.797928397725004*^9}, {
   3.7979310917693987`*^9, 3.797931093896633*^9}, 3.825425607597279*^9, {
   3.852292857524308*^9, 3.852292885241428*^9}, {3.852292916836088*^9, 
   3.852292918921585*^9}, {3.852326817240532*^9, 3.852326818719849*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"db939458-1278-47a5-9297-fea4cf6e93e3"],

Cell["Numerical parameters for plotting", "Text",
 CellChangeTimes->{{3.8393244558123302`*^9, 
  3.8393244651657267`*^9}},ExpressionUUID->"d66bfdce-39ae-4071-9b2f-\
39f713e04153"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defnumChKo00", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Psi]", "\[Rule]", "13"}], ",", 
    RowBox[{"va", "\[Rule]", 
     RowBox[{"1", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "ts"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Psi]", "-", "1"}], ")"}]}], "]"}]}]}], ",", 
    RowBox[{"\[CapitalDelta]V", "\[Rule]", "5"}], ",", 
    RowBox[{"T", "\[Rule]", "2"}], ",", 
    RowBox[{"ts", "\[Rule]", 
     RowBox[{"T", "-", "\[Delta]"}]}], ",", 
    RowBox[{"\[Delta]", "\[Rule]", "0.5"}], ",", " ", 
    RowBox[{"Vr", "\[Rule]", "10"}], ",", 
    RowBox[{"gc01", "\[Rule]", "0"}], ",", 
    RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
    RowBox[{"\[Sigma]r", "\[Rule]", "0.1"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.797770601242674*^9, 3.797770602660177*^9}, {
   3.797770967567554*^9, 3.797771025089922*^9}, {3.797771091644964*^9, 
   3.7977710972172813`*^9}, {3.797771238282358*^9, 3.797771256294142*^9}, {
   3.797771308109311*^9, 3.797771338085142*^9}, {3.7977713739478416`*^9, 
   3.797771385002099*^9}, {3.797771486132901*^9, 3.7977714873231173`*^9}, {
   3.797772071238406*^9, 3.797772073211141*^9}, {3.7977735871517143`*^9, 
   3.797773613761384*^9}, {3.797774870001588*^9, 3.79777487052724*^9}, 
   3.797774913914055*^9, {3.7977749910335827`*^9, 3.797774992157557*^9}, {
   3.79777570343869*^9, 3.797775712375266*^9}, {3.797791173937484*^9, 
   3.797791176192442*^9}, {3.797792702431056*^9, 3.797792706025711*^9}, {
   3.797792850405901*^9, 3.797792857035926*^9}, {3.7977936250982924`*^9, 
   3.797793630004829*^9}, {3.797845874516293*^9, 3.797845895581175*^9}, {
   3.797850130206772*^9, 3.7978501399066772`*^9}, {3.797850365855144*^9, 
   3.7978503735989103`*^9}, {3.79785494170189*^9, 3.797854941812599*^9}, {
   3.797855041678966*^9, 3.7978550491472178`*^9}, {3.798103776936699*^9, 
   3.7981037834023733`*^9}, {3.800905694523387*^9, 3.80090569559186*^9}, {
   3.803317500225425*^9, 3.803317500625996*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"eca3a922-6605-49af-8e03-a6124456c7c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Psi]", "\[Rule]", "13"}], ",", 
   RowBox[{"va", "\[Rule]", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "ts"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]]}], ",", 
   RowBox[{"\[CapitalDelta]V", "\[Rule]", "5"}], ",", 
   RowBox[{"T", "\[Rule]", "2"}], ",", 
   RowBox[{"ts", "\[Rule]", 
    RowBox[{"T", "-", "\[Delta]"}]}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "0.5`"}], ",", 
   RowBox[{"Vr", "\[Rule]", "10"}], ",", 
   RowBox[{"gc01", "\[Rule]", "0"}], ",", 
   RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
   RowBox[{"\[Sigma]r", "\[Rule]", "0.1`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.797773591422822*^9, 3.7977736144068613`*^9}, 
   3.797774310396497*^9, 3.797774871816328*^9, 3.7977749149278927`*^9, 
   3.7977749931634617`*^9, 3.797775714035421*^9, 3.797776186547022*^9, 
   3.79778859210821*^9, 3.797791177094963*^9, 3.797791228931237*^9, 
   3.797792709342223*^9, 3.797792864282014*^9, 3.7977945736203814`*^9, 
   3.797794706741995*^9, 3.797794762422307*^9, 3.797794898772071*^9, 
   3.797794977007431*^9, 3.797843183163269*^9, 3.7978457781148863`*^9, 
   3.7978458763627787`*^9, 3.797846065580291*^9, 3.797847271306416*^9, 
   3.797849048347269*^9, 3.797849122101*^9, 3.797849401105197*^9, 
   3.797849845418541*^9, 3.797849929771995*^9, 3.797850026010016*^9, {
   3.797850133435588*^9, 3.797850140524674*^9}, 3.797850539506115*^9, 
   3.7978547410176907`*^9, 3.797854942319859*^9, 3.797855042799493*^9, 
   3.797858838481744*^9, 3.7978592316654654`*^9, 3.797859622232579*^9, 
   3.797859763393211*^9, 3.797875498233904*^9, 3.7978827747057037`*^9, 
   3.7979282679925127`*^9, 3.7979285216469088`*^9, 3.797940026576868*^9, 
   3.797940584541794*^9, 3.7979407423495903`*^9, 3.797941036819847*^9, 
   3.7981033908367443`*^9, 3.798103786246747*^9, 3.7981115004407787`*^9, 
   3.7983296097722282`*^9, 3.798381745356444*^9, 3.7984773123174887`*^9, 
   3.798795129492229*^9, 3.798843515796962*^9, 3.799059712055225*^9, 
   3.799076984895813*^9, 3.799682871905423*^9, 3.8003486146900454`*^9, 
   3.8008146708372307`*^9, 3.800815078201786*^9, 3.8008163223938503`*^9, 
   3.8008284584496202`*^9, 3.800830244992283*^9, 3.8008304557394133`*^9, 
   3.8008690818900547`*^9, 3.800870835108184*^9, 3.800871118595153*^9, 
   3.8008972464568253`*^9, 3.80090193999152*^9, 3.800902301225154*^9, 
   3.80090276987854*^9, 3.800905284432811*^9, 3.800905696273142*^9, 
   3.8009621679217*^9, 3.800968372652112*^9, 3.801331050931116*^9, 
   3.802709462526005*^9, 3.802710611072198*^9, 3.80271347265267*^9, 
   3.802713592009342*^9, 3.802765251242708*^9, 3.802770728897559*^9, 
   3.8027713656138353`*^9, 3.802774830354505*^9, 3.803117939212184*^9, 
   3.803197066255999*^9, 3.803302492963945*^9, 3.803302863763027*^9, 
   3.8033080115329323`*^9, 3.8033242657514544`*^9, 3.803411192337023*^9, 
   3.80341178720813*^9, 3.803412374168272*^9, 3.803474896999501*^9, 
   3.80372955103329*^9, 3.8037434172698402`*^9, 3.803806557891276*^9, 
   3.803808106287983*^9, 3.803812219748351*^9, 3.803825085243531*^9, 
   3.803830026940441*^9, 3.803891629424819*^9, 3.803979035741869*^9, 
   3.804270351702654*^9, 3.8044463987993402`*^9, 3.804598603965507*^9, 
   3.805045100036772*^9, 3.806938030461164*^9, 3.807091992572191*^9, 
   3.807092670356614*^9, 3.825425166812793*^9, 3.82542520880107*^9, 
   3.828107417338581*^9, 3.828716920091711*^9, 3.828717700017276*^9, 
   3.8320751612159224`*^9, 3.8320854148021097`*^9, 3.839324832195777*^9, 
   3.8521154971462383`*^9, 3.852137356890991*^9, 3.852138123593539*^9, 
   3.8521431244564123`*^9, 3.852293271414905*^9, 3.852294233680538*^9, 
   3.852327516526759*^9, 3.8523282030576572`*^9, 3.8523641236726093`*^9, 
   3.85236516658945*^9, 3.8523668153034077`*^9, 3.8537461333366203`*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"3ca0f1be-69ca-41f9-a97c-1545340269f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"defnumorig", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Psi]", "\[Rule]", "13"}], ",", 
      RowBox[{"va", "\[Rule]", 
       RowBox[{"0.2", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "ts"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Psi]", "-", "1"}], ")"}]}], "]"}]}]}], ",", 
      RowBox[{"\[CapitalDelta]V", "\[Rule]", "7.2017"}], ",", 
      RowBox[{"ts", "\[Rule]", 
       RowBox[{"T", "-", "\[Delta]"}]}], ",", 
      RowBox[{"\[Delta]", "\[Rule]", ".5"}], ",", " ", 
      RowBox[{"Vr", "\[Rule]", "10"}], ",", 
      RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
      RowBox[{"\[Sigma]r", "\[Rule]", "5.5"}], ",", 
      RowBox[{"g0", "\[Rule]", "0.1"}]}], "}"}]}], " ", ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "in", " ", "simulations", " ", "\[CapitalDelta]2", " ", "is", " ", "about",
     " ", "0.1"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defnum", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "\[Rule]", "10.1"}], ",", 
     RowBox[{"va", "\[Rule]", 
      RowBox[{"0.2", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "ts"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Psi]", "-", "1"}], ")"}]}], "]"}]}]}], ",", 
     RowBox[{"\[CapitalDelta]V", "\[Rule]", "2.3"}], ",", 
     RowBox[{"ts", "\[Rule]", 
      RowBox[{"T", "-", "\[Delta]"}]}], ",", 
     RowBox[{"\[Delta]", "\[Rule]", "0.5"}], ",", " ", 
     RowBox[{"Vr", "\[Rule]", "10"}], ",", 
     RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
     RowBox[{"\[Sigma]r", "\[Rule]", "5.5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"defnuma", "=", "defnum"}], " ", 
   RowBox[{"(*", 
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{"defnum", ",", 
       RowBox[{"\[Alpha]", "\[Rule]", "1"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", "0"}]}], "}"}], "]"}], "*)"}], " ", 
   ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "only", " ", "one", " ", "synaptic", " ", "contribution", " ", "for", " ", 
    "testing", " ", "whether", " ", "2", " ", "contributions", " ", "are", 
    " ", "sufficent"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"defnumb", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{"defnum", ",", 
     RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"the", " ", "calculation", " ", "assumes", " ", "ts"}], "<", 
    RowBox[{"T", "-", 
     RowBox[{"\[Phi]T", " ", 
      RowBox[{"i", ".", "e", ".", " ", "\[Delta]"}]}]}], ">", "\[Phi]T"}], 
   " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.797793637970132*^9, 3.797793659336334*^9}, {
   3.797793705937991*^9, 3.797793706353537*^9}, {3.797793786170442*^9, 
   3.797793786497499*^9}, {3.7978452233124857`*^9, 3.797845223958416*^9}, {
   3.797845905667006*^9, 3.797845915634089*^9}, 3.797846463810728*^9, {
   3.7978465651294413`*^9, 3.797846583163361*^9}, {3.797846683693831*^9, 
   3.797846684167828*^9}, {3.797846810466284*^9, 3.7978468135013237`*^9}, {
   3.797846988945972*^9, 3.797846990076479*^9}, {3.7978484229185123`*^9, 
   3.797848424653813*^9}, {3.797850119608*^9, 3.7978501253812733`*^9}, {
   3.797850378239917*^9, 3.797850381797947*^9}, {3.797852847580873*^9, 
   3.7978528487254457`*^9}, 3.797854937174368*^9, {3.797855051128372*^9, 
   3.797855051347982*^9}, {3.797855682745934*^9, 3.797855684347374*^9}, 
   3.7978561729947987`*^9, {3.797857060674768*^9, 3.797857064020609*^9}, 
   3.7978571696001663`*^9, {3.7978572608636427`*^9, 3.797857262062318*^9}, {
   3.797872675670207*^9, 3.797872677337072*^9}, {3.797873790777017*^9, 
   3.797873804996161*^9}, {3.797874023662496*^9, 3.797874024345831*^9}, {
   3.797877040998086*^9, 3.7978770434421186`*^9}, 3.797931194590938*^9, {
   3.797933995266967*^9, 3.7979339961188097`*^9}, {3.7979341174954233`*^9, 
   3.797934118779771*^9}, {3.797934216686448*^9, 3.7979342313397017`*^9}, {
   3.797934495763729*^9, 3.797934521946341*^9}, {3.7979488412815523`*^9, 
   3.7979488499339123`*^9}, {3.797949100846849*^9, 3.797949101064271*^9}, {
   3.7979491625861397`*^9, 3.7979491662449627`*^9}, {3.797949669297159*^9, 
   3.79794966953827*^9}, {3.797949744933218*^9, 3.7979497455505037`*^9}, {
   3.798103791616371*^9, 3.798103795580324*^9}, 3.7981045790376873`*^9, {
   3.798104683526658*^9, 3.798104687314152*^9}, {3.7981049674182243`*^9, 
   3.798104971487686*^9}, {3.798105043831481*^9, 3.798105044767457*^9}, {
   3.7981051284304667`*^9, 3.798105128713914*^9}, {3.7981052297224607`*^9, 
   3.798105229937954*^9}, {3.798329513030789*^9, 3.798329520964094*^9}, {
   3.7983818616125097`*^9, 3.7983818764224777`*^9}, {3.7983836526316433`*^9, 
   3.798383661291216*^9}, {3.798477185134034*^9, 3.798477204159686*^9}, {
   3.798797652355435*^9, 3.798797656950605*^9}, {3.7987981756709633`*^9, 
   3.7987981771532288`*^9}, {3.798798533051282*^9, 3.798798534171077*^9}, {
   3.79879864757518*^9, 3.7987986499505577`*^9}, {3.79879876941494*^9, 
   3.798798769777125*^9}, {3.7988464796694098`*^9, 3.798846592750618*^9}, {
   3.798846684431785*^9, 3.798846686134153*^9}, {3.798847139706517*^9, 
   3.7988471409237213`*^9}, {3.799061004868287*^9, 3.79906100716084*^9}, {
   3.799061428708658*^9, 3.7990614307412*^9}, {3.7990621362216663`*^9, 
   3.799062144205206*^9}, {3.799062284708593*^9, 3.799062286505473*^9}, {
   3.79906313064251*^9, 3.799063132870961*^9}, {3.799063328961321*^9, 
   3.799063331293006*^9}, {3.7990636218144503`*^9, 3.799063622099813*^9}, {
   3.7990774913437777`*^9, 3.7990774918423767`*^9}, {3.799081275709918*^9, 
   3.7990812799252663`*^9}, {3.8003487212539577`*^9, 3.800348754234333*^9}, {
   3.800349461451202*^9, 3.800349461541089*^9}, 3.800349658656114*^9, 
   3.800366471236854*^9, {3.800819358958663*^9, 3.800819363046598*^9}, {
   3.800819396724804*^9, 3.800819404072857*^9}, {3.800828358973033*^9, 
   3.800828383881886*^9}, {3.800869759771647*^9, 3.800869760050576*^9}, {
   3.800899805957548*^9, 3.800899806067073*^9}, {3.800899942550791*^9, 
   3.800899944919587*^9}, {3.8009000890593357`*^9, 3.800900089373448*^9}, {
   3.800900292118023*^9, 3.800900295136064*^9}, {3.8009050216432343`*^9, 
   3.800905038458515*^9}, {3.800906077954158*^9, 3.800906078112589*^9}, {
   3.800906542321423*^9, 3.8009065506055393`*^9}, {3.800970022905674*^9, 
   3.8009700236106033`*^9}, 3.800977118238906*^9, 3.800977508789764*^9, {
   3.801334396619059*^9, 3.801334396742137*^9}, {3.8033175916691504`*^9, 
   3.803317608765215*^9}, {3.803324727801618*^9, 3.803324748612829*^9}, {
   3.803327860957983*^9, 3.803327861255066*^9}, {3.803327975518573*^9, 
   3.803327994215073*^9}, {3.803378734341673*^9, 3.803378737947267*^9}, {
   3.803379164465444*^9, 3.803379185450659*^9}, {3.803395119935326*^9, 
   3.803395122351968*^9}, {3.803396427029874*^9, 3.8033964322063513`*^9}, {
   3.8033978815049057`*^9, 3.8033978853698378`*^9}, {3.8034762080911827`*^9, 
   3.803476209782143*^9}, {3.8034770958902607`*^9, 3.8034770962797127`*^9}, {
   3.803477180243704*^9, 3.8034771818462*^9}, {3.803478286639632*^9, 
   3.803478296843172*^9}, {3.803478908344555*^9, 3.803478910563382*^9}, {
   3.803730265168112*^9, 3.803730265235312*^9}, {3.803730391912114*^9, 
   3.8037303948361797`*^9}, {3.8037305187600393`*^9, 3.803730519186453*^9}, {
   3.803730758111383*^9, 3.8037307584660263`*^9}, {3.803743467238559*^9, 
   3.803743503836659*^9}, {3.803743542623855*^9, 3.803743543729931*^9}, {
   3.803812767775358*^9, 3.80381276938704*^9}, {3.803813851372427*^9, 
   3.803813853592078*^9}, {3.803815023380706*^9, 3.803815024831636*^9}, {
   3.8038159997681713`*^9, 3.8038160012330503`*^9}, {3.8038161038897867`*^9, 
   3.803816105355225*^9}, {3.8038162328568296`*^9, 3.8038162352695312`*^9}, {
   3.803816489222752*^9, 3.803816493225389*^9}, {3.803816586103936*^9, 
   3.8038166062265663`*^9}, {3.8038220440358553`*^9, 
   3.8038220456867123`*^9}, {3.803835099356284*^9, 3.803835101514889*^9}, {
   3.803835167097335*^9, 3.803835173960881*^9}, {3.803837749106032*^9, 
   3.803837762778784*^9}, {3.803839679870433*^9, 3.80383968934879*^9}, {
   3.803840615770994*^9, 3.8038406167698517`*^9}, {3.8042708237431803`*^9, 
   3.804270825206162*^9}, {3.8044234362482443`*^9, 3.804423480631481*^9}, {
   3.804503380257764*^9, 3.8045033858531723`*^9}, {3.8045295783490257`*^9, 
   3.804529585429121*^9}, {3.8050452904358807`*^9, 3.8050453240231867`*^9}, {
   3.85236636020015*^9, 3.8523663766261463`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"f5103d3c-5f30-4278-8992-91909b0b6445"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Psi]", "\[Rule]", "10.1`"}], ",", 
   RowBox[{"va", "\[Rule]", 
    RowBox[{"0.2`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "ts"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]]}]}], ",", 
   RowBox[{"\[CapitalDelta]V", "\[Rule]", "2.3`"}], ",", 
   RowBox[{"ts", "\[Rule]", 
    RowBox[{"T", "-", "\[Delta]"}]}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "0.5`"}], ",", 
   RowBox[{"Vr", "\[Rule]", "10"}], ",", 
   RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
   RowBox[{"\[Sigma]r", "\[Rule]", "5.5`"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8033242658010073`*^9, {3.803324713056909*^9, 3.80332474993601*^9}, 
   3.803327863854169*^9, 3.80332799933986*^9, 3.803378742368717*^9, 
   3.8033791931584272`*^9, 3.803395123629033*^9, 3.8033964471035*^9, 
   3.8033978864300823`*^9, 3.803411193500825*^9, 3.8034117872462473`*^9, 
   3.8034123742255507`*^9, 3.803474897063766*^9, 3.803476210246451*^9, 
   3.8034770976793137`*^9, 3.80347718294097*^9, 3.80347829837739*^9, 
   3.803478911250432*^9, 3.803729551075489*^9, 3.803730266211681*^9, 
   3.803730396140073*^9, 3.80373052039263*^9, 3.8037307595091543`*^9, 
   3.803743417308298*^9, 3.8037451117041597`*^9, 3.803806557933958*^9, 
   3.8038081062963247`*^9, 3.803812219780767*^9, 3.803812770379204*^9, 
   3.8038138592202997`*^9, 3.803815025615477*^9, 3.803816001937009*^9, {
   3.803816105889308*^9, 3.803816135702876*^9}, 3.8038162005464077`*^9, 
   3.803816235854487*^9, 3.803816498662558*^9, 3.8038166069189*^9, 
   3.803822047003943*^9, 3.803825085451305*^9, 3.803830026975664*^9, 
   3.8038351023481092`*^9, 3.803835176475627*^9, 3.803837771936872*^9, {
   3.803839682368617*^9, 3.803839690084868*^9}, 3.803840617562417*^9, 
   3.803891629456884*^9, 3.803979035807399*^9, 3.804270351802329*^9, 
   3.804270829396035*^9, 3.804446398857885*^9, 3.804503389523391*^9, 
   3.804529589449819*^9, 3.804598603994176*^9, 3.805045100113106*^9, 
   3.8050453397515707`*^9, 3.806938030821072*^9, 3.807091992632759*^9, 
   3.807092670424815*^9, 3.825425166848382*^9, 3.825425208838409*^9, 
   3.8281074173781157`*^9, 3.828716920142704*^9, 3.828717700085657*^9, 
   3.8320751612671127`*^9, 3.8320854148501587`*^9, 3.839324832204597*^9, 
   3.852115497184414*^9, 3.852137356945017*^9, 3.852138123604926*^9, 
   3.852143124501259*^9, 3.852293271458076*^9, 3.8522942337179203`*^9, 
   3.852327516571619*^9, 3.8523282031044064`*^9, 3.852364123718556*^9, 
   3.852365166633449*^9, 3.852366815352922*^9, 3.853746133456756*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"fa742351-26cb-4226-a2a2-2b030789b7d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"parametertext", "=", 
  RowBox[{"\"\<_\[Psi]\>\"", "<>", 
   RowBox[{"ToString", "[", 
    RowBox[{"\[Psi]", "/.", "defnumb"}], "]"}], "<>", 
   "\"\<_\[CapitalDelta]V\>\"", "<>", 
   RowBox[{"ToString", "[", 
    RowBox[{"\[CapitalDelta]V", "/.", "defnumb"}], "]"}], "<>", 
   "\"\<_\[Delta]\>\"", "<>", 
   RowBox[{"ToString", "[", 
    RowBox[{"\[Delta]", "/.", "defnumb"}], "]"}], "<>", "\"\<_Vr\>\"", "<>", 
   RowBox[{"ToString", "[", 
    RowBox[{"Vr", "/.", "defnumb"}], "]"}], "<>", "\"\<_\[Sigma]f\>\"", "<>", 
   
   RowBox[{"ToString", "[", 
    RowBox[{"\[Sigma]f", "/.", "defnumb"}], "]"}], "<>", "\"\<_\[Sigma]r\>\"",
    "<>", 
   RowBox[{"ToString", "[", 
    RowBox[{"\[Sigma]r", "/.", "defnumb"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.80347630164734*^9, 3.803476401236371*^9}, {
   3.803476473476454*^9, 3.8034765272749*^9}, 3.803476817356329*^9, {
   3.803730092378035*^9, 3.803730120103034*^9}, 3.803730168204583*^9, {
   3.803743897676738*^9, 3.8037439015577497`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"ad38bf0a-3f3c-4380-b411-1b7fe67b95a2"],

Cell[BoxData["\<\"_\[Psi]10.1_\[CapitalDelta]V2.3_\[Delta]0.5_Vr10_\[Sigma]f5_\
\[Sigma]r5.5\"\>"], "Output",
 CellChangeTimes->{{3.8034765100586157`*^9, 3.803476528360837*^9}, 
   3.803476818951545*^9, 3.803477099454829*^9, 3.803477184078424*^9, 
   3.803477813381501*^9, 3.803478305841208*^9, 3.803478912187113*^9, 
   3.803729551086975*^9, 3.8037301205657187`*^9, 3.803730169317306*^9, 
   3.803730268461061*^9, 3.80373039730259*^9, 3.803730521347838*^9, 
   3.803730761045785*^9, 3.803743417315364*^9, 3.803743903155891*^9, 
   3.803745113366197*^9, 3.803806557942622*^9, 3.803808106338215*^9, 
   3.80381221979032*^9, 3.803812771663143*^9, 3.803813860289386*^9, 
   3.803815026894096*^9, 3.803816003035124*^9, 3.803816106569622*^9, 
   3.8038161370385647`*^9, 3.8038162042464323`*^9, 3.8038162368175583`*^9, 
   3.803816499593803*^9, 3.803816607796397*^9, 3.803822048848419*^9, 
   3.8038250855372953`*^9, 3.803830026985327*^9, 3.803835103381693*^9, 
   3.803835177337281*^9, 3.803837774093293*^9, 3.803839690956143*^9, 
   3.8038406198290997`*^9, 3.803891629464904*^9, 3.803979035819633*^9, 
   3.804270351811748*^9, 3.804270830920993*^9, 3.80444639886518*^9, 
   3.8045033907830343`*^9, 3.804529591692931*^9, 3.8045986040031643`*^9, 
   3.8050451001228228`*^9, 3.8050453413804493`*^9, 3.806938031415431*^9, 
   3.807091992642123*^9, 3.807092670432507*^9, 3.8254251668560667`*^9, 
   3.8254252088450212`*^9, 3.828107417388796*^9, 3.828716920156128*^9, 
   3.82871770010044*^9, 3.832075161276544*^9, 3.832085414859226*^9, 
   3.839324832261531*^9, 3.852115497192265*^9, 3.852137356955304*^9, 
   3.8521381236861773`*^9, 3.8521431245120163`*^9, 3.85229327146986*^9, 
   3.8522942337289867`*^9, 3.852327516585038*^9, 3.8523282031158457`*^9, 
   3.8523641237291193`*^9, 3.852365166644924*^9, 3.852366815364154*^9, 
   3.85374613350418*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"cdb36b84-49ef-4369-af5a-4080f1a411d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{"defI0", "\[IndentingNewLine]", 
 RowBox[{"defI0numb", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"defI0", "/.", "defnumb"}], "/.", "defnumb"}], "/.", 
   "defnumb"}]}]}], "Input",
 CellLabel->"In[91]:=",ExpressionUUID->"1b0391dd-868a-4fae-a689-9900ee789895"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"I0", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "ts"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"T", " ", "\[Psi]"}]]}], " ", "va"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"ts", " ", "\[Psi]"}]], " ", "va"}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "ts"], " ", "\[Psi]"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"T", "+", "ts"}]], " ", "\[Psi]"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "T"], " ", "\[CapitalDelta]V", " ", 
        "\[Psi]"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", "T"]}], ")"}], " ", "\[Psi]"}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.8034123742478848`*^9, 3.803474897080056*^9, 3.803476211528727*^9, 
   3.803477101130662*^9, 3.803477184941702*^9, 3.8034778140993147`*^9, 
   3.8034783083755827`*^9, 3.803478912970427*^9, 3.803729551128223*^9, 
   3.803730123099777*^9, 3.803730170321452*^9, 3.803730270419344*^9, 
   3.8037303981546783`*^9, 3.803730522092153*^9, 3.803730761948049*^9, 
   3.803743417354403*^9, 3.8037439043764668`*^9, 3.8037451160104237`*^9, 
   3.803806557986697*^9, 3.803806861529361*^9, {3.803808106346797*^9, 
   3.80380811609383*^9}, 3.8038122198226233`*^9, 3.8038127726857433`*^9, 
   3.803813861142807*^9, 3.803815028045401*^9, 3.803816003894129*^9, 
   3.803816108073669*^9, 3.8038161381004333`*^9, 3.803816205811482*^9, 
   3.8038162376223907`*^9, 3.803816500428398*^9, 3.803816608533482*^9, 
   3.803822050454562*^9, 3.8038250857484617`*^9, 3.803830027013763*^9, 
   3.803835104830084*^9, 3.803835178199918*^9, 3.803837774937642*^9, 
   3.8038396916835833`*^9, 3.803840623905205*^9, 3.8038916294976063`*^9, 
   3.8039790358919363`*^9, 3.804270351946816*^9, 3.804270832121792*^9, 
   3.804446398922353*^9, 3.804503391796935*^9, 3.804529592656274*^9, 
   3.8045986040354147`*^9, 3.805045100204608*^9, 3.80504534346845*^9, 
   3.8069380314669724`*^9, 3.8070919927069817`*^9, 3.807092670499509*^9, 
   3.825425166895982*^9, 3.825425208852235*^9, 3.8281074174283133`*^9, 
   3.828716920206698*^9, 3.8287177001647253`*^9, 3.832075161328211*^9, 
   3.8320854149090223`*^9, 3.839324832276024*^9, 3.852115497230977*^9, 
   3.852137356998794*^9, 3.852138123697402*^9, 3.8521431245571537`*^9, 
   3.852293271515053*^9, 3.852294233766222*^9, 3.852327516632758*^9, 
   3.852328203156068*^9, 3.852364123773796*^9, 3.8523651666916313`*^9, 
   3.852366815426671*^9, 3.853746133806643*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"fc1b8661-c1b1-4025-b2d8-feda041178f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"I0", "\[Rule]", 
   FractionBox[
    RowBox[{"0.09900990099009901`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"0.5`", "\[VeryThinSpace]", "-", "T"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "10.1`"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "0.5`"}], "+", "T"}]]}], "+", 
       RowBox[{"0.2`", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"1.`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "0.5`"}], "+", "T"}], ")"}]}]]}], "+", 
       RowBox[{"23.229999999999997`", " ", 
        SuperscriptBox["\[ExponentialE]", "T"]}], "+", 
       RowBox[{"10.1`", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "0.5`"}], "+", 
          RowBox[{"2", " ", "T"}]}]]}], "-", 
       RowBox[{"0.2`", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9.1`"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "0.5`"}], "+", "T"}], ")"}]}], "+", 
          RowBox[{"10.1`", " ", "T"}]}]]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", "T"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8034123742478848`*^9, 3.803474897080056*^9, 3.803476211528727*^9, 
   3.803477101130662*^9, 3.803477184941702*^9, 3.8034778140993147`*^9, 
   3.8034783083755827`*^9, 3.803478912970427*^9, 3.803729551128223*^9, 
   3.803730123099777*^9, 3.803730170321452*^9, 3.803730270419344*^9, 
   3.8037303981546783`*^9, 3.803730522092153*^9, 3.803730761948049*^9, 
   3.803743417354403*^9, 3.8037439043764668`*^9, 3.8037451160104237`*^9, 
   3.803806557986697*^9, 3.803806861529361*^9, {3.803808106346797*^9, 
   3.80380811609383*^9}, 3.8038122198226233`*^9, 3.8038127726857433`*^9, 
   3.803813861142807*^9, 3.803815028045401*^9, 3.803816003894129*^9, 
   3.803816108073669*^9, 3.8038161381004333`*^9, 3.803816205811482*^9, 
   3.8038162376223907`*^9, 3.803816500428398*^9, 3.803816608533482*^9, 
   3.803822050454562*^9, 3.8038250857484617`*^9, 3.803830027013763*^9, 
   3.803835104830084*^9, 3.803835178199918*^9, 3.803837774937642*^9, 
   3.8038396916835833`*^9, 3.803840623905205*^9, 3.8038916294976063`*^9, 
   3.8039790358919363`*^9, 3.804270351946816*^9, 3.804270832121792*^9, 
   3.804446398922353*^9, 3.804503391796935*^9, 3.804529592656274*^9, 
   3.8045986040354147`*^9, 3.805045100204608*^9, 3.80504534346845*^9, 
   3.8069380314669724`*^9, 3.8070919927069817`*^9, 3.807092670499509*^9, 
   3.825425166895982*^9, 3.825425208852235*^9, 3.8281074174283133`*^9, 
   3.828716920206698*^9, 3.8287177001647253`*^9, 3.832075161328211*^9, 
   3.8320854149090223`*^9, 3.839324832276024*^9, 3.852115497230977*^9, 
   3.852137356998794*^9, 3.852138123697402*^9, 3.8521431245571537`*^9, 
   3.852293271515053*^9, 3.852294233766222*^9, 3.852327516632758*^9, 
   3.852328203156068*^9, 3.852364123773796*^9, 3.8523651666916313`*^9, 
   3.852366815426671*^9, 3.8537461338295403`*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"8f72ce4e-6b04-4990-a953-b0f225dc0658"]
}, Open  ]],

Cell["For matlab output we cannot have greek letters.", "Text",
 CellChangeTimes->{{3.839324481908531*^9, 
  3.839324492324092*^9}},ExpressionUUID->"9cc7b6da-50f1-4d9d-a537-\
68cae550802d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"degreek", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Sigma]f", "\[Rule]", "sigmaf"}], ",", 
    RowBox[{"\[Sigma]r", "\[Rule]", "sigmar"}], ",", 
    RowBox[{"\[Psi]", "\[Rule]", "psi"}], ",", 
    RowBox[{"\[CapitalDelta]V", "\[Rule]", "DeltaV"}], ",", 
    RowBox[{"\[Phi]", "\[Rule]", "phi"}], ",", 
    RowBox[{"\[Delta]", "\[Rule]", "delta"}], ",", 
    RowBox[{"\[Gamma]", "\[Rule]", "gamma"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.803895194388751*^9, 3.803895226068022*^9}, {
  3.803895280754551*^9, 3.8038953189965763`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"4439917b-6d3b-49ed-b2fc-d30b571c2bd6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Sigma]f", "\[Rule]", "sigmaf"}], ",", 
   RowBox[{"\[Sigma]r", "\[Rule]", "sigmar"}], ",", 
   RowBox[{"\[Psi]", "\[Rule]", "psi"}], ",", 
   RowBox[{"\[CapitalDelta]V", "\[Rule]", "DeltaV"}], ",", 
   RowBox[{"\[Phi]", "\[Rule]", "phi"}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "delta"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "gamma"}]}], "}"}]], "Output",
 CellChangeTimes->{3.803895324843973*^9, 3.803898059820038*^9, 
  3.803979035906726*^9, 3.804270351959399*^9, 3.804270833228643*^9, 
  3.804446398931703*^9, 3.8045033927702293`*^9, 3.8045295966290197`*^9, 
  3.804598604052631*^9, 3.8050451002150908`*^9, 3.805045344419485*^9, 
  3.806938031815584*^9, 3.8070919927198772`*^9, 3.807092670509325*^9, 
  3.825425166905959*^9, 3.825425208891088*^9, 3.828107417438356*^9, 
  3.8287169202256517`*^9, 3.828717700182371*^9, 3.832075161339589*^9, 
  3.832085414920268*^9, 3.839324832343775*^9, 3.8521154972422523`*^9, 
  3.852137357012617*^9, 3.852138123757978*^9, 3.8521431245736*^9, 
  3.852293271534133*^9, 3.8522942337818117`*^9, 3.852327516651739*^9, 
  3.852328203174074*^9, 3.8523641237915382`*^9, 3.852365166710273*^9, 
  3.8523668154453506`*^9, 3.8537461338458548`*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"b4e706aa-a312-4f79-b234-25c84079d895"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"defabbrev", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"sigmaf", "-", "1"}], "\[Rule]", "sigmafm1"}], ",", 
    RowBox[{
     RowBox[{"sigmar", "-", "1"}], "\[Rule]", "sigmarm1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "sigmaf"}], "+", "sigmar"}], "\[Rule]", "sigmadiff"}], ",", 
    RowBox[{
     RowBox[{"sigmaf", "-", "sigmar"}], "\[Rule]", 
     RowBox[{"-", "sigmadiff"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"Exp", "[", "T", "]"}]}], "\[Rule]", "exptm1"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.803892416639348*^9, 3.803892440908124*^9}, {
   3.803892493754236*^9, 3.803892510635785*^9}, {3.803892550882967*^9, 
   3.8038925587909937`*^9}, {3.8038952324703217`*^9, 3.803895275287105*^9}, 
   3.803898445604495*^9},
 CellLabel->"In[94]:=",ExpressionUUID->"0d4a1721-ac40-4c4e-a2e5-f8e2e1dab699"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", "sigmaf"}], "\[Rule]", "sigmafm1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", "sigmar"}], "\[Rule]", "sigmarm1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "sigmaf"}], "+", "sigmar"}], "\[Rule]", "sigmadiff"}], ",", 
   
   RowBox[{
    RowBox[{"sigmaf", "-", "sigmar"}], "\[Rule]", 
    RowBox[{"-", "sigmadiff"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", "T"]}], "\[Rule]", "exptm1"}]}], 
  "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+IvYhahkeFvHC32mkeDaD6OT8kgWs73ZyaI5nzPsCsK
SHNsWCYZA6RLJz48lwqk49zrFzcD6c83GB8JRrxxfByUIycEpI/cv389HUjP
uWi0phlIi2WvK58ApC9dadLcBKQN8zp1eyLfOF57aOADomUu/y7ViH3jmPNO
YnExkHbLvfQdRPNY3EvMbnjj2LZXJh1Er1XVF+5sfeM48yTH+k1tbxzVjrcL
bAbS76p1iqV63zhaXr5XIg+kHxVyh7yb9cbx1HeNo8Gb3zgeuLSwMA5Ir+Co
vAiiFx2b7JQIpJuXfJq0CkifMLHiXg2kPVumee8G0knP0xaC6Giuau2zQDrC
8sZaEH3r+fvqc0B6s+O+X/nb3jgCANTmpFY=
  "],
 CellLabel->"Out[94]=",ExpressionUUID->"9cb68fee-a651-44aa-95fd-19d4b43593fe"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"I1matlab", "=", 
   RowBox[{"I1", "/.", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{"defI1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"UnitStep", "[", "_", "]"}], ",", "gc01", ",", "\[Gamma]",
             ",", " ", "g0", ",", "va", ",", "\[CapitalDelta]V", ",", "Vr"}], 
           "}"}], ",", "Simplify"}], "]"}], "/.", "degreek"}], "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"UnitStep", "[", "_", "]"}], ",", "gc01", ",", " ", "g0", ",",
         "va", ",", "DeltaV", ",", "Vr"}], "}"}], ",", "Simplify"}], 
     "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8038920943750153`*^9, 3.803892094675786*^9}, {
   3.803892126791642*^9, 3.803892151440134*^9}, {3.803892204505684*^9, 
   3.8038922061670113`*^9}, {3.803892400728717*^9, 3.803892403321679*^9}, {
   3.803892664167096*^9, 3.803892667380426*^9}, {3.803892709076438*^9, 
   3.803892737361668*^9}, {3.803892773384335*^9, 3.8038928031082497`*^9}, {
   3.803893761562544*^9, 3.803893770930997*^9}, {3.803895334652287*^9, 
   3.803895347160136*^9}, 3.803898037718318*^9, 3.8039217644660883`*^9, {
   3.80392210092074*^9, 3.803922114086512*^9}, {3.8039221560725193`*^9, 
   3.803922156921536*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"6cec3b12-2be4-4e93-81ac-268cc479bbba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"parts", "=", 
   RowBox[{"Level", "[", 
    RowBox[{"I1matlab", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.80392283042346*^9, 3.8039228331288137`*^9}, {
   3.803922962999127*^9, 3.8039229681611013`*^9}, {3.8039232395546722`*^9, 
   3.8039232590539427`*^9}, 3.803927786661764*^9},
 CellLabel->"In[96]:=",ExpressionUUID->"31a49396-12d2-4a7c-a9ed-ce85529e868a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "parts", "]"}]], "Input",
 CellChangeTimes->{{3.803923294570355*^9, 3.803923297149481*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"56c8fa35-0232-4b0a-a422-58cbdd9988e3"],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.803923297588109*^9, 3.803979086490192*^9, 
  3.804270404546987*^9, 3.80427092482235*^9, 3.804446436229147*^9, 
  3.804503434546259*^9, 3.80452966885005*^9, 3.804598629724258*^9, 
  3.8050451510859613`*^9, 3.805045375699025*^9, 3.806938070160151*^9, 
  3.807092035818502*^9, 3.807092708666073*^9, 3.8254251676052647`*^9, 
  3.825425209518276*^9, 3.8281074181840153`*^9, 3.82871699312352*^9, 
  3.828717711680397*^9, 3.832075169933935*^9, 3.832085423662758*^9, 
  3.8393248414032993`*^9, 3.85213740974647*^9, 3.852138177505578*^9, 
  3.852143177443178*^9, 3.8522932802051067`*^9, 3.852294240385092*^9, 
  3.8523275224226713`*^9, 3.85232820957416*^9, 3.8523641302682037`*^9, 
  3.8523651994230747`*^9, 3.8523668479352913`*^9, 3.853746170043679*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"cc3b4bfa-b115-43d8-aa13-a73a1b60ba09"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"v01", "[", "t", "]"}], "/.", "defv01"}], "/.", "degreek"}], "/.", 
  RowBox[{"gamma", "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.807090696006473*^9, 3.8070907679694366`*^9}, {
  3.807090989596245*^9, 3.807091006269147*^9}, {3.807093963030822*^9, 
  3.8070939713957*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"26c125d5-7cc4-49c8-a72d-0a620a8f08a8"],

Cell[BoxData[
 RowBox[{"I0", "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "t"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.807090712280377*^9, 3.807090768826531*^9}, {
   3.8070909934774017`*^9, 3.807091007911046*^9}, 3.8070920358270693`*^9, 
   3.8070927087328978`*^9, {3.807093966998597*^9, 3.807093972523862*^9}, 
   3.8254251676434917`*^9, 3.825425209561513*^9, 3.828107418217945*^9, 
   3.8287169931833487`*^9, 3.828717711692132*^9, 3.832075169941704*^9, 
   3.8320854236708527`*^9, 3.839324841413377*^9, 3.852137409755756*^9, 
   3.8521381775350647`*^9, 3.852143177456203*^9, 3.852293280214898*^9, 
   3.852294240397361*^9, 3.852327522435623*^9, 3.8523282095844927`*^9, 
   3.8523641303182487`*^9, 3.85236519944204*^9, 3.852366847946693*^9, 
   3.853746170079278*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"f702255e-b4c8-4d22-99a0-f234ca76800e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["defv02"], "Input",
 CellChangeTimes->{{3.807091029666239*^9, 3.807091034731444*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"ca12a261-9576-494a-9368-fdac398c898c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v02", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{"I0", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8070910353162937`*^9, 3.807092035899981*^9, 
  3.807092708739738*^9, 3.82542516765129*^9, 3.82542520956776*^9, 
  3.828107418224576*^9, 3.8287169931956987`*^9, 3.8287177117496557`*^9, 
  3.832075169991288*^9, 3.832085423709651*^9, 3.839324841460174*^9, 
  3.852137409799964*^9, 3.852138177637835*^9, 3.852143177509055*^9, 
  3.8522932802521887`*^9, 3.852294240440057*^9, 3.852327522479459*^9, 
  3.852328209621871*^9, 3.852364130329077*^9, 3.852365199496709*^9, 
  3.852366847998477*^9, 3.853746170442924*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"fabfc40f-16c4-492c-8687-03d3f5c2814a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["defv03"], "Input",
 CellChangeTimes->{{3.8070910375038652`*^9, 3.807091039268196*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"0222ed67-5f86-49fe-81da-23232955ef29"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v03", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "t"], " ", "I0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
      "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
          RowBox[{"I0", " ", "\[Psi]"}], "+", 
          RowBox[{"V00", " ", "\[Psi]"}]}], ")"}]}], "\[Psi]"]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.807091041999682*^9, 3.807092035908615*^9, 
  3.807092708810004*^9, 3.825425167692631*^9, 3.825425209608222*^9, 
  3.828107418260942*^9, 3.828716993248413*^9, 3.828717711762241*^9, 
  3.8320751699994783`*^9, 3.832085423717238*^9, 3.8393248414706497`*^9, 
  3.852137409808785*^9, 3.852138177656782*^9, 3.85214317751857*^9, 
  3.852293280263049*^9, 3.85229424045284*^9, 3.8523275224908237`*^9, 
  3.852328209632296*^9, 3.852364130380218*^9, 3.8523651995091257`*^9, 
  3.852366848010478*^9, 3.8537461709872723`*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"e3e1b6a2-4321-4c95-b4ca-0d9f9574cef7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["defv04"], "Input",
 CellChangeTimes->{{3.8070910815459414`*^9, 3.807091083103271*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"5438af5a-996f-4f80-bba5-d85382e877dc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v04", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", "t"], " ", "I0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"t", " ", "\[Psi]"}]], " ", "va"}], "\[Psi]"]}], ")"}]}], 
      "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"ts", " ", "\[Psi]"}]]}], " ", "va"}], "-", 
          RowBox[{"I0", " ", "\[Psi]"}], "+", 
          RowBox[{"V00", " ", "\[Psi]"}]}], ")"}]}], "\[Psi]"]}]}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.807091083563631*^9, 3.807092035975713*^9, 
  3.807092708817953*^9, 3.825425167701914*^9, 3.825425209614943*^9, 
  3.8281074182687893`*^9, 3.828716993263289*^9, 3.8287177118154182`*^9, 
  3.832075170049418*^9, 3.832085423757338*^9, 3.8393248415206327`*^9, 
  3.852137409852932*^9, 3.852138177808361*^9, 3.852143177563396*^9, 
  3.8522932803020363`*^9, 3.852294240495617*^9, 3.852327522538191*^9, 
  3.852328209678317*^9, 3.8523641303917227`*^9, 3.852365199564045*^9, 
  3.852366848059758*^9, 3.853746171009499*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"53a8f23c-4c10-4d23-a0a3-b90df9373e58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"v11", "/.", "defv11"}], "/.", "degreek"}], "/.", 
  RowBox[{"gamma", "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.8070911436646423`*^9, 3.807091147372467*^9}, {
  3.80709130844228*^9, 3.807091316246355*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"b8503c64-770b-4eeb-88e3-a76cc9e5b09b"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", "t", "}"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "t"}], "-", 
       RowBox[{"T", " ", "phi"}]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"T", " ", "phi"}]]}], ")"}], " ", "g0", " ", "t", " ", 
     RowBox[{"(", 
      RowBox[{"I0", "-", "V00"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[ExponentialE]", "t"]}], ")"}], " ", "I1"}], "+", 
       "V10"}], ")"}]}], "+", 
    RowBox[{"gc01", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "t"}]]}], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmaf"}], "+", 
              RowBox[{"Tc1", " ", "sigmaf"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmaf"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "t"}], "+", "Tc1"}], ")"}], " ", "sigmaf"}]], 
            " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}]}], "sigmaf"], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmar"}], "+", 
              RowBox[{"Tc1", " ", "sigmar"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmar"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "Vr"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "t"}], "+", "Tc1"}], ")"}], " ", "sigmar"}]], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "sigmar"], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{"sigmaf", " ", "sigmar"}]]}], ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"t", "-", "Tc1"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Vr", " ", "sigmaf", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmar"}]]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"T", "+", "Tc1"}]], " ", 
                RowBox[{"(", 
                 RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmaf"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]}], ")"}], " ", 
             "sigmar"}], "+", 
            RowBox[{"V00", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmar"}]]}], 
                 ")"}], " ", "sigmaf"}], "+", "sigmar", "-", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmaf"}]], " ", 
                "sigmar"}]}], ")"}]}], "+", 
            RowBox[{"I0", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmaf"}]]}], 
                   ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", 
                  "sigmar"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["sigmaf", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmar"}]], "+", 
                  "sigmar", "-", 
                  RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"T", "+", "Tc1"}]], " ", "sigmar"}]}], ")"}]}], 
               "-", 
               RowBox[{"sigmaf", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmar"}]], "+", 
                  SuperscriptBox["sigmar", "2"], "-", 
                  RowBox[{
                   SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"T", "+", "Tc1"}]], " ", 
                   SuperscriptBox["sigmar", "2"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"UnitStep", "[", 
           RowBox[{
            RowBox[{"-", "T"}], "-", "Tc1"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", "sigmaf", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", "sigmar"}], 
         ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmaf"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmaf"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmaf"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "t"}], "+", "T", "+", "Tc1"}], ")"}], " ", 
              "sigmaf"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}]}], "sigmaf"], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmar"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"T", "+", "Tc1"}], ")"}], " ", "sigmar"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmar"}]], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"T", "+", "Tc1"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "t"}], "+", "T", "+", "Tc1"}], ")"}], " ", 
              "sigmar"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "sigmar"], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{"sigmaf", " ", "sigmar"}]]}], ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"t", "-", "T", "-", "Tc1"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "T"}], "+", "Tc1"}], ")"}], " ", "sigmaf"}]], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "V00", "-", 
              RowBox[{"V00", " ", "sigmaf"}], "+", 
              RowBox[{"Vr", " ", "sigmaf"}]}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", "sigmaf"}]], 
          "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "T"}], "+", "Tc1"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{"sigmaf", " ", "sigmar"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "T"}], "+", "Tc1"}], ")"}], " ", "sigmar"}]], 
            " ", 
            RowBox[{"(", 
             RowBox[{"I0", "+", 
              RowBox[{"V00", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}], "-", 
              RowBox[{"Vr", " ", "sigmar"}]}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", "sigmar"}]]}], 
         ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"T", "-", "Tc1"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmaf"}], "-", 
              RowBox[{"T", " ", "sigmaf"}], "+", 
              RowBox[{"Tc1", " ", "sigmaf"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmaf"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "sigmaf"}], 
               ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "sigmaf"], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmar"}], "-", 
              RowBox[{"T", " ", "sigmar"}], "+", 
              RowBox[{"Tc1", " ", "sigmar"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmar"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "T"}], "+", "Tc1"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", "T", "-", "Tc1"}], ")"}], " ", "sigmar"}], 
               ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}]}], "sigmar"], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{"sigmaf", " ", "sigmar"}]]}], ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"t", "+", "T", "-", "Tc1"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}], ")"}], " ", 
              "sigmaf"}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "V00", "-", 
              RowBox[{"V00", " ", "sigmaf"}], "+", 
              RowBox[{"Vr", " ", "sigmaf"}]}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", "sigmaf"}]], 
          "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{"sigmaf", " ", "sigmar"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}], ")"}], " ", 
              "sigmar"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "+", 
              RowBox[{"V00", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}], "-", 
              RowBox[{"Vr", " ", "sigmar"}]}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", "sigmar"}]]}], 
         ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{
          RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmaf"}], "-", 
              RowBox[{"2", " ", "T", " ", "sigmaf"}], "+", 
              RowBox[{"Tc1", " ", "sigmaf"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmaf"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", 
                  RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
                "sigmaf"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "V00"}], ")"}]}], "sigmaf"], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"t", "-", 
              RowBox[{"t", " ", "sigmar"}], "-", 
              RowBox[{"2", " ", "T", " ", "sigmar"}], "+", 
              RowBox[{"Tc1", " ", "sigmar"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "I0"}], "+", "Vr"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmar"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "T"}], "+", "Tc1"}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "Vr"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t", "+", 
                  RowBox[{"2", " ", "T"}], "-", "Tc1"}], ")"}], " ", 
                "sigmar"}], ")"}]}]], " ", 
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}]}], "sigmar"], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"I0", "-", "V00"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], 
           RowBox[{"sigmaf", " ", "sigmar"}]]}], ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"t", "+", 
          RowBox[{"2", " ", "T"}], "-", "Tc1"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", "t"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Vr", " ", "sigmaf", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"Tc1", " ", "sigmar"}]]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
                RowBox[{"(", 
                 RowBox[{"sigmaf", "-", "sigmar"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"Tc1", " ", "sigmaf"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "sigmar"}], ")"}]}]}], ")"}], " ", 
             "sigmar"}], "+", 
            RowBox[{"V00", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"Tc1", " ", "sigmar"}]]}], ")"}], " ", "sigmaf"}], 
               "+", "sigmar", "-", 
               RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"Tc1", " ", "sigmaf"}]], " ", "sigmar"}]}], ")"}]}], 
            "+", 
            RowBox[{"I0", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"Tc1", " ", "sigmaf"}]]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", 
                  "sigmar"}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["sigmaf", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"Tc1", " ", "sigmar"}]], "+", "sigmar", "-", 
                  RowBox[{
                   SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
                   "sigmar"}]}], ")"}]}], "-", 
               RowBox[{"sigmaf", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"Tc1", " ", "sigmar"}]], "+", 
                  SuperscriptBox["sigmar", "2"], "-", 
                  RowBox[{
                   SuperscriptBox["\[ExponentialE]", "Tc1"], " ", 
                   SuperscriptBox["sigmar", "2"]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"UnitStep", "[", 
           RowBox[{"-", "Tc1"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmaf"}], ")"}], " ", "sigmaf", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "sigmar"}], ")"}], " ", "sigmar"}], 
         ")"}]}]}], ")"}]}]}]}], "]"}]], "Output",
 CellChangeTimes->{3.807091147859133*^9, 3.807091316902646*^9, 
  3.8070920359905043`*^9, 3.8070927088979397`*^9, 3.825425167753996*^9, 
  3.825425209654872*^9, 3.828107418303536*^9, 3.828716993317265*^9, 
  3.828717711830789*^9, 3.832075170061553*^9, 3.8320854237681093`*^9, 
  3.8393248415330763`*^9, 3.852137409868311*^9, 3.852138177949377*^9, 
  3.852143177609371*^9, 3.852293280313553*^9, 3.8522942405101967`*^9, 
  3.852327522551021*^9, 3.8523282096920958`*^9, 3.852364130444437*^9, 
  3.8523651996261253`*^9, 3.85236684812368*^9, 3.8537461715783787`*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"4fde3405-dd82-423e-91cf-4a3f1e384968"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gc1", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.807091606048018*^9, 3.8070916100164347`*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"fb6f1ea3-3479-43bd-8cdc-8dc1fb403361"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]f"}], ")"}]}]], "-", 
    
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "-", "Tc1"}], ")"}], " ", "\[Sigma]r"}], ")"}]}]]}], 
   ")"}], " ", "gc01", " ", 
  RowBox[{"UnitStep", "[", 
   RowBox[{"t", "-", "Tc1"}], "]"}]}]], "Output",
 CellChangeTimes->{3.807091610498316*^9, 3.807092036061652*^9, 
  3.8070927089192*^9, 3.825425167854229*^9, 3.825425209661633*^9, 
  3.82810741831179*^9, 3.828716993342495*^9, 3.828717711893956*^9, 
  3.8320751701104*^9, 3.832085423807707*^9, 3.839324841582727*^9, 
  3.8521374099275208`*^9, 3.852138178034642*^9, 3.852143177637059*^9, 
  3.8522932803553553`*^9, 3.852294240554061*^9, 3.852327522598528*^9, 
  3.852328209733341*^9, 3.852364130456808*^9, 3.8523651996579857`*^9, 
  3.8523668481551847`*^9, 3.853746172196361*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"c8ada77f-6569-4ecf-a2f3-d02d11033429"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"V10", "/.", "defV10"}], "/.", "degreek"}], "/.", 
     RowBox[{"gamma", "\[Rule]", "1"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"UnitStep", "[", "_", "]"}], ",", "g0", ",", "gc01", ",", "va", 
      ",", "DeltaV", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"UnitStep", "[", "_", "]"}], "^", "_."}], 
       RowBox[{"g0", "^", "_."}], 
       RowBox[{"gc01", "^", "_."}], 
       RowBox[{"va", "^", "_."}], 
       RowBox[{"DeltaV", "^", "_."}]}]}], "}"}], ",", "Simplify"}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8070960344717617`*^9, 3.80709603638132*^9}, {
   3.807096146652301*^9, 3.807096157110025*^9}, {3.807096189276622*^9, 
   3.8070961974195147`*^9}, {3.807096512175549*^9, 3.80709651525025*^9}, {
   3.807096546885263*^9, 3.80709654845514*^9}, {3.807096693369879*^9, 
   3.8070966977262297`*^9}, {3.8070970966101217`*^9, 3.807097135577487*^9}, {
   3.807097168580559*^9, 3.8070971726489058`*^9}, {3.8070972326618032`*^9, 
   3.80709723465981*^9}, {3.807097275563711*^9, 3.807097289821444*^9}, {
   3.807097322181047*^9, 3.807097323370043*^9}, 3.852326894859586*^9},
 CellLabel->
  "In[104]:=",ExpressionUUID->"cee7f10d-6bbb-497c-967f-48d22116b4c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Write", " ", "results", " ", "to", " ", "matlab", " ", "for", " ", 
    "numerical", " ", "evaluation"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"fid", "=", 
    RowBox[{
    "OpenWrite", "[", 
     "\"\<~hermann/Dropbox/Zebrafish_Spine/twosegmentsraw.m\>\"", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"WriteMatlab", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"I0", "/.", "defI0"}], "/.", "degreek"}], ",", "fid", ",", 
     "I0"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"WriteMatlab", "[", 
    RowBox[{"I1matlab", ",", "fid", ",", "I1"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"WriteMatlab", "[", 
    RowBox[{"I1matlab0", ",", "fid", ",", "I10"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"index", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"index", "<=", 
      RowBox[{"Length", "[", "parts", "]"}]}], ",", 
     RowBox[{
      RowBox[{"WriteMatlab", "[", 
       RowBox[{
        RowBox[{"Collect", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Expand", "[", 
            RowBox[{"parts", "[", 
             RowBox[{"[", "index", "]"}], "]"}], "]"}], "/.", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"(", "a_", ")"}]}], "\[RuleDelayed]", 
            RowBox[{"E", "^", 
             RowBox[{"Simplify", "[", "a", "]"}]}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"gc01", ",", "DeltaV", ",", "Vr", ",", "va", ",", 
            RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}]}], "]"}], ",", "fid",
         ",", 
        RowBox[{"I1parts", "[", "index", "]"}]}], "]"}], ";", 
      RowBox[{"Print", "[", "index", "]"}], ";", 
      RowBox[{"index", "++"}]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v01", "[", "t", "]"}], "/.", "defv01"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v01"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v02", "[", "t", "]"}], "/.", "defv02"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v02"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v03", "[", "t", "]"}], "/.", "defv03"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v03"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v04", "[", "t", "]"}], "/.", "defv04"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v04"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v11", "[", "t", "]"}], "/.", "defv11"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v11"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v12", "[", "t", "]"}], "/.", "defv12"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v12"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v13", "[", "t", "]"}], "/.", "defv13"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v13"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"v14", "[", "t", "]"}], "/.", "defv14"}], "/.", "degreek"}], 
       "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "v14"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"gc1", "[", "t", "]"}], "/.", "degreek"}], "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "gc1"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"V00", "/.", "defV00"}], "/.", "degreek"}], "/.", 
       RowBox[{"gamma", "\[Rule]", "1"}]}], ",", "fid", ",", "V00"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WriteMatlab", "[", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"V10", "/.", "defV10"}], "/.", "degreek"}], "/.", 
         RowBox[{"gamma", "\[Rule]", "1"}]}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"UnitStep", "[", "_", "]"}], ",", "g0", ",", "gc01", ",", 
          "va", ",", "DeltaV", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"UnitStep", "[", "_", "]"}], "^", "_."}], 
           RowBox[{"g0", "^", "_."}], 
           RowBox[{"gc01", "^", "_."}], 
           RowBox[{"va", "^", "_."}], 
           RowBox[{"DeltaV", "^", "_."}]}]}], "}"}], ",", "Simplify"}], "]"}],
       ",", "fid", ",", "V10"}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Close", "[", "fid", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8038938084666348`*^9, 3.803893857054811*^9}, 
   3.803894534325828*^9, {3.803894605290278*^9, 3.803894663358822*^9}, {
   3.803894699303299*^9, 3.803894726117086*^9}, {3.8038948685526743`*^9, 
   3.803894870667057*^9}, {3.803895437464922*^9, 3.8038954393240356`*^9}, {
   3.803898140823327*^9, 3.803898141098283*^9}, {3.8039176959895163`*^9, 
   3.8039176984686623`*^9}, 3.8039183723958693`*^9, {3.803923392675767*^9, 
   3.80392341321177*^9}, {3.8039234640983067`*^9, 3.803923529147132*^9}, {
   3.803926399683234*^9, 3.803926449718635*^9}, {3.803926578516795*^9, 
   3.803926579065456*^9}, {3.8039266531783943`*^9, 3.803926661327538*^9}, {
   3.803926821490307*^9, 3.8039268409373713`*^9}, {3.803926935134781*^9, 
   3.803926957196705*^9}, {3.804270796362314*^9, 3.804270799265711*^9}, {
   3.807091358934029*^9, 3.807091435759301*^9}, {3.8070916190985126`*^9, 
   3.807091634596591*^9}, {3.8070938581069717`*^9, 3.8070939053179207`*^9}, {
   3.8070940101916943`*^9, 3.8070940190427933`*^9}, {3.807095765217787*^9, 
   3.807095838565411*^9}, {3.807097476337797*^9, 3.807097490473852*^9}, {
   3.852293462264984*^9, 3.852293479111865*^9}, {3.852327438407897*^9, 
   3.852327439170703*^9}, {3.852327620592457*^9, 3.852327621140667*^9}, {
   3.8523276517851257`*^9, 3.8523276542082*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"f8023d9b-83b5-48ba-8e2b-290f08d92314"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["OutputStream",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.0016806722689075631`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               RGBColor[0.699951, 0.699951, 0.699951], 
               Opacity[1.], 
               JoinForm[{ElisionsDump`Miter, 10.}], 
               
               JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{3.52539, 
                1.0035199999999997`}, {2.5250000000000004`, 
                1.0035199999999997`}, {1.6828099999999997`, 
                1.0035199999999997`}, {0.9999999999999999, 
                1.6863299999999997`}, {0.9999999999999999, 
                2.5285199999999994`}, {0.9999999999999999, 
                23.474999999999998`}, {0.9999999999999999, 
                24.317199999999996`}, {1.6828099999999997`, 
                24.999999999999996`}, {2.5250000000000004`, 
                24.999999999999996`}, {3.52539, 24.999999999999996`}, {
                3.52539, 24.999999999999993`}, {5.523440000000001, 
                22.421099999999996`}, {5.523440000000001, 13.0039}, {
                5.523440000000001, 3.5867199999999992`}, {3.52539, 
                1.0035199999999997`}, {3.52539, 1.0035199999999997`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}}}, {{{22.4977, 12.9016}, {
                17.740599999999997`, 16.8398}, {17.740599999999997`, 
                14.856599999999998`}, {19.980900000000002`, 
                12.947299999999997`}, {17.740599999999997`, 
                10.946100000000001`}, {17.740599999999997`, 8.96289}, {
                22.4977, 12.9016}}}]}, {
               FaceForm[{
                 RGBColor[
                 0.46093800000000007`, 0.46093800000000007`, 
                  0.46093800000000007`], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{9.202339999999998, 12.8969}, {9.202339999999998, 
                12.335499999999998`}, {8.747660000000002, 
                11.880899999999999`}, {8.186329999999998, 
                11.880899999999999`}, {7.624999999999999, 
                11.880899999999999`}, {7.169920000000001, 
                12.335499999999998`}, {7.169920000000001, 12.8969}, {
                7.169920000000001, 13.458200000000003`}, {7.624999999999999, 
                13.9133}, {8.186329999999998, 13.9133}, {8.747660000000002, 
                13.9133}, {9.202339999999998, 13.458200000000003`}, {
                9.202339999999998, 12.8969}}}], 
               
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{12.6227, 12.8969}, {12.6227, 12.335499999999998`}, {
                12.167599999999998`, 11.880899999999999`}, {
                11.606200000000001`, 11.880899999999999`}, {11.0449, 
                11.880899999999999`}, {10.589799999999999`, 
                12.335499999999998`}, {10.589799999999999`, 12.8969}, {
                10.589799999999999`, 13.458200000000003`}, {11.0449, 
                13.9133}, {11.606200000000001`, 13.9133}, {
                12.167599999999998`, 13.9133}, {12.6227, 
                13.458200000000003`}, {12.6227, 12.8969}}}], 
               
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{16.042600000000004`, 12.8969}, {16.042600000000004`, 
                12.335499999999998`}, {15.587499999999999`, 
                11.880899999999999`}, {15.026199999999998`, 
                11.880899999999999`}, {14.464799999999997`, 
                11.880899999999999`}, {14.010199999999998`, 
                12.335499999999998`}, {14.010199999999998`, 12.8969}, {
                14.010199999999998`, 13.458200000000003`}, {
                14.464799999999997`, 13.9133}, {15.026199999999998`, 
                13.9133}, {15.587499999999999`, 13.9133}, {
                16.042600000000004`, 13.458200000000003`}, {
                16.042600000000004`, 12.8969}}}]}}, AspectRatio -> 1, Axes -> 
             False, Background -> GrayLevel[0.5], Frame -> True, FrameStyle -> 
             Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]], FrameTicks -> None, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Name: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  StyleBox[
                   PaneBox[
                   "\"twosegmentsraw.m\"", ContentPadding -> False, 
                    FrameMargins -> 0, StripOnInput -> True, BaselinePosition -> 
                    Baseline, ImageSize -> {{1, 300}, Automatic}], 
                   LineBreakWithin -> False], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Unique ID: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.0016806722689075631`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               RGBColor[0.699951, 0.699951, 0.699951], 
               Opacity[1.], 
               JoinForm[{ElisionsDump`Miter, 10.}], 
               
               JoinedCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}}}, {{{3.52539, 
                1.0035199999999997`}, {2.5250000000000004`, 
                1.0035199999999997`}, {1.6828099999999997`, 
                1.0035199999999997`}, {0.9999999999999999, 
                1.6863299999999997`}, {0.9999999999999999, 
                2.5285199999999994`}, {0.9999999999999999, 
                23.474999999999998`}, {0.9999999999999999, 
                24.317199999999996`}, {1.6828099999999997`, 
                24.999999999999996`}, {2.5250000000000004`, 
                24.999999999999996`}, {3.52539, 24.999999999999996`}, {
                3.52539, 24.999999999999993`}, {5.523440000000001, 
                22.421099999999996`}, {5.523440000000001, 13.0039}, {
                5.523440000000001, 3.5867199999999992`}, {3.52539, 
                1.0035199999999997`}, {3.52539, 1.0035199999999997`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}}}, {{{22.4977, 12.9016}, {
                17.740599999999997`, 16.8398}, {17.740599999999997`, 
                14.856599999999998`}, {19.980900000000002`, 
                12.947299999999997`}, {17.740599999999997`, 
                10.946100000000001`}, {17.740599999999997`, 8.96289}, {
                22.4977, 12.9016}}}]}, {
               FaceForm[{
                 RGBColor[
                 0.46093800000000007`, 0.46093800000000007`, 
                  0.46093800000000007`], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{9.202339999999998, 12.8969}, {9.202339999999998, 
                12.335499999999998`}, {8.747660000000002, 
                11.880899999999999`}, {8.186329999999998, 
                11.880899999999999`}, {7.624999999999999, 
                11.880899999999999`}, {7.169920000000001, 
                12.335499999999998`}, {7.169920000000001, 12.8969}, {
                7.169920000000001, 13.458200000000003`}, {7.624999999999999, 
                13.9133}, {8.186329999999998, 13.9133}, {8.747660000000002, 
                13.9133}, {9.202339999999998, 13.458200000000003`}, {
                9.202339999999998, 12.8969}}}], 
               
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{12.6227, 12.8969}, {12.6227, 12.335499999999998`}, {
                12.167599999999998`, 11.880899999999999`}, {
                11.606200000000001`, 11.880899999999999`}, {11.0449, 
                11.880899999999999`}, {10.589799999999999`, 
                12.335499999999998`}, {10.589799999999999`, 12.8969}, {
                10.589799999999999`, 13.458200000000003`}, {11.0449, 
                13.9133}, {11.606200000000001`, 13.9133}, {
                12.167599999999998`, 13.9133}, {12.6227, 
                13.458200000000003`}, {12.6227, 12.8969}}}], 
               
               FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                3}}}, {{{16.042600000000004`, 12.8969}, {16.042600000000004`, 
                12.335499999999998`}, {15.587499999999999`, 
                11.880899999999999`}, {15.026199999999998`, 
                11.880899999999999`}, {14.464799999999997`, 
                11.880899999999999`}, {14.010199999999998`, 
                12.335499999999998`}, {14.010199999999998`, 12.8969}, {
                14.010199999999998`, 13.458200000000003`}, {
                14.464799999999997`, 13.9133}, {15.026199999999998`, 
                13.9133}, {15.587499999999999`, 13.9133}, {
                16.042600000000004`, 13.458200000000003`}, {
                16.042600000000004`, 12.8969}}}]}}, AspectRatio -> 1, Axes -> 
             False, Background -> GrayLevel[0.5], Frame -> True, FrameStyle -> 
             Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]], FrameTicks -> None, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Name: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"/Users/hermann/Dropbox/Zebrafish_Spine/twosegmentsraw.m\"\
", ImageSize -> {{1, 500}, Automatic}, BaselinePosition -> Baseline, 
                   ContentPadding -> False, FrameMargins -> 0, StripOnInput -> 
                   True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Unique ID: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Binary: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Open: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  DynamicBox[
                   ToBoxes[Options[
                    OutputStream[
                    "/Users/hermann/Dropbox/Zebrafish_Spine/twosegmentsraw.m",
                     3]] =!= {}, StandardForm], UpdateInterval -> 1], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Encoding: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["Automatic", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Format: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["InputForm", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Page width: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["78", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Number marks: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["Automatic", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  OutputStream["/Users/hermann/Dropbox/Zebrafish_Spine/twosegmentsraw.m", 3],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.80389474388664*^9, 3.803894803988634*^9}, 
   3.803894871720924*^9, 3.803895392000133*^9, 3.803895441528029*^9, 
   3.803898091438677*^9, 3.803898304923728*^9, 3.8039176992574377`*^9, 
   3.803917987561924*^9, {3.80391836396566*^9, 3.8039183744874563`*^9}, 
   3.803923413984091*^9, 3.8039234672702427`*^9, 3.803923532615513*^9, 
   3.8039264434838457`*^9, 3.803926580794692*^9, 3.803926663477153*^9, 
   3.803926842035614*^9, {3.803926943386792*^9, 3.803926958525672*^9}, 
   3.803979086571176*^9, 3.8042704047484503`*^9, 3.8042709258777227`*^9, 
   3.804446436297817*^9, 3.804503434619959*^9, 3.804529668990735*^9, 
   3.804598629782165*^9, 3.805045151176467*^9, 3.805045375776457*^9, 
   3.806938070374083*^9, 3.807091713612821*^9, 3.807092036149287*^9, 
   3.8070927089873543`*^9, 3.807093912395042*^9, 3.807094022421529*^9, 
   3.807095844432865*^9, 3.807098014569434*^9, 3.825425168893433*^9, 
   3.825425210670665*^9, 3.828107419420126*^9, 3.828717076928227*^9, 
   3.8287177252910357`*^9, 3.832075179938656*^9, 3.832085433814042*^9, 
   3.83932485154706*^9, 3.8521374571682243`*^9, 3.852138225190247*^9, 
   3.852143222337285*^9, 3.8522932904008493`*^9, 3.852294250572749*^9, 
   3.8523275316195087`*^9, 3.8523276779737587`*^9, 3.852328218709683*^9, 
   3.852364139863649*^9, 3.852365249578017*^9, 3.852366893118402*^9, 
   3.853746225637105*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"11c01fe3-6e0b-4484-9445-531820021e08"],

Cell[CellGroupData[{

Cell[BoxData["1"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226183674*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"379ab4b3-34d9-439b-afba-3d183ab18d64"],

Cell[BoxData["2"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226281023*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"7b1a3e1e-3cd2-4884-ad8c-8f376846ee19"],

Cell[BoxData["3"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.8537462262861567`*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"2908eb9d-79b5-4d74-a3ce-d05e3f8fbdb4"],

Cell[BoxData["4"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226287689*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"96f62046-7828-4244-a445-c1a0a8b4c174"],

Cell[BoxData["5"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226289235*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"bc003454-f956-41fc-bed8-4ccbdc7cf60c"],

Cell[BoxData["6"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226290868*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"55e1f5ed-04a4-4462-81ea-5afd108c7dcf"],

Cell[BoxData["7"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226292511*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"711d1c33-f110-44c7-8687-4c486f6ebfb5"],

Cell[BoxData["8"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226294392*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"aa96cdd4-74e7-4083-97a7-61eeb3bff8cb"],

Cell[BoxData["9"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226397995*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"914a67b0-9180-4e4e-9357-b337a7da535e"],

Cell[BoxData["10"], "Print",
 CellChangeTimes->{
  3.8039266643396873`*^9, 3.803926842157816*^9, {3.803926943523622*^9, 
   3.803926958661776*^9}, 3.80397908666214*^9, 3.80427040485535*^9, 
   3.804270925978368*^9, 3.804446436387762*^9, 3.804503434732624*^9, 
   3.804529669167183*^9, 3.804598629863405*^9, 3.805045151280719*^9, 
   3.805045375896174*^9, 3.80693807060928*^9, 3.8070917137070227`*^9, 
   3.807092036247621*^9, 3.807092709074909*^9, 3.8070939124859037`*^9, 
   3.8070940225151987`*^9, 3.807095844511333*^9, 3.80709801466608*^9, 
   3.825425168971695*^9, 3.825425210679558*^9, 3.8281074195015497`*^9, 
   3.828717077009529*^9, 3.8287177253702497`*^9, 3.8320751799941597`*^9, 
   3.832085433867194*^9, 3.839324851602721*^9, 3.852137457256735*^9, 
   3.852138225279456*^9, 3.852143222431108*^9, 3.85229329045612*^9, 
   3.852294250630546*^9, 3.852327531687463*^9, 3.8523276780424023`*^9, 
   3.852328218779745*^9, 3.852364139929446*^9, 3.852365249679386*^9, 
   3.852366893224127*^9, 3.853746226400236*^9},
 CellLabel->
  "During evaluation of \
In[105]:=",ExpressionUUID->"4aeef5aa-42b5-449f-aab7-8bce99a738a7"]
}, Open  ]],

Cell[BoxData["\<\"/Users/hermann/Dropbox/Zebrafish_Spine/twosegmentsraw.m\"\>\
"], "Output",
 CellChangeTimes->{{3.80389474388664*^9, 3.803894803988634*^9}, 
   3.803894871720924*^9, 3.803895392000133*^9, 3.803895441528029*^9, 
   3.803898091438677*^9, 3.803898304923728*^9, 3.8039176992574377`*^9, 
   3.803917987561924*^9, {3.80391836396566*^9, 3.8039183744874563`*^9}, 
   3.803923413984091*^9, 3.8039234672702427`*^9, 3.803923532615513*^9, 
   3.8039264434838457`*^9, 3.803926580794692*^9, 3.803926663477153*^9, 
   3.803926842035614*^9, {3.803926943386792*^9, 3.803926958525672*^9}, 
   3.803979086571176*^9, 3.8042704047484503`*^9, 3.8042709258777227`*^9, 
   3.804446436297817*^9, 3.804503434619959*^9, 3.804529668990735*^9, 
   3.804598629782165*^9, 3.805045151176467*^9, 3.805045375776457*^9, 
   3.806938070374083*^9, 3.807091713612821*^9, 3.807092036149287*^9, 
   3.8070927089873543`*^9, 3.807093912395042*^9, 3.807094022421529*^9, 
   3.807095844432865*^9, 3.807098014569434*^9, 3.825425168893433*^9, 
   3.825425210670665*^9, 3.828107419420126*^9, 3.828717076928227*^9, 
   3.8287177252910357`*^9, 3.832075179938656*^9, 3.832085433814042*^9, 
   3.83932485154706*^9, 3.8521374571682243`*^9, 3.852138225190247*^9, 
   3.852143222337285*^9, 3.8522932904008493`*^9, 3.852294250572749*^9, 
   3.8523275316195087`*^9, 3.8523276779737587`*^9, 3.852328218709683*^9, 
   3.852364139863649*^9, 3.852365249578017*^9, 3.852366893118402*^9, 
   3.8537462407285547`*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"ad80dbc1-b7ea-428f-9196-e4663292b402"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{"defI1", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"UnitStep", "[", "_", "]"}], ",", "gc01", ",", "\[Gamma]", ",", 
      " ", "g0", ",", "va", ",", "\[CapitalDelta]V", ",", "\[Psi]"}], "}"}], 
    ",", "Simplify"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defI1numb", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"%", "/.", "defgc01"}], "/.", "defnumb"}], "/.", "defnumb"}], 
      "/.", "defnumb"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "\[Gamma]", ",", " ", "gcn", 
       ",", "g0", ",", "va"}], "}"}], ",", "Simplify"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defI1e", "=", 
   RowBox[{"defI1numb", "/.", 
    RowBox[{"Tc1", "\[Rule]", 
     RowBox[{"\[CapitalDelta]", "-", 
      RowBox[{"2", "\[Phi]", " ", "T"}]}]}]}]}], ";"}]}], "Input",
 CellLabel->
  "In[123]:=",ExpressionUUID->"769078c4-53d7-40ce-821e-6954d419c919"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"V01a", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v01", "[", "t", "]"}], "/.", "defv01"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], "/.", "defnuma"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V02a", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v02", "[", "t", "]"}], "/.", "defv02"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], "/.", "defnuma"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V03a", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v03", "[", "t", "]"}], "/.", "defv03"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], "/.", "defnuma"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V04a", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v04", "[", "t", "]"}], "/.", "defv04"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], "/.", "defnuma"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V11a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v11", "[", "t", "]"}], "/.", "defv11"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnuma"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V12a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v12", "[", "t", "]"}], "/.", "defv12"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnuma"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V13a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v13", "[", "t", "]"}], "/.", "defv13"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnuma"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V14a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v14", "[", "t", "]"}], "/.", "defv14"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnuma"}], "/.", "defnuma"}], "/.", 
      "defnuma"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.797772147054212*^9, 3.797772196580112*^9}, {
   3.797772265997737*^9, 3.79777234956919*^9}, {3.797772429221787*^9, 
   3.7977724331666107`*^9}, {3.797772465041727*^9, 3.79777250290536*^9}, {
   3.7977725488227663`*^9, 3.797772652528284*^9}, {3.797772701310975*^9, 
   3.79777276093808*^9}, {3.797773284602642*^9, 3.797773396333815*^9}, {
   3.797773463311829*^9, 3.79777350797299*^9}, {3.797773650531926*^9, 
   3.7977736564516163`*^9}, 3.797773694719648*^9, {3.797774893778529*^9, 
   3.7977748948356533`*^9}, {3.79777495522118*^9, 3.797774956766889*^9}, {
   3.7977750461650248`*^9, 3.797775047085772*^9}, {3.797776232981812*^9, 
   3.797776275715522*^9}, {3.7977763264445877`*^9, 3.7977764143128033`*^9}, {
   3.797776504236657*^9, 3.7977765257359943`*^9}, {3.797776622580469*^9, 
   3.797776768370297*^9}, {3.7977768184305553`*^9, 3.797776827462613*^9}, {
   3.797776875992424*^9, 3.79777691659385*^9}, {3.7977769931018133`*^9, 
   3.7977770028796473`*^9}, {3.797777101184779*^9, 3.797777237888777*^9}, {
   3.797788779949814*^9, 3.7977888065715714`*^9}, {3.7977888885554743`*^9, 
   3.797788889566066*^9}, {3.797788926673805*^9, 3.797788943929202*^9}, {
   3.797788979659156*^9, 3.7977890545409718`*^9}, {3.797789087258276*^9, 
   3.797789091571568*^9}, {3.797789168680793*^9, 3.797789200714191*^9}, {
   3.797789244877307*^9, 3.797789271543898*^9}, {3.797789337333045*^9, 
   3.797789347034181*^9}, {3.797789399402878*^9, 3.797789401472487*^9}, {
   3.7977926452316217`*^9, 3.7977926463145247`*^9}, {3.7978446604722977`*^9, 
   3.797844667243247*^9}, {3.797850505509376*^9, 3.797850512752988*^9}, {
   3.7978527712737503`*^9, 3.7978527914830236`*^9}, {3.797859564266468*^9, 
   3.7978595693767433`*^9}, {3.797859707041148*^9, 3.797859713015132*^9}, {
   3.797942264625979*^9, 3.797942317168138*^9}, {3.79794889810375*^9, 
   3.797948911954324*^9}, {3.797948945701316*^9, 3.7979489512655277`*^9}, {
   3.798846601399407*^9, 3.7988466184030027`*^9}, {3.798846687870954*^9, 
   3.798846733378467*^9}, {3.798851007891026*^9, 3.798851009154398*^9}, {
   3.799061498361374*^9, 3.799061499568959*^9}, {3.804407787616127*^9, 
   3.80440780079465*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"68061e1a-25e1-4db7-9a27-6ec98ebea197"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"V11a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V11a", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V12a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V12a", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V13a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V13a", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V14a", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V14a", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.799077233705367*^9, 3.799077247165496*^9}, {
  3.804407821472856*^9, 3.8044078354482393`*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"80b134b3-4c03-4432-a631-e1beacb79dcf"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"V01b", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v01", "[", "t", "]"}], "/.", "defv01"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], "/.", "defnumb"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V02b", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v02", "[", "t", "]"}], "/.", "defv02"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], "/.", "defnumb"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V03b", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v03", "[", "t", "]"}], "/.", "defv03"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], "/.", "defnumb"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V04b", "[", "t_", "]"}], "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v04", "[", "t", "]"}], "/.", "defv04"}], "/.", "defV00"}],
          "/.", "defI0"}], "/.", "defgc01"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], "/.", "defnumb"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V11b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v11", "[", "t", "]"}], "/.", "defv11"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnumb"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V12b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v12", "[", "t", "]"}], "/.", "defv12"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnumb"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V13b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v13", "[", "t", "]"}], "/.", "defv13"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnumb"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V14b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"v14", "[", "t", "]"}], "/.", "defv14"}], "/.", 
             "defV10"}], "/.", "defI0"}], "/.", "defI1"}], "/.", "defV00"}], "/.",
          "defgc01"}], "/.", "defnumb"}], "/.", "defnumb"}], "/.", 
      "defnumb"}], ",", 
     RowBox[{"{", 
      RowBox[{"gc01", ",", 
       RowBox[{"UnitStep", "[", "_", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.798846815210807*^9, 3.7988468659816847`*^9}, {
  3.799060721495758*^9, 3.7990607226030817`*^9}, {3.799060805677445*^9, 
  3.799060806910324*^9}, {3.804407805078079*^9, 3.8044078157627172`*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"6a6d3f24-4e91-4ff2-aaff-96c913939b76"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"V11b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V11b", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V12b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V12b", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V13b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V13b", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V14b", "[", "t_", "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Expand", "[", 
        RowBox[{"V14b", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Exp", "[", "_", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"UnitStep", "[", "_", "]"}], ",", "gcn"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7990606070133133`*^9, 3.7990606494347677`*^9}, {
   3.799060730710782*^9, 3.799060747658866*^9}, {3.799060824150709*^9, 
   3.799060855838335*^9}, {3.7990609794171762`*^9, 3.79906098089515*^9}, 
   3.79906102235245*^9, {3.804407837797303*^9, 3.80440784861327*^9}, {
   3.804421987128606*^9, 3.804422026369192*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"463c41e2-e317-4e2f-9ebb-8bdf07ea1ab7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"relation", " ", "between", " ", "\[Phi]", " ", "and", " ", 
     RowBox[{"T", ".", " ", "I1hat"}], " ", "is", " ", "the", " ", "total", 
     " ", "current", " ", "into", " ", "segment", " ", "3"}], ",", " ", 
    RowBox[{
    "which", " ", "is", " ", "kept", " ", "constant", " ", "in", " ", "the", 
     " ", "simulations", " ", "I0", " ", "is", " ", "changed", " ", "to", " ",
      "change", " ", "the", " ", 
     RowBox[{"period", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"I1hat", "[", "T_", "]"}], "=", 
   RowBox[{
    RowBox[{"I0", "[", "T", "]"}], "+", " ", 
    RowBox[{"I1", "[", 
     RowBox[{"T", ",", 
      RowBox[{"\[Phi]", "[", "T", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.800868596836813*^9, 3.800868699333144*^9}, {
   3.800868873776671*^9, 3.800868897107633*^9}, 3.800871401599614*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"26186c48-d4ca-425f-b029-7dbb1a8902bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"I0", "[", "T", "]"}], "+", 
  RowBox[{"I1", "[", 
   RowBox[{"T", ",", 
    RowBox[{"\[Phi]", "[", "T", "]"}]}], "]"}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0l1Ik3EUBvCZH6VWflC41BCJSi8qP9K9E2u+ZWS2yo05tdDUVQ6SzZqu
kZXCaFjMlYXa6sKlMyMlh0tdmS6lNqdrF1lEKq0iceDbkshaEtXz7+Lwg4dz
dZ4TXy4XnvRjsVhiTKVaEtAsYGhqz6YQomB4Mo4o93NdILLTbcv/88NzqS1Q
JhPsInoyOR/aIWfRudcIpc9+Hid6Ppcf7YSWyWA90XN1ynUPBs0d5HXBV7rw
GuKUMr55DM7UbjS8gFun7TIbfD0xvuCAPYsdMRNw9o7BohQydMB8b5kKrpNW
26LyGbo64WsuG8bEtZk2wIahMitxNsnuS4EfQy92psG8bPYSsTI3opdD9qYp
jhveL/3yLlDM0CsrtSIu9Ok7NMSRmbagTFgfKbRkwXGvITUb/slz9u+D3v4W
O3FMI9GVwGWt1UZ01wZcPwWfGt9zKqBp6ZGHeLbriEkGczaLfhPP9FANjfD7
TOI3HdRKXcnXIP+v+xzxE9ftDi5g6OiGH3fDYbs5UbEDZm2TpadAGy+QuxPm
6d+qKdgXIVrIgL+G69J4MMlRa1XDE+HZKyILGVrVuqVXBMVcZ0g+LEhVD6qh
MmqE2wdjg1cd0xYxdMUbStEIn8vrNQnFDK2jLpkUcO18k3811DvqJKfrGbqm
MFZK3P9w9/orl3HvgUFXn4ahUw7cjDLD0SeUKroRPTrCiry38Tf8Kk2JmaHj
mh57iOxRs7gMtrIibz2AGd3esG64+lCOcQjyeTe2v4QtpaFWosXfp3PB88XJ
a6oGGPofNCla/w==
  "],
 CellLabel->
  "Out[150]=",ExpressionUUID->"7d7c9378-e226-45d2-9295-22e28323f8b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"I1hat", "[", "T", "]"}], ",", "T"}], "]"}], "\[Equal]", 
  "0"}]], "Input",
 CellChangeTimes->{{3.800868951737721*^9, 3.800868957548811*^9}},
 CellLabel->
  "In[151]:=",ExpressionUUID->"5c1e8768-f71c-4147-8412-51934ecb86c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["I0", "\[Prime]",
     MultilineFunction->None], "[", "T", "]"}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "T", "]"}], " ", 
    RowBox[{
     SuperscriptBox["I1", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", 
      RowBox[{"\[Phi]", "[", "T", "]"}]}], "]"}]}], "+", 
   RowBox[{
    SuperscriptBox["I1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", 
     RowBox[{"\[Phi]", "[", "T", "]"}]}], "]"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz1tIE2AABeBpKXnJy8SmNomRpSAozXRuXfQPhYoQsm1lK21L10BSSZtC
OkxpLZqzsq2smKu0i5KOaVPXRYyaJTYDFaqHZr4k+lsqWGMEdf6Hw/dyOHAE
qsrCsgAOh3ME4appmPkwJVkrp6KZroiJLczs4Zl65j+9288M+/4jwwJrfK17
mEk9otkHMEcmyO+EL4X+Eqb5olXRBcM3hbYzJX+mPI+gYG8EeQyrZmPOM2Pd
AvMbaHqVaHsHDQUnzrnhhq0Tix+gMObp5nH4228b0hZScmDcoayDzkP1bp6M
kuOalYNx8FZZhz0ecr+qRpgL2jGfEF5QNHRlwoSFuDVm4N3oPhFMCpGIvLDE
ufQlSE6JpdcoFcPGpYd6pjjZFrwbTvBlQ7lQ/c2TkQflFZPP8+HQ5fYx5tlS
takYJnaMupkqV/A1NTRGuubPwFJ+ob2C7S7L/jLXB+0ytEBpq3XVBPm1c7Wt
MO261xtyFD91vvtRMNmTWp0O77VVZAnhjIIn3gkNAZ+bs6GvWLoogdOlTZk5
MH2gYaQZWpV5gdxjlPROpfRJ4dykJ1QGP0n1g82Q0/Ra7IDPdoQpjEWUlKc2
6VNOUrI6qLNXQ92+G+tqoMPZeLq8kZJlC1/DtPJyY69couSJYdjj0FOyfbSN
1w/fX5XUJbRQ8jY+qujnHUoKrFX64n5Kttlc88xQwYBcCXWV3NvdUJP0K7IH
crr3d76A09ybaR9ZPyh8hGnX+kweuKYWbaxyUvIfm55JxA==
  "],
 CellLabel->
  "Out[151]=",ExpressionUUID->"b0b5df0a-c6f5-4055-b123-4d6b5d03a19f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"Solve", "[", 
   RowBox[{"%", ",", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "T", "]"}], ",", "T"}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8008689690329647`*^9, 3.800868995457017*^9}},
 CellLabel->
  "In[152]:=",ExpressionUUID->"4e1d0dd1-1f93-4e92-908c-16c8d9c8e400"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "T", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["I0", "\[Prime]",
        MultilineFunction->None], "[", "T", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["I1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", 
       RowBox[{"\[Phi]", "[", "T", "]"}]}], "]"}]}], 
    RowBox[{
     SuperscriptBox["I1", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", 
      RowBox[{"\[Phi]", "[", "T", "]"}]}], "]"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.800868984135952*^9, 3.800869004295051*^9}, 
   3.800869118421509*^9, 3.800869862763525*^9, 3.8008708702592363`*^9, 
   3.800871327300712*^9, 3.800871405633902*^9, 3.800897281803103*^9, 
   3.800900137203875*^9, 3.8009003518884563`*^9, 3.800902365215975*^9, 
   3.800902856361628*^9, 3.800905334668993*^9, 3.800906248575468*^9, 
   3.8009066647225733`*^9, 3.800962217157071*^9, 3.8009684489778137`*^9, 
   3.8009701310915213`*^9, 3.800977246482545*^9, 3.800977629446506*^9, 
   3.801331141078846*^9, 3.801334541688143*^9, 3.802709556178323*^9, 
   3.802710615553814*^9, 3.8027134770286016`*^9, 3.80271359509832*^9, 
   3.802765254270235*^9, 3.802770731951317*^9, 3.802771368871642*^9, 
   3.802774904585925*^9, 3.803118009821463*^9, 3.803197135462083*^9, 
   3.8033025644445333`*^9, 3.803302965419436*^9, 3.803308085109686*^9, 
   3.803317698721416*^9, 3.803324831565023*^9, 3.8033279185852413`*^9, 
   3.803328060881357*^9, 3.803378803327783*^9, 3.80337925411707*^9, 
   3.803395200276456*^9, 3.8033979579617043`*^9, 3.803411842577162*^9, 
   3.803412450698551*^9, 3.8034750098593693`*^9, 3.803477909195368*^9, 
   3.80347897515457*^9, 3.803729663039278*^9, 3.803743503779582*^9, 
   3.80380661738116*^9, 3.8038122755014677`*^9, 3.803816392814925*^9, 
   3.803825183093914*^9, 3.803830106684586*^9, 3.803838892180895*^9, 
   3.803979259941033*^9, 3.8042706101825733`*^9, 3.804407161341119*^9, 
   3.804407894549776*^9, 3.804503484290113*^9, 3.804598734029525*^9, 
   3.805045464447897*^9, 3.806938164424017*^9, 3.807092100025107*^9, 
   3.807092764646173*^9, 3.8254251800300827`*^9, 3.825425216920117*^9, 
   3.828107434018458*^9, 3.828717173811534*^9, 3.828717756690443*^9, 
   3.832075201839567*^9, 3.839324872551971*^9, 3.852137523571837*^9, 
   3.852138309990847*^9, 3.8521432856829233`*^9, 3.852293312608512*^9, 
   3.8522942715198393`*^9, 3.8523282263215313`*^9, 3.8523641486395493`*^9, 
   3.852365304424974*^9, 3.8523669678198347`*^9, 3.853746281746026*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"9ef73319-f595-4077-9f39-5663823887c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["defnumb"], "Input",
 CellChangeTimes->{{3.804503752340073*^9, 3.804503753363797*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"95460580-95b2-487c-951a-da546faa0903"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Psi]", "\[Rule]", "10.1`"}], ",", 
   RowBox[{"va", "\[Rule]", 
    RowBox[{"0.2`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "ts"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]]}]}], ",", 
   RowBox[{"\[CapitalDelta]V", "\[Rule]", "2.3`"}], ",", 
   RowBox[{"ts", "\[Rule]", 
    RowBox[{"T", "-", "\[Delta]"}]}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "0.5`"}], ",", 
   RowBox[{"Vr", "\[Rule]", "10"}], ",", 
   RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
   RowBox[{"\[Sigma]r", "\[Rule]", "5.5`"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8523669678327837`*^9, 3.8537462818632307`*^9},
 CellLabel->
  "Out[153]=",ExpressionUUID->"0355bf98-1754-408a-bf34-7e62a32c9e58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Psi]", "\[Rule]", "10.1"}], ",", 
   RowBox[{"va", "\[Rule]", 
    RowBox[{"0.2", "  ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "ts"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]]}]}], ",", 
   RowBox[{"\[CapitalDelta]V", "\[Rule]", "2.3"}], ",", 
   RowBox[{"ts", "\[Rule]", 
    RowBox[{"T", "-", "\[Delta]"}]}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "1"}], ",", 
   RowBox[{"Vr", "\[Rule]", "10"}], ",", 
   RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
   RowBox[{"\[Sigma]r", "\[Rule]", "5.5`"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.852365591875167*^9, 3.8523656136042147`*^9}, 
   3.85236582639155*^9},
 CellLabel->
  "In[154]:=",ExpressionUUID->"1fc4a148-5087-4a44-8523-1ebef3c11572"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Psi]", "\[Rule]", "10.1`"}], ",", 
   RowBox[{"va", "\[Rule]", 
    RowBox[{"0.2`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "ts"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}]]}]}], ",", 
   RowBox[{"\[CapitalDelta]V", "\[Rule]", "2.3`"}], ",", 
   RowBox[{"ts", "\[Rule]", 
    RowBox[{"T", "-", "\[Delta]"}]}], ",", 
   RowBox[{"\[Delta]", "\[Rule]", "1"}], ",", 
   RowBox[{"Vr", "\[Rule]", "10"}], ",", 
   RowBox[{"\[Sigma]f", "\[Rule]", "5"}], ",", 
   RowBox[{"\[Sigma]r", "\[Rule]", "5.5`"}], ",", 
   RowBox[{"\[Gamma]", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.852366967894163*^9, 3.853746282091455*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"cc3125c5-f5f5-43fc-bcdd-63e6db8f6905"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"va", " ", "/.", "defnumb"}], "}"}], " ", 
  RowBox[{"Exp", "[", 
   RowBox[{"ts", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.804504035177331*^9, 3.804504049958036*^9}},
 CellLabel->
  "In[155]:=",ExpressionUUID->"5ea72838-e8e9-4809-ada1-b4314c04ad6a"],

Cell[BoxData[
 RowBox[{"{", "0.2`", "}"}]], "Output",
 CellChangeTimes->{
  3.8045039779501047`*^9, {3.804504044995657*^9, 3.804504050551866*^9}, 
   3.804598734124173*^9, 3.805045465531374*^9, 3.806938164958763*^9, 
   3.8070921001220713`*^9, 3.8070927647358847`*^9, 3.825425180068075*^9, 
   3.825425216956843*^9, 3.82810743407456*^9, 3.828717173892372*^9, 
   3.828717756765641*^9, 3.832075201899144*^9, 3.83932487261069*^9, 
   3.852137523635374*^9, 3.852138310179328*^9, 3.852143285745987*^9, 
   3.852293312652216*^9, 3.852294271574938*^9, 3.852328226381522*^9, 
   3.8523641487005653`*^9, 3.852365304485825*^9, 3.852366967909863*^9, 
   3.8537462822328043`*^9},
 CellLabel->
  "Out[155]=",ExpressionUUID->"20bdcc45-fd55-42da-ae1d-bbf374b2cef7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"10", " ", 
      RowBox[{"gc1", "[", "t", "]"}]}], "/.", "defgc01"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
      RowBox[{"Tc1", "\[Rule]", 
       RowBox[{"\[CapitalDelta]", "-", 
        RowBox[{"2", "\[CapitalPhi]", " ", "per"}]}]}]}], "}"}]}], "/.", 
   RowBox[{"T", "\[Rule]", "per"}]}], "/.", "defnumb"}]], "Input",
 CellLabel->
  "In[156]:=",ExpressionUUID->"1725f0a3-ab4b-437a-9030-310f694fab45"],

Cell[BoxData[
 RowBox[{"550.`", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "5.5`"}], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "\[CapitalDelta]", "+", 
         RowBox[{"2", " ", "per", " ", "\[CapitalPhi]"}]}], ")"}]}]]}], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "5"}], " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "\[CapitalDelta]", "+", 
        RowBox[{"2", " ", "per", " ", "\[CapitalPhi]"}]}], ")"}]}]]}], ")"}], 
  " ", "Gcn", " ", 
  RowBox[{"UnitStep", "[", 
   RowBox[{"t", "-", "\[CapitalDelta]", "+", 
    RowBox[{"2", " ", "per", " ", "\[CapitalPhi]"}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.8071044501224117`*^9, 3.825425180104968*^9, 
  3.825425216981072*^9, 3.8281074341400747`*^9, 3.8287171739543047`*^9, 
  3.828717756781201*^9, 3.8320752019542723`*^9, 3.839324872620297*^9, 
  3.852137523648871*^9, 3.852138310198835*^9, 3.8521432857612467`*^9, 
  3.8522933126670237`*^9, 3.8522942715874166`*^9, 3.852328226393515*^9, 
  3.852364148749276*^9, 3.8523653044987926`*^9, 3.8523669679578753`*^9, 
  3.853746282307128*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"ac054438-132b-4867-8ced-e908f232b0fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "keeping", " ", "\[CapitalDelta]", " ", "fixed", " ", "as", " ", 
     "\[CapitalPhi]", " ", "is", " ", "varied"}], ";", " ", 
    RowBox[{
     RowBox[{
     "the", " ", "chemical", " ", "synapses", " ", "is", " ", "triggered", 
      " ", "at", " ", "time", " ", "\[CapitalDelta]"}], "-", 
     RowBox[{"2", "\[CapitalPhi]T"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"as", " ", "it", " ", "should"}], ",", " ", 
    RowBox[{
    "I1", " ", "scales", " ", "linearly", " ", "in", " ", "g0", " ", "and", 
     " ", "gcn"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    StyleBox["IMPORTANT",
     FontWeight->"Bold"], 
    StyleBox[":",
     FontWeight->"Bold"], 
    StyleBox[" ",
     FontWeight->"Bold"], 
    RowBox[{
     StyleBox["this",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], 
     StyleBox["calculation",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], 
     StyleBox["assumes",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], 
     StyleBox["that",
      FontWeight->"Plain"], 
     StyleBox[" ",
      FontWeight->"Plain"], "the", " ", "spike", " ", "times", " ", "differ", 
     " ", "by", " ", "less", " ", "than", " ", "the", " ", "spike", " ", 
     RowBox[{"width", ".", " ", "This"}], " ", "is", " ", "monitored", " ", 
     "in", " ", "the", " ", "title", " ", "of", " ", "the", " ", "plot", " ", 
     "in", " ", "the", " ", "statement", " ", "`valid", " ", 
     RowBox[{
      RowBox[{"if", "'"}], " ", ".", " ", "It"}], " ", "limits", " ", "the", 
     " ", "range", " ", "over", " ", "which", " ", "\[CapitalPhi]", "  ", 
     "can", " ", "be", " ", "varied"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{"g01", "=", "1"}], ";", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Piecewise", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"V01b", "[", "t", "]"}], "/.", 
                  RowBox[{"T", "\[Rule]", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", "<", "ts"}], "/.", "defnumb"}], "/.", 
                  "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"V01b", "[", 
                   RowBox[{"t", "-", "T"}], "]"}], "/.", 
                  RowBox[{"T", "\[Rule]", "per"}]}], "}"}], ",", 
                RowBox[{"t", ">", "per"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"V03b", "[", "t", "]"}], "/.", 
                  RowBox[{"T", "\[Rule]", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", ">", "ts"}], "/.", "defnumb"}], "/.", 
                  "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}]}], "}"}], "]"}], 
           ",", 
           RowBox[{"Piecewise", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"V01b", "[", 
                   RowBox[{"t", "+", 
                    RowBox[{"\[CapitalPhi]", " ", "T"}]}], "]"}], "/.", 
                  RowBox[{"T", "\[Rule]", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", "<", 
                    RowBox[{"ts", "-", 
                    RowBox[{"\[CapitalPhi]", " ", "T"}]}]}], "/.", 
                   "defnumb"}], "/.", "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"V01b", "[", 
                   RowBox[{"t", "-", "T", "+", 
                    RowBox[{"\[CapitalPhi]", " ", "T"}]}], "]"}], "/.", 
                  RowBox[{"T", "\[Rule]", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", ">", 
                    RowBox[{"per", "-", 
                    RowBox[{"\[CapitalPhi]", " ", "T"}]}]}], "/.", 
                   "defnumb"}], "/.", "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"V03b", "[", 
                   RowBox[{"t", "+", 
                    RowBox[{"\[CapitalPhi]", " ", "T"}]}], "]"}], "/.", 
                  RowBox[{"T", "\[Rule]", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", ">", 
                    RowBox[{"ts", "-", 
                    RowBox[{"\[CapitalPhi]", " ", "T"}]}]}], "/.", 
                   "defnumb"}], "/.", "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}]}], "}"}], "]"}], 
           ",", 
           RowBox[{"Piecewise", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"V11b", "[", "t", "]"}], "/.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}], ",", 
                    RowBox[{"Tc1", "\[Rule]", 
                    RowBox[{"\[CapitalDelta]", "-", 
                    RowBox[{"2", "\[CapitalPhi]", " ", "T"}]}]}], ",", 
                    RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
                    RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
                  RowBox[{"T", "->", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"t", "<", 
                    RowBox[{"ts", "-", 
                    RowBox[{"\[Phi]", " ", "T"}]}]}], "/.", "defnumb"}], "/.",
                    "defnumb"}], "/.", 
                  RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}]}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"V11b", "[", 
                    RowBox[{"t", "-", "T"}], "]"}], "/.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"T", "->", "per"}], ",", 
                    RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}], ",", 
                    RowBox[{"Tc1", "\[Rule]", 
                    RowBox[{"\[CapitalDelta]", "-", 
                    RowBox[{"2", "\[CapitalPhi]", " ", "T"}]}]}], ",", 
                    RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
                    RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
                  RowBox[{"T", "->", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"t", ">", "per"}], "/.", "defnumb"}], "/.", 
                   "defnumb"}], "/.", 
                  RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}]}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"V12b", "[", "t", "]"}], "/.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"T", "->", "per"}], ",", 
                    RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}], ",", 
                    RowBox[{"Tc1", "\[Rule]", 
                    RowBox[{"\[CapitalDelta]", "-", 
                    RowBox[{"2", "\[CapitalPhi]", " ", "T"}]}]}], ",", 
                    RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
                    RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
                  RowBox[{"T", "->", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", "<", "ts"}], "/.", "defnumb"}], "/.", 
                  "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"V14b", "[", "t", "]"}], "/.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"T", "->", "per"}], ",", 
                    RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}], ",", 
                    RowBox[{"Tc1", "\[Rule]", 
                    RowBox[{"\[CapitalDelta]", "-", 
                    RowBox[{"2", "\[CapitalPhi]", " ", "T"}]}]}], ",", 
                    RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
                    RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
                  RowBox[{"T", "->", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", ">", 
                    RowBox[{"T", "-", 
                    RowBox[{"\[Phi]", " ", "T"}]}]}], "/.", 
                   RowBox[{"T", "\[Rule]", "per"}]}], "/.", "defnumb"}], "/.", 
                 RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}]}]}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"V13b", "[", "t", "]"}], "/.", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"T", "->", "per"}], ",", 
                    RowBox[{"\[Phi]", "\[Rule]", "\[CapitalPhi]"}], ",", 
                    RowBox[{"Tc1", "\[Rule]", 
                    RowBox[{"\[CapitalDelta]", "-", 
                    RowBox[{"2", "\[CapitalPhi]", " ", "T"}]}]}], ",", 
                    RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
                    RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
                  RowBox[{"T", "->", "per"}]}], "}"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"t", ">", "ts"}], "/.", "defnumb"}], "/.", 
                  "defnumb"}], "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}]}], "}"}], "]"}], 
           ",", 
           RowBox[{"Piecewise", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", 
                 RowBox[{
                  RowBox[{"t", "<", 
                   RowBox[{"per", "-", "\[Delta]"}]}], "/.", "defnumb"}]}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", 
                 RowBox[{"t", ">", "per"}]}], "}"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{
                RowBox[{"t", ">", 
                 RowBox[{"per", "-", "\[Delta]"}]}], "/.", "defnumb"}]}], 
              "}"}]}], "]"}], ",", 
           RowBox[{"Piecewise", "[", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"10", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"gc1", "[", "t", "]"}], " ", "+", " ", 
                    RowBox[{"\[Alpha]", " ", 
                    RowBox[{"gc1", "[", 
                    RowBox[{"t", "+", "T"}], "]"}]}], "+", 
                    RowBox[{"\[Gamma]", " ", 
                    RowBox[{"gc1", "[", 
                    RowBox[{"t", "-", "T"}], "]"}]}], "+", 
                    RowBox[{"\[Beta]", " ", 
                    RowBox[{"gc1", "[", 
                    RowBox[{"t", "+", " ", 
                    RowBox[{"2", " ", "T"}]}], "]"}]}]}], ")"}]}], "/.", 
                    "def\[Alpha]\[Beta]\[Gamma]"}], "/.", "defgc01"}], "/.", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
                    RowBox[{"Tc1", "\[Rule]", 
                    RowBox[{"\[CapitalDelta]", "-", 
                    RowBox[{"2", "\[CapitalPhi]", " ", "per"}]}]}]}], "}"}]}],
                  "/.", 
                 RowBox[{"T", "\[Rule]", "per"}]}], "/.", "defnumb"}], ",", 
               RowBox[{"t", ">", 
                RowBox[{"\[CapitalDelta]", "-", 
                 RowBox[{"2", "\[CapitalPhi]", " ", "per"}]}]}]}], "}"}], 
             "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "7"}], "}"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"Scaled", "[", ".5", "]"}]}], ",", 
         RowBox[{"PlotLegends", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<V01\>\"", ",", "\"\<V00\>\"", ",", "\"\<V10\>\"", ",", 
            "\"\<no spike current\>\"", ",", "\"\<synapse\>\""}], "}"}]}], 
         ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "4"}], "}"}]}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Time\>\"", ",", "\"\<Voltage Conductance\>\""}], 
           "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\<\[Sigma]r=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Sigma]r", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[Sigma]f=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Sigma]f", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[CapitalDelta]=\>\"", "<>", 
             RowBox[{"ToString", "[", "\[CapitalDelta]", "]"}]}], ",", 
            RowBox[{"\"\<g0=\>\"", "<>", 
             RowBox[{"ToString", "[", "g01", "]"}]}], ",", 
            RowBox[{"\"\<Gcn=\>\"", "<>", 
             RowBox[{"ToString", "[", "Gcn", "]"}]}], ",", 
            RowBox[{"\"\<\[CapitalPhi]=\>\"", "<>", 
             RowBox[{"ToString", "[", "\[CapitalPhi]", "]"}]}], ",", 
            RowBox[{"\"\<\[Beta]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Beta]", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[Delta]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Delta]", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[Psi]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Psi]", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<van=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"va", " ", "/.", "defnumb"}], "}"}], " ", 
                RowBox[{"Exp", "[", 
                 RowBox[{"ts", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}], "]"}]}], 
               "]"}], "]"}]}], ",", 
            RowBox[{"\"\<valid if \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{
               RowBox[{"\[Delta]", "-", 
                RowBox[{"\[CapitalPhi]", " ", "per"}]}], "/.", "defnumb"}], 
              "]"}], "<>", "\"\<>0\>\""}]}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"I1", "/.", "\[VeryThinSpace]", "defI1numb"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Tc1", "\[Rule]", 
                RowBox[{"\[CapitalDelta]", "-", 
                 RowBox[{"2", "\[Phi]", " ", "T"}]}]}], ",", 
               RowBox[{"T", "->", "per"}], ",", 
               RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
               RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
            RowBox[{"T", "\[Rule]", "per"}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"I1", "/.", "\[VeryThinSpace]", "defI1numb"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Tc1", "\[Rule]", 
                RowBox[{"0.1", "-", 
                 RowBox[{"2", "\[Phi]", " ", "T"}]}]}], ",", 
               RowBox[{"T", "->", "per"}], ",", 
               RowBox[{"gcn", "\[Rule]", "Gcn"}], ",", 
               RowBox[{"g0", "\[Rule]", "g01"}]}], "}"}]}], "/.", 
            RowBox[{"T", "\[Rule]", "per"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Phi]", ",", 
           RowBox[{"-", "0.2"}], ",", " ", "1"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "0.1"}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"Scaled", "[", ".5", "]"}]}], ",", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<\[Phi]\>\"", ",", "\"\<I1\>\""}], "}"}]}], ",", 
         RowBox[{"PlotLegends", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\[CapitalDelta]\>\"", ",", "\"\<\[CapitalDelta]=0.1\>\""}], 
           "}"}]}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\<\[Sigma]r=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Sigma]r", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[Sigma]f=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Sigma]f", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<tc1=\>\"", "<>", 
             RowBox[{"ToString", "[", "tc1", "]"}]}], ",", 
            RowBox[{"\"\<Gcn=\>\"", "<>", 
             RowBox[{"ToString", "[", "Gcn", "]"}]}], ",", 
            RowBox[{"\"\<\[Beta]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Beta]", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[Delta]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Delta]", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<\[Psi]=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"\[Psi]", "/.", "defnumb"}], "]"}]}], ",", 
            RowBox[{"\"\<van=\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"va", " ", "/.", "defnumb"}], "}"}], " ", 
                RowBox[{"Exp", "[", 
                 RowBox[{"ts", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "\[Psi]"}], ")"}]}], "]"}]}], 
               "]"}], "]"}]}]}], "}"}]}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"per", ",", "5"}], "}"}], ",", "2", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[CapitalPhi]", ",", ".08"}], "}"}], ",", 
       RowBox[{"-", "0.1"}], ",", "0.9", ",", "0.01"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[CapitalDelta]", ",", "0.1"}], "}"}], ",", 
       RowBox[{"-", "0.1"}], ",", "0.5", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Gcn", ",", "0.1"}], "}"}], ",", "0", ",", "1", ",", "0.01"}],
       "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.804412794194852*^9, 3.804412802120166*^9}, {
   3.804412889012673*^9, 3.804412938965654*^9}, {3.804412992969486*^9, 
   3.804413000349107*^9}, {3.8044130683230047`*^9, 3.8044131187010098`*^9}, 
   3.804413216687765*^9, {3.8044133313130074`*^9, 3.8044133521053143`*^9}, {
   3.8044134647922163`*^9, 3.8044134850369987`*^9}, {3.804413570078203*^9, 
   3.804413579650413*^9}, {3.804413622094576*^9, 3.804413622219666*^9}, {
   3.804413690651341*^9, 3.80441369262358*^9}, {3.80441373944064*^9, 
   3.804413759784959*^9}, {3.804413804824436*^9, 3.804413816142805*^9}, {
   3.8044139787510023`*^9, 3.8044139895506763`*^9}, {3.8044141173972597`*^9, 
   3.804414130310844*^9}, {3.8044159137083807`*^9, 3.804415975413477*^9}, {
   3.80441929596733*^9, 3.8044193302675*^9}, {3.804419411455068*^9, 
   3.804419433668825*^9}, {3.80442060319401*^9, 3.8044206045438633`*^9}, {
   3.80442077810214*^9, 3.8044207783964167`*^9}, {3.804420828941926*^9, 
   3.804420873013508*^9}, {3.804420971348031*^9, 3.804420979027697*^9}, {
   3.804421269316806*^9, 3.804421283326194*^9}, {3.804421819521929*^9, 
   3.804421820831872*^9}, {3.8044220660988607`*^9, 3.80442206634413*^9}, {
   3.804422117317259*^9, 3.804422117744835*^9}, {3.80442227994777*^9, 
   3.804422280512409*^9}, {3.8044237565429287`*^9, 3.8044238937820053`*^9}, {
   3.804424029804894*^9, 3.804424132253134*^9}, 3.804499996106805*^9, {
   3.8045037117082577`*^9, 3.804503801644916*^9}, {3.804503837925346*^9, 
   3.804503948496125*^9}, {3.8045040154021807`*^9, 3.80450402101159*^9}, {
   3.8045040548567047`*^9, 3.804504090789256*^9}, 3.804504129385007*^9, {
   3.804504182037331*^9, 3.804504192813376*^9}, 3.8045042500097103`*^9, 
   3.804504284296671*^9, {3.805045566396861*^9, 3.8050455678300858`*^9}, {
   3.805046568580875*^9, 3.805046569163707*^9}, {3.805046645001096*^9, 
   3.8050466455610027`*^9}, {3.805047851941614*^9, 3.805047852471796*^9}, {
   3.8050481505883293`*^9, 3.805048151072362*^9}, {3.8050485012957687`*^9, 
   3.80504857639785*^9}, {3.805051302594849*^9, 3.8050513302333937`*^9}, {
   3.805051367039667*^9, 3.805051367510236*^9}, {3.805051446580552*^9, 
   3.8050514471158133`*^9}, {3.805051493754415*^9, 3.805051494840165*^9}, {
   3.8050515372449493`*^9, 3.805051537874558*^9}, 3.8050515826268063`*^9, {
   3.8050516486197033`*^9, 3.805051676727838*^9}, {3.807105456213077*^9, 
   3.807105472454063*^9}, {3.8071129226409807`*^9, 3.80711296013307*^9}, 
   3.839326865767859*^9, {3.852364622072125*^9, 3.852364675852971*^9}, {
   3.8523679011019793`*^9, 3.852367907924692*^9}, {3.85236795577664*^9, 
   3.852368005716667*^9}, {3.8523683764476624`*^9, 3.8523683980727043`*^9}, {
   3.852368436880088*^9, 3.85236845918399*^9}, {3.852368560606859*^9, 
   3.852368583323406*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"e4c231bc-e461-4314-921f-e0a71b3e91c0"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`Gcn$$ = 0.1, $CellContext`per$$ = 
    5, $CellContext`\[CapitalDelta]$$ = 0.1, $CellContext`\[CapitalPhi]$$ = 
    0.08, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`per$$], 5}, 2, 8}, {{
       Hold[$CellContext`\[CapitalPhi]$$], 0.08}, -0.1, 0.9, 0.01}, {{
       Hold[$CellContext`\[CapitalDelta]$$], 0.1}, -0.1, 0.5, 0.05}, {{
       Hold[$CellContext`Gcn$$], 0.1}, 0, 1, 0.01}}, Typeset`size$$ = {
    488., {363., 108.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`Gcn$$ = 0.1, $CellContext`per$$ = 
        5, $CellContext`\[CapitalDelta]$$ = 0.1, $CellContext`\[CapitalPhi]$$ = 
        0.08}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> {
        Plot[{
          Piecewise[{{{
              ReplaceAll[
               $CellContext`V01b[$CellContext`t], $CellContext`T -> \
$CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t < $CellContext`ts, \
$CellContext`defnumb], $CellContext`defnumb], $CellContext`T -> \
$CellContext`per$$]}, {{
              ReplaceAll[
               $CellContext`V01b[$CellContext`t - $CellContext`T], \
$CellContext`T -> $CellContext`per$$]}, $CellContext`t > $CellContext`per$$}, \
{{
              ReplaceAll[
               $CellContext`V03b[$CellContext`t], $CellContext`T -> \
$CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t > $CellContext`ts, \
$CellContext`defnumb], $CellContext`defnumb], $CellContext`T -> \
$CellContext`per$$]}}], 
          Piecewise[{{{
              ReplaceAll[
               $CellContext`V01b[$CellContext`t + \
$CellContext`\[CapitalPhi]$$ $CellContext`T], $CellContext`T -> \
$CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t < $CellContext`ts - $CellContext`\
\[CapitalPhi]$$ $CellContext`T, $CellContext`defnumb], $CellContext`defnumb], \
$CellContext`T -> $CellContext`per$$]}, {{
              ReplaceAll[
               $CellContext`V01b[$CellContext`t - $CellContext`T + \
$CellContext`\[CapitalPhi]$$ $CellContext`T], $CellContext`T -> \
$CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t > $CellContext`per$$ - $CellContext`\
\[CapitalPhi]$$ $CellContext`T, $CellContext`defnumb], $CellContext`defnumb], \
$CellContext`T -> $CellContext`per$$]}, {{
              ReplaceAll[
               $CellContext`V03b[$CellContext`t + \
$CellContext`\[CapitalPhi]$$ $CellContext`T], $CellContext`T -> \
$CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t > $CellContext`ts - $CellContext`\
\[CapitalPhi]$$ $CellContext`T, $CellContext`defnumb], $CellContext`defnumb], \
$CellContext`T -> $CellContext`per$$]}}], 
          Piecewise[{{{
              ReplaceAll[
               ReplaceAll[
                $CellContext`V11b[$CellContext`t], {$CellContext`\[Phi] -> \
$CellContext`\[CapitalPhi]$$, $CellContext`Tc1 -> \
$CellContext`\[CapitalDelta]$$ - 
                  2 $CellContext`\[CapitalPhi]$$ $CellContext`T, \
$CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               ReplaceAll[
                
                ReplaceAll[$CellContext`t < $CellContext`ts - $CellContext`\
\[Phi] $CellContext`T, $CellContext`defnumb], $CellContext`defnumb], \
$CellContext`\[Phi] -> $CellContext`\[CapitalPhi]$$], $CellContext`T -> \
$CellContext`per$$]}, {{
              ReplaceAll[
               ReplaceAll[
                $CellContext`V11b[$CellContext`t - $CellContext`T], \
{$CellContext`T -> $CellContext`per$$, $CellContext`\[Phi] -> $CellContext`\
\[CapitalPhi]$$, $CellContext`Tc1 -> $CellContext`\[CapitalDelta]$$ - 
                  2 $CellContext`\[CapitalPhi]$$ $CellContext`T, \
$CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               ReplaceAll[
                
                ReplaceAll[$CellContext`t > $CellContext`per$$, \
$CellContext`defnumb], $CellContext`defnumb], $CellContext`\[Phi] -> \
$CellContext`\[CapitalPhi]$$], $CellContext`T -> $CellContext`per$$]}, {{
              ReplaceAll[
               ReplaceAll[
                $CellContext`V12b[$CellContext`t], {$CellContext`T -> \
$CellContext`per$$, $CellContext`\[Phi] -> $CellContext`\[CapitalPhi]$$, \
$CellContext`Tc1 -> $CellContext`\[CapitalDelta]$$ - 
                  2 $CellContext`\[CapitalPhi]$$ $CellContext`T, \
$CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t < $CellContext`ts, \
$CellContext`defnumb], $CellContext`defnumb], $CellContext`T -> \
$CellContext`per$$]}, {{
              ReplaceAll[
               ReplaceAll[
                $CellContext`V14b[$CellContext`t], {$CellContext`T -> \
$CellContext`per$$, $CellContext`\[Phi] -> $CellContext`\[CapitalPhi]$$, \
$CellContext`Tc1 -> $CellContext`\[CapitalDelta]$$ - 
                  
                  2 $CellContext`\[CapitalPhi]$$ $CellContext`T, \
$CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t > $CellContext`T - $CellContext`\
\[Phi] $CellContext`T, $CellContext`T -> $CellContext`per$$], \
$CellContext`defnumb], $CellContext`\[Phi] -> $CellContext`\[CapitalPhi]$$]}, \
{{
              ReplaceAll[
               ReplaceAll[
                $CellContext`V13b[$CellContext`t], {$CellContext`T -> \
$CellContext`per$$, $CellContext`\[Phi] -> $CellContext`\[CapitalPhi]$$, \
$CellContext`Tc1 -> $CellContext`\[CapitalDelta]$$ - 
                  2 $CellContext`\[CapitalPhi]$$ $CellContext`T, \
$CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$]}, 
             ReplaceAll[
              ReplaceAll[
               
               ReplaceAll[$CellContext`t > $CellContext`ts, \
$CellContext`defnumb], $CellContext`defnumb], $CellContext`T -> \
$CellContext`per$$]}}], 
          Piecewise[{{-1, 
             
             ReplaceAll[$CellContext`t < $CellContext`per$$ - $CellContext`\
\[Delta], $CellContext`defnumb]}, {-1, $CellContext`t > $CellContext`per$$}}, \
{1, 
            
            ReplaceAll[$CellContext`t > $CellContext`per$$ - $CellContext`\
\[Delta], $CellContext`defnumb]}], 
          Piecewise[{{
             ReplaceAll[
              ReplaceAll[
               ReplaceAll[
                ReplaceAll[
                 ReplaceAll[
                 10 ($CellContext`gc1[$CellContext`t] + $CellContext`\[Alpha] \
$CellContext`gc1[$CellContext`t + $CellContext`T] + $CellContext`\[Gamma] \
$CellContext`gc1[$CellContext`t - $CellContext`T] + $CellContext`\[Beta] \
$CellContext`gc1[$CellContext`t + 
                    2 $CellContext`T]), $CellContext`def\[Alpha]\[Beta]\
\[Gamma]], $CellContext`defgc01], {$CellContext`gcn -> $CellContext`Gcn$$, \
$CellContext`Tc1 -> $CellContext`\[CapitalDelta]$$ - 
                  2 $CellContext`\[CapitalPhi]$$ $CellContext`per$$}], \
$CellContext`T -> $CellContext`per$$], $CellContext`defnumb], $CellContext`t > \
$CellContext`\[CapitalDelta]$$ - 
              2 $CellContext`\[CapitalPhi]$$ $CellContext`per$$}}]}, \
{$CellContext`t, 0, 7}, ImageSize -> Scaled[0.5], 
         PlotLegends -> {"V01", "V00", "V10", "no spike current", "synapse"}, 
         PlotRange -> {-2, 4}, AxesLabel -> {"Time", "Voltage Conductance"}, 
         PlotLabel -> {
           StringJoin["\[Sigma]r=", 
            ToString[
             ReplaceAll[$CellContext`\[Sigma]r, $CellContext`defnumb]]], 
           StringJoin["\[Sigma]f=", 
            ToString[
             ReplaceAll[$CellContext`\[Sigma]f, $CellContext`defnumb]]], 
           StringJoin["\[CapitalDelta]=", 
            ToString[$CellContext`\[CapitalDelta]$$]], 
           StringJoin["g0=", 
            ToString[$CellContext`g01]], 
           StringJoin["Gcn=", 
            ToString[$CellContext`Gcn$$]], 
           StringJoin["\[CapitalPhi]=", 
            ToString[$CellContext`\[CapitalPhi]$$]], 
           StringJoin["\[Beta]=", 
            ToString[
             ReplaceAll[$CellContext`\[Beta], $CellContext`defnumb]]], 
           StringJoin["\[Delta]=", 
            ToString[
             ReplaceAll[$CellContext`\[Delta], $CellContext`defnumb]]], 
           StringJoin["\[Psi]=", 
            ToString[
             ReplaceAll[$CellContext`\[Psi], $CellContext`defnumb]]], 
           StringJoin["van=", 
            ToString[
             Flatten[{
                ReplaceAll[$CellContext`va, $CellContext`defnumb]} 
              Exp[$CellContext`ts (-1 + $CellContext`\[Psi])]]]], 
           StringJoin["valid if ", 
            ToString[
             
             ReplaceAll[$CellContext`\[Delta] - $CellContext`\[CapitalPhi]$$ \
$CellContext`per$$, $CellContext`defnumb]], ">0"]}], 
        Plot[{
          ReplaceAll[
           ReplaceAll[
            
            ReplaceAll[$CellContext`I1, $CellContext`defI1numb], \
{$CellContext`Tc1 -> $CellContext`\[CapitalDelta]$$ - 
              2 $CellContext`\[Phi] $CellContext`T, $CellContext`T -> \
$CellContext`per$$, $CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$], 
          ReplaceAll[
           ReplaceAll[
            
            ReplaceAll[$CellContext`I1, $CellContext`defI1numb], \
{$CellContext`Tc1 -> 
             0.1 - 2 $CellContext`\[Phi] $CellContext`T, $CellContext`T -> \
$CellContext`per$$, $CellContext`gcn -> $CellContext`Gcn$$, $CellContext`g0 -> \
$CellContext`g01}], $CellContext`T -> $CellContext`per$$]}, {$CellContext`\
\[Phi], -0.2, 1}, PlotRange -> {-2, 0.1}, ImageSize -> Scaled[0.5], 
         AxesLabel -> {"\[Phi]", "I1"}, 
         PlotLegends -> {"\[CapitalDelta]", "\[CapitalDelta]=0.1"}, PlotLabel -> {
           StringJoin["\[Sigma]r=", 
            ToString[
             ReplaceAll[$CellContext`\[Sigma]r, $CellContext`defnumb]]], 
           StringJoin["\[Sigma]f=", 
            ToString[
             ReplaceAll[$CellContext`\[Sigma]f, $CellContext`defnumb]]], 
           StringJoin["tc1=", 
            ToString[$CellContext`tc1]], 
           StringJoin["Gcn=", 
            ToString[$CellContext`Gcn$$]], 
           StringJoin["\[Beta]=", 
            ToString[
             ReplaceAll[$CellContext`\[Beta], $CellContext`defnumb]]], 
           StringJoin["\[Delta]=", 
            ToString[
             ReplaceAll[$CellContext`\[Delta], $CellContext`defnumb]]], 
           StringJoin["\[Psi]=", 
            ToString[
             ReplaceAll[$CellContext`\[Psi], $CellContext`defnumb]]], 
           StringJoin["van=", 
            ToString[
             Flatten[{
                ReplaceAll[$CellContext`va, $CellContext`defnumb]} 
              Exp[$CellContext`ts (-1 + $CellContext`\[Psi])]]]]}]}, 
      "Specifications" :> {{{$CellContext`per$$, 5}, 2, 
         8}, {{$CellContext`\[CapitalPhi]$$, 0.08}, -0.1, 0.9, 
         0.01}, {{$CellContext`\[CapitalDelta]$$, 0.1}, -0.1, 0.5, 
         0.05}, {{$CellContext`Gcn$$, 0.1}, 0, 1, 0.01}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{533., {320., 326.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8050466467079287`*^9, 3.805047705942862*^9, 3.805047853755245*^9, 
   3.805048152323103*^9, {3.805048523847251*^9, 3.8050485460822983`*^9}, 
   3.805048577427194*^9, 3.805051368560519*^9, {3.80505142200476*^9, 
   3.805051454308107*^9}, {3.805051496357952*^9, 3.805051553536539*^9}, 
   3.806938165419209*^9, 3.807091509991473*^9, 3.807092100193343*^9, 
   3.807092764812645*^9, {3.807100013168804*^9, 3.807100039257807*^9}, {
   3.807102286389679*^9, 3.807102288795437*^9}, {3.807105457530509*^9, 
   3.807105485300104*^9}, 3.8071129666532593`*^9, 3.825425180154141*^9, 
   3.8254252170199337`*^9, 3.828107434200993*^9, 3.8287171740348587`*^9, 
   3.828717756855266*^9, 3.828718122633984*^9, 3.832075202025877*^9, 
   3.839324872693801*^9, 3.852137523712839*^9, 3.852138310360964*^9, 
   3.8521432858144827`*^9, 3.8522933127175617`*^9, 3.852294271646756*^9, 
   3.8523282265022793`*^9, 3.852364148848494*^9, {3.852364245352631*^9, 
   3.852364262215536*^9}, 3.852364702681951*^9, 3.852365304571014*^9, 
   3.852366968022842*^9, {3.852367191773616*^9, 3.8523671977536383`*^9}, 
   3.852367919321377*^9, {3.852367963921879*^9, 3.852367977085108*^9}, 
   3.852368020520295*^9, 3.852368112385804*^9, 3.8523681454864817`*^9, 
   3.8523684967088013`*^9, 3.852368673739254*^9, 3.853746282531725*^9},
 CellLabel->
  "Out[157]=",ExpressionUUID->"8b9f97e6-437c-4bb8-b074-8dcdd3b27b8f"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{837, 997},
WindowMargins->{{Automatic, -1729}, {Automatic, -7}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.3 for Mac OS X x86 (64-bit) (June 19, 2021)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"e2b3488e-5c1a-449c-b312-d031b9267830"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[400, 13, 3170, 49, 725, "Text",ExpressionUUID->"4dfaffcc-4d8d-4293-99b2-0f6af7a7feb8"],
Cell[CellGroupData[{
Cell[3595, 66, 229, 5, 31, "Input",ExpressionUUID->"a86198ef-b65c-4ae3-9fe1-f37b416eb620"],
Cell[3827, 73, 997, 15, 34, "Output",ExpressionUUID->"9bab464a-3879-48c7-a3f6-4546cadf8378"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4861, 93, 227, 3, 31, "Input",ExpressionUUID->"528579bc-7d5e-47b7-9135-bf27c64c7795"],
Cell[5091, 98, 998, 15, 34, "Output",ExpressionUUID->"24445103-a314-437a-9d4b-644db6078519"]
}, Open  ]],
Cell[6104, 116, 247, 4, 30, "Input",ExpressionUUID->"8a1e072f-7ecc-49ae-8212-d9681a8680cc"],
Cell[6354, 122, 426, 9, 31, "Input",ExpressionUUID->"daff1a6f-8b85-4c35-b5c7-62c24f83f911"],
Cell[6783, 133, 842, 14, 150, "Text",ExpressionUUID->"4ca9e746-0910-4191-ac29-996be2ad40de"],
Cell[CellGroupData[{
Cell[7650, 151, 1074, 28, 51, "Input",ExpressionUUID->"3aeb75c3-7116-4a1f-8860-e0871d898682"],
Cell[8727, 181, 2844, 40, 34, "Output",ExpressionUUID->"ca382533-5772-489a-bb1b-26cbdd006735"],
Cell[11574, 223, 3366, 59, 38, "Output",ExpressionUUID->"663c6978-aecf-4031-a17e-7df0ab82c3c0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14977, 287, 876, 22, 31, "Input",ExpressionUUID->"52a9f14b-01ed-48af-a73c-1025905a54b3"],
Cell[15856, 311, 1309, 22, 52, "Output",ExpressionUUID->"4d7dc536-8b67-442c-a08d-3ee990f3b10c"]
}, Open  ]],
Cell[17180, 336, 320, 6, 31, "Input",ExpressionUUID->"eedf817a-5494-4048-85b8-4ec7d8800752"],
Cell[17503, 344, 613, 12, 81, "Text",ExpressionUUID->"e99b3b4a-d7a5-4800-8ad7-e28b2b708469"],
Cell[CellGroupData[{
Cell[18141, 360, 715, 13, 31, "Input",ExpressionUUID->"4a5379c6-5f3b-43b4-843c-cd67a794a889"],
Cell[18859, 375, 824, 15, 34, "Output",ExpressionUUID->"b0b9d21c-6563-49b6-b89f-84e8c2c1d830"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19720, 395, 280, 5, 31, "Input",ExpressionUUID->"46fa5bc8-d136-4d23-a5ed-0f23f0782278"],
Cell[20003, 402, 2967, 43, 34, "Output",ExpressionUUID->"86d62c03-f495-4f55-8a2c-6ef4eb228b61"]
}, Open  ]],
Cell[22985, 448, 1245, 27, 91, "Input",ExpressionUUID->"accaaae3-2335-4172-8022-198663c6a02f"],
Cell[CellGroupData[{
Cell[24255, 479, 275, 5, 67, "Section",ExpressionUUID->"68d0a436-1a95-43b1-be8a-3f42197fe5f3"],
Cell[CellGroupData[{
Cell[24555, 488, 632, 13, 31, "Input",ExpressionUUID->"25aa7f8d-59e2-416d-a950-2579b62036c4"],
Cell[25190, 503, 4376, 65, 34, "Output",ExpressionUUID->"3e7136aa-4b6a-442d-9e0c-b3164f0b8d17"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29603, 573, 973, 24, 71, "Input",ExpressionUUID->"b1ac7172-ffbb-4c2f-856e-992ff4ca7054"],
Cell[30579, 599, 3876, 61, 37, "Output",ExpressionUUID->"2c46e15b-9e71-4623-9344-7058ed119ef0"],
Cell[34458, 662, 3703, 56, 34, "Output",ExpressionUUID->"89bd5c0c-34b8-4971-8e41-1da443e4f894"],
Cell[38164, 720, 3926, 63, 37, "Output",ExpressionUUID->"ad163300-baf3-4885-8991-9df3e657a713"]
}, Open  ]],
Cell[42105, 786, 219, 4, 35, "Text",ExpressionUUID->"4e27cbc1-4342-44d2-be93-5e785c926bed"],
Cell[CellGroupData[{
Cell[42349, 794, 522, 11, 31, "Input",ExpressionUUID->"68c1be2d-21de-49b0-a182-43b6526aeebe"],
Cell[42874, 807, 4177, 62, 34, "Output",ExpressionUUID->"82d998aa-25ab-461f-a3e7-5abd52c0f61d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47088, 874, 1020, 27, 71, "Input",ExpressionUUID->"7ab6f854-39e6-4b39-a577-79b35d6f5549"],
Cell[48111, 903, 3777, 60, 37, "Output",ExpressionUUID->"7156eff2-a9f7-4a01-9ed9-bc10e43934fb"],
Cell[51891, 965, 3606, 55, 34, "Output",ExpressionUUID->"78541d38-b5f3-462f-92d9-d8965affae3e"],
Cell[55500, 1022, 3829, 62, 37, "Output",ExpressionUUID->"1845be3f-a00a-46b3-b943-84d12129f6b2"]
}, Open  ]],
Cell[59344, 1087, 148, 3, 35, "Text",ExpressionUUID->"c4a0d137-bb0b-4834-bbff-a923b290f906"],
Cell[CellGroupData[{
Cell[59517, 1094, 403, 11, 31, "Input",ExpressionUUID->"d27ab50d-56a0-4318-a299-99164c16b850"],
Cell[59923, 1107, 3733, 59, 34, "Output",ExpressionUUID->"44bae80a-c1c1-48d9-a386-6efc03849327"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63693, 1171, 1490, 40, 111, "Input",ExpressionUUID->"226eab27-6842-4374-9195-3e2da6a6a8ed"],
Cell[65186, 1213, 4114, 71, 57, "Output",ExpressionUUID->"e560b660-e84e-4c06-b48e-099bbfeb0aa1"],
Cell[69303, 1286, 3766, 60, 55, "Output",ExpressionUUID->"a83675a6-01f3-4aea-b2fd-7ab3fe4b3b39"],
Cell[73072, 1348, 4408, 79, 59, "Output",ExpressionUUID->"fbc1635b-fc05-4d82-9d77-30c8e6a7f802"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77517, 1432, 409, 9, 31, "Input",ExpressionUUID->"3d2f2f06-c7f7-4c29-9067-705bc4d65d5e"],
Cell[77929, 1443, 1255, 30, 57, "Output",ExpressionUUID->"35b8ac6e-6a45-4252-a2cf-1101c1af47a2"]
}, Open  ]],
Cell[79199, 1476, 298, 5, 35, "Text",ExpressionUUID->"020867d9-cd29-4cbc-91a2-c1c025895d50"],
Cell[CellGroupData[{
Cell[79522, 1485, 403, 11, 31, "Input",ExpressionUUID->"2ec89a7a-d435-4177-a21f-713f348928b8"],
Cell[79928, 1498, 3749, 59, 34, "Output",ExpressionUUID->"97c378db-1be5-40ac-9e15-fd79ef2eb581"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83714, 1562, 1386, 38, 91, "Input",ExpressionUUID->"ea944281-bc0f-43a5-9102-da85cfff3b0d"],
Cell[85103, 1602, 4078, 71, 57, "Output",ExpressionUUID->"a00b45e8-40f6-440b-8962-1c4afee647d8"],
Cell[89184, 1675, 3730, 60, 55, "Output",ExpressionUUID->"bc3bbfdf-fa95-40a9-9398-01d0f30540ce"],
Cell[92917, 1737, 4369, 79, 59, "Output",ExpressionUUID->"e4ce2c42-2738-4a82-8cde-1028fc47f5f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97323, 1821, 499, 12, 31, "Input",ExpressionUUID->"f96bdcc7-09d4-45d2-9cf3-e45eae7a9090"],
Cell[97825, 1835, 1352, 33, 56, "Output",ExpressionUUID->"1604c65f-4c7a-4f3f-b255-2a7d70760a4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99214, 1873, 474, 12, 30, "Input",ExpressionUUID->"d8829b46-2169-4d11-9cc0-ff89de2c58ea"],
Cell[99691, 1887, 622, 11, 35, "Output",ExpressionUUID->"92f8b49c-bd1d-4c13-bfa1-02a8f04955d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100350, 1903, 688, 20, 30, "Input",ExpressionUUID->"2a524f92-f72e-4c44-a805-7ad6cb4f56e5"],
Cell[101041, 1925, 925, 23, 56, "Output",ExpressionUUID->"edfa5492-4ce4-4aa0-a3a6-5609061848a9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102003, 1953, 287, 6, 30, "Input",ExpressionUUID->"d6bf6256-0a24-4ccb-a269-d7e478be1a45"],
Cell[102293, 1961, 633, 11, 35, "Output",ExpressionUUID->"96f3f77a-f7af-4bbf-8be4-926c3e31ffb3"]
}, Open  ]],
Cell[102941, 1975, 179, 3, 51, "Text",ExpressionUUID->"2953cdb4-9adc-4cf2-b170-2a8aea13e68d"],
Cell[CellGroupData[{
Cell[103145, 1982, 1970, 45, 71, "Input",ExpressionUUID->"50482738-96ce-4929-8e08-f939d04ed38e"],
Cell[105118, 2029, 6804, 149, 105, "Output",ExpressionUUID->"9620880d-0e6f-4e18-a3b6-b5b0854c3203"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111959, 2183, 2162, 51, 91, "Input",ExpressionUUID->"047d3352-a18f-49b6-9aac-c0fbe711aa24"],
Cell[114124, 2236, 30615, 751, 819, "Output",ExpressionUUID->"5e1cd10f-8f0b-4f8d-b252-1f253803d509"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144776, 2992, 1805, 43, 71, "Input",ExpressionUUID->"dda52fc4-7d9d-40c6-91c6-fe7e1b06e9b7"],
Cell[146584, 3037, 6539, 146, 105, "Output",ExpressionUUID->"0f46d1f8-624a-4c07-a9f0-fff153288e6f"]
}, Open  ]],
Cell[153138, 3186, 2185, 57, 91, "Input",ExpressionUUID->"08266c2f-9642-4160-99eb-c147cd098500"],
Cell[CellGroupData[{
Cell[155348, 3247, 1735, 42, 71, "Input",ExpressionUUID->"aae63640-282d-4530-a862-7fafd9b768c9"],
Cell[157086, 3291, 6439, 144, 105, "Output",ExpressionUUID->"59160e79-5dd6-4333-939b-82c338407c59"]
}, Open  ]],
Cell[163540, 3438, 1978, 51, 91, "Input",ExpressionUUID->"06f997ec-7c92-4a21-9a2b-07d18a6b0934"],
Cell[CellGroupData[{
Cell[165543, 3493, 1678, 41, 71, "Input",ExpressionUUID->"3eb07f67-d163-418e-bbfb-0f3d34e96ae6"],
Cell[167224, 3536, 6327, 142, 105, "Output",ExpressionUUID->"169d2849-b1c1-4da9-8f7c-f4f1c713925f"]
}, Open  ]],
Cell[173566, 3681, 2083, 55, 91, "Input",ExpressionUUID->"b42c13be-259c-41aa-81bf-26d2aa560f63"],
Cell[175652, 3738, 369, 5, 51, "Text",ExpressionUUID->"3833bfd4-d706-4e73-866c-e8a298e84907"],
Cell[176024, 3745, 294, 6, 30, "Input",ExpressionUUID->"7ca10a5b-d270-4e81-89f8-3366635f9a00"],
Cell[CellGroupData[{
Cell[176343, 3755, 609, 10, 30, "Input",ExpressionUUID->"47385cd9-161e-4f52-9690-1a66d77b054a"],
Cell[176955, 3767, 3377, 49, 34, "Output",ExpressionUUID->"4c03f43b-5ec8-43d4-abf1-10f066f09f35"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180369, 3821, 255, 4, 31, "Input",ExpressionUUID->"2608d2c2-be49-4e96-89d9-c2c5f47a38d8"],
Cell[180627, 3827, 3474, 56, 34, "Output",ExpressionUUID->"f8b96837-ee61-434c-a94e-de367a284378"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184138, 3888, 320, 7, 31, "Input",ExpressionUUID->"da9dbef9-ff78-44f3-bd41-4cf285f57484"],
Cell[184461, 3897, 3443, 53, 37, "Output",ExpressionUUID->"c61afa6e-1b0b-4ee5-9c60-bf687db139a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187941, 3955, 355, 7, 30, "Input",ExpressionUUID->"aa7e92ae-3287-4f13-ae3e-1a67202078fa"],
Cell[188299, 3964, 3770, 55, 34, "Output",ExpressionUUID->"f5e1fe67-f2ea-4185-86f4-49efe5b896d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192106, 4024, 539, 10, 31, "Input",ExpressionUUID->"003b6122-9dcd-42e7-9783-098b78282ae7"],
Cell[192648, 4036, 4759, 87, 59, "Output",ExpressionUUID->"49478ab7-4fa2-4c50-b423-b2a030386cf4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197444, 4128, 380, 8, 31, "Input",ExpressionUUID->"28d31074-4f4a-4e2d-9208-308b71fd10c2"],
Cell[197827, 4138, 4406, 78, 62, "Output",ExpressionUUID->"4382f131-76de-4bcd-84bc-852ebbd23687"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202270, 4221, 383, 9, 31, "Input",ExpressionUUID->"42777a7e-1e61-4635-b770-c8df2eaea8d6"],
Cell[202656, 4232, 1509, 37, 62, "Output",ExpressionUUID->"6af764f1-1a5c-470d-965a-5411cb3cc86d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204202, 4274, 244, 4, 31, "Input",ExpressionUUID->"91cd6d3e-a035-4c92-a28f-3e8bfd1a8d78"],
Cell[204449, 4280, 2167, 52, 62, "Output",ExpressionUUID->"20501c8b-af81-4012-aa73-3cb96084f780"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206653, 4337, 362, 8, 31, "Input",ExpressionUUID->"aa5b9fc9-3db1-45c7-b21f-600f4b8fb097"],
Cell[207018, 4347, 1694, 43, 62, "Output",ExpressionUUID->"4ad8428c-8c64-4a70-ae09-1f6b776f3541"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208749, 4395, 740, 17, 31, "Input",ExpressionUUID->"2fcfb9d3-d71f-4eff-a759-800035f4d8e9"],
Cell[209492, 4414, 2109, 53, 63, "Output",ExpressionUUID->"3293ebb2-4f47-4dd5-8c0e-6f5cfc357b4c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211638, 4472, 382, 10, 30, "Input",ExpressionUUID->"c02698be-b555-4742-9805-e947541c8515"],
Cell[212023, 4484, 1223, 31, 56, "Output",ExpressionUUID->"f299228b-80d9-49b0-9786-856c682536cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[213283, 4520, 1173, 32, 73, "Input",ExpressionUUID->"349635be-57a6-4535-9f8d-c820512f4007"],
Cell[214459, 4554, 982, 24, 56, "Output",ExpressionUUID->"bf7cf17e-ce78-4507-ae6f-01466826629b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215478, 4583, 206, 3, 30, "Input",ExpressionUUID->"3f7b239e-9bbe-45ae-9150-6a2fa67244dd"],
Cell[215687, 4588, 1015, 27, 54, "Output",ExpressionUUID->"1ffae74c-1901-4de3-bb63-d10dfac1a906"]
}, Open  ]],
Cell[CellGroupData[{
Cell[216739, 4620, 206, 3, 30, "Input",ExpressionUUID->"1499267e-4996-4dca-8062-d46aa5a4e45f"],
Cell[216948, 4625, 943, 23, 56, "Output",ExpressionUUID->"c01b20d9-4c37-4945-8375-445c5ff85e6a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217928, 4653, 1024, 26, 73, "Input",ExpressionUUID->"c7a2c5a5-48d4-433b-9f85-6a602c20670e"],
Cell[218955, 4681, 1421, 35, 61, "Output",ExpressionUUID->"cfd2f44b-d0c1-44f7-be9c-d4d0498eb64b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220413, 4721, 211, 3, 30, "Input",ExpressionUUID->"2e88868d-87d9-4057-9959-26d246d5e5d9"],
Cell[220627, 4726, 1262, 33, 61, "Output",ExpressionUUID->"8d60960d-27ef-4e31-ad6f-8345264aa545"]
}, Open  ]],
Cell[221904, 4762, 236, 4, 35, "Text",ExpressionUUID->"45e62339-fa1a-4989-aea3-36bdddd2b500"],
Cell[CellGroupData[{
Cell[222165, 4770, 1688, 52, 91, "Input",ExpressionUUID->"66e4a244-31b3-4d77-a9d5-ca0fdf43a22a"],
Cell[223856, 4824, 2972, 43, 34, "Output",ExpressionUUID->"e9f9f753-5fbf-474c-827c-2b0a4ff5171f"],
Cell[226831, 4869, 2993, 44, 34, "Output",ExpressionUUID->"70aac965-f01b-4b74-aec6-d00806c9e9f6"],
Cell[229827, 4915, 2991, 44, 34, "Output",ExpressionUUID->"f268474d-7c25-4145-b607-004f67beb788"],
Cell[232821, 4961, 2985, 43, 34, "Output",ExpressionUUID->"9d777167-192c-4244-a48c-1fff3818961d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235843, 5009, 667, 18, 51, "Input",ExpressionUUID->"d0fe302e-daee-4687-af0f-81f603d1e7ad"],
Cell[236513, 5029, 1804, 47, 62, "Output",ExpressionUUID->"15f325a7-49ee-4766-928f-b1489817e31d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[238354, 5081, 811, 20, 51, "Input",ExpressionUUID->"31813d3a-0c1b-4633-9275-b8f0c43e5d9d"],
Cell[239168, 5103, 2540, 65, 58, "Output",ExpressionUUID->"f8276c83-58be-4044-9f07-bbf069de3629"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241745, 5173, 340, 7, 31, "Input",ExpressionUUID->"df3860b4-e702-4adf-8f77-17cfef5ea08f"],
Cell[242088, 5182, 2230, 58, 63, "Output",ExpressionUUID->"0bd0191f-6b5e-4d4c-8539-24c75da32128"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[244367, 5246, 197, 3, 67, "Section",ExpressionUUID->"657d70d2-f37c-4724-9f19-6d870b655bd9"],
Cell[244567, 5251, 315, 7, 35, "Text",ExpressionUUID->"8aca3365-0534-40ad-85fb-f6756cc2c34b"],
Cell[CellGroupData[{
Cell[244907, 5262, 609, 10, 30, "Input",ExpressionUUID->"361989b0-5e04-4d76-905c-2274a750bdaf"],
Cell[245519, 5274, 4067, 58, 34, "Output",ExpressionUUID->"5825e59f-9f20-475f-9234-08e175af7aac"]
}, Open  ]],
Cell[249601, 5335, 583, 11, 31, "Input",ExpressionUUID->"c5486be1-b1b6-48ae-bace-de710f169382"],
Cell[250187, 5348, 1201, 23, 31, "Input",ExpressionUUID->"9b64d72b-2a86-4502-9f7d-dcc5d16da8cc"],
Cell[251391, 5373, 272, 6, 35, "Text",ExpressionUUID->"a226dfe2-4055-4445-95e0-bd4c4611c7bb"],
Cell[CellGroupData[{
Cell[251688, 5383, 1281, 30, 71, "Input",ExpressionUUID->"7335208d-ced6-4bb6-a342-7a2e03b04abc"],
Cell[252972, 5415, 3279, 47, 34, "Output",ExpressionUUID->"890fe186-e69b-424c-b8c8-7a0ae7961fad"]
}, Open  ]],
Cell[256266, 5465, 209, 3, 35, "Text",ExpressionUUID->"593fee1b-a173-4669-8453-45a47c32557b"],
Cell[256478, 5470, 1099, 24, 51, "Input",ExpressionUUID->"db939458-1278-47a5-9297-fea4cf6e93e3"],
Cell[257580, 5496, 179, 3, 35, "Text",ExpressionUUID->"d66bfdce-39ae-4071-9b2f-39f713e04153"],
Cell[CellGroupData[{
Cell[257784, 5503, 2072, 38, 51, "Input",ExpressionUUID->"eca3a922-6605-49af-8e03-a6124456c7c1"],
Cell[259859, 5543, 3931, 64, 37, "Output",ExpressionUUID->"3ca0f1be-69ca-41f9-a97c-1545340269f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263827, 5612, 8629, 155, 171, "Input",ExpressionUUID->"f5103d3c-5f30-4278-8992-91909b0b6445"],
Cell[272459, 5769, 2740, 48, 37, "Output",ExpressionUUID->"fa742351-26cb-4226-a2a2-2b030789b7d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275236, 5822, 1099, 23, 71, "Input",ExpressionUUID->"ad38bf0a-3f3c-4380-b411-1b7fe67b95a2"],
Cell[276338, 5847, 1920, 27, 34, "Output",ExpressionUUID->"cdb36b84-49ef-4369-af5a-4080f1a411d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[278295, 5879, 271, 6, 51, "Input",ExpressionUUID->"1b0391dd-868a-4fae-a689-9900ee789895"],
Cell[278569, 5887, 2836, 56, 62, "Output",ExpressionUUID->"fc1b8661-c1b1-4025-b2d8-feda041178f9"],
Cell[281408, 5945, 3203, 65, 57, "Output",ExpressionUUID->"8f72ce4e-6b04-4990-a953-b0f225dc0658"]
}, Open  ]],
Cell[284626, 6013, 189, 3, 35, "Text",ExpressionUUID->"9cc7b6da-50f1-4d9d-a537-68cae550802d"],
Cell[CellGroupData[{
Cell[284840, 6020, 647, 13, 31, "Input",ExpressionUUID->"4439917b-6d3b-49ed-b2fc-d30b571c2bd6"],
Cell[285490, 6035, 1313, 22, 34, "Output",ExpressionUUID->"b4e706aa-a312-4f79-b234-25c84079d895"]
}, Open  ]],
Cell[CellGroupData[{
Cell[286840, 6062, 908, 23, 51, "Input",ExpressionUUID->"0d4a1721-ac40-4c4e-a2e5-f8e2e1dab699"],
Cell[287751, 6087, 1120, 30, 60, "Output",ExpressionUUID->"9cb68fee-a651-44aa-95fd-19d4b43593fe"]
}, Open  ]],
Cell[288886, 6120, 1444, 30, 51, "Input",ExpressionUUID->"6cec3b12-2be4-4e93-81ac-268cc479bbba"],
Cell[290333, 6152, 410, 8, 31, "Input",ExpressionUUID->"31a49396-12d2-4a7c-a9ed-ce85529e868a"],
Cell[CellGroupData[{
Cell[290768, 6164, 208, 3, 31, "Input",ExpressionUUID->"56c8fa35-0232-4b0a-a422-58cbdd9988e3"],
Cell[290979, 6169, 875, 12, 34, "Output",ExpressionUUID->"cc3b4bfa-b115-43d8-aa13-a73a1b60ba09"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291891, 6186, 418, 9, 31, "Input",ExpressionUUID->"26c125d5-7cc4-49c8-a72d-0a620a8f08a8"],
Cell[292312, 6197, 958, 18, 34, "Output",ExpressionUUID->"f702255e-b4c8-4d22-99a0-f234ca76800e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293307, 6220, 177, 2, 30, "Input",ExpressionUUID->"ca12a261-9576-494a-9368-fdac398c898c"],
Cell[293487, 6224, 987, 22, 37, "Output",ExpressionUUID->"fabfc40f-16c4-492c-8687-03d3f5c2814a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294511, 6251, 183, 3, 30, "Input",ExpressionUUID->"0222ed67-5f86-49fe-81da-23232955ef29"],
Cell[294697, 6256, 1616, 41, 59, "Output",ExpressionUUID->"e3e1b6a2-4321-4c95-b4ca-0d9f9574cef7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[296350, 6302, 183, 3, 30, "Input",ExpressionUUID->"5438af5a-996f-4f80-bba5-d85382e877dc"],
Cell[296536, 6307, 1618, 41, 59, "Output",ExpressionUUID->"53a8f23c-4c10-4d23-a0a3-b90df9373e58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298191, 6353, 344, 8, 31, "Input",ExpressionUUID->"b8503c64-770b-4eeb-88e3-a76cc9e5b09b"],
Cell[298538, 6363, 25782, 693, 1032, "Output",ExpressionUUID->"4fde3405-dd82-423e-91cf-4a3f1e384968"]
}, Open  ]],
Cell[CellGroupData[{
Cell[324357, 7061, 207, 4, 31, "Input",ExpressionUUID->"fb6f1ea3-3479-43bd-8cdc-8dc1fb403361"],
Cell[324567, 7067, 1161, 29, 38, "Output",ExpressionUUID->"c8ada77f-6569-4ecf-a2f3-d02d11033429"]
}, Open  ]],
Cell[325743, 7099, 1299, 29, 51, "Input",ExpressionUUID->"cee7f10d-6bbb-497c-967f-48d22116b4c3"],
Cell[CellGroupData[{
Cell[327067, 7132, 7100, 187, 491, "Input",ExpressionUUID->"f8023d9b-83b5-48ba-8e2b-290f08d92314"],
Cell[334170, 7321, 20541, 376, 63, "Output",ExpressionUUID->"11c01fe3-6e0b-4484-9445-531820021e08"],
Cell[CellGroupData[{
Cell[354736, 7701, 1123, 18, 24, "Print",ExpressionUUID->"379ab4b3-34d9-439b-afba-3d183ab18d64"],
Cell[355862, 7721, 1123, 18, 24, "Print",ExpressionUUID->"7b1a3e1e-3cd2-4884-ad8c-8f376846ee19"],
Cell[356988, 7741, 1125, 18, 24, "Print",ExpressionUUID->"2908eb9d-79b5-4d74-a3ce-d05e3f8fbdb4"],
Cell[358116, 7761, 1123, 18, 24, "Print",ExpressionUUID->"96f62046-7828-4244-a445-c1a0a8b4c174"],
Cell[359242, 7781, 1123, 18, 24, "Print",ExpressionUUID->"bc003454-f956-41fc-bed8-4ccbdc7cf60c"],
Cell[360368, 7801, 1123, 18, 24, "Print",ExpressionUUID->"55e1f5ed-04a4-4462-81ea-5afd108c7dcf"],
Cell[361494, 7821, 1123, 18, 24, "Print",ExpressionUUID->"711d1c33-f110-44c7-8687-4c486f6ebfb5"],
Cell[362620, 7841, 1123, 18, 24, "Print",ExpressionUUID->"aa96cdd4-74e7-4083-97a7-61eeb3bff8cb"],
Cell[363746, 7861, 1123, 18, 24, "Print",ExpressionUUID->"914a67b0-9180-4e4e-9357-b337a7da535e"],
Cell[364872, 7881, 1124, 18, 24, "Print",ExpressionUUID->"4aeef5aa-42b5-449f-aab7-8bce99a738a7"]
}, Open  ]],
Cell[366011, 7902, 1554, 23, 34, "Output",ExpressionUUID->"ad80dbc1-b7ea-428f-9196-e4663292b402"]
}, Open  ]],
Cell[367580, 7928, 1061, 30, 94, "Input",ExpressionUUID->"769078c4-53d7-40ce-821e-6954d419c919"],
Cell[368644, 7960, 6704, 176, 251, "Input",ExpressionUUID->"68061e1a-25e1-4db7-9a27-6ec98ebea197"],
Cell[375351, 8138, 1933, 60, 91, "Input",ExpressionUUID->"80b134b3-4c03-4432-a631-e1beacb79dcf"],
Cell[377287, 8200, 4748, 149, 251, "Input",ExpressionUUID->"6a6d3f24-4e91-4ff2-aaff-96c913939b76"],
Cell[382038, 8351, 2153, 63, 91, "Input",ExpressionUUID->"463c41e2-e317-4e2f-9ebb-8bdf07ea1ab7"],
Cell[CellGroupData[{
Cell[384216, 8418, 1003, 22, 71, "Input",ExpressionUUID->"26186c48-d4ca-425f-b029-7dbb1a8902bf"],
Cell[385222, 8442, 1103, 23, 34, "Output",ExpressionUUID->"7d7c9378-e226-45d2-9295-22e28323f8b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386362, 8470, 294, 8, 31, "Input",ExpressionUUID->"5c1e8768-f71c-4147-8412-51934ecb86c1"],
Cell[386659, 8480, 1694, 45, 34, "Output",ExpressionUUID->"b0b5df0a-c6f5-4055-b123-4d6b5d03a19f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[388390, 8530, 363, 10, 31, "Input",ExpressionUUID->"4e1d0dd1-1f93-4e92-908c-16c8d9c8e400"],
Cell[388756, 8542, 2912, 59, 57, "Output",ExpressionUUID->"9ef73319-f595-4077-9f39-5663823887c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391705, 8606, 182, 3, 30, "Input",ExpressionUUID->"95460580-95b2-487c-951a-da546faa0903"],
Cell[391890, 8611, 870, 22, 37, "Output",ExpressionUUID->"0355bf98-1754-408a-bf34-7e62a32c9e58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[392797, 8638, 889, 23, 56, "Input",ExpressionUUID->"1fc4a148-5087-4a44-8523-1ebef3c11572"],
Cell[393689, 8663, 863, 22, 37, "Output",ExpressionUUID->"cc3125c5-f5f5-43fc-bcdd-63e6db8f6905"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394589, 8690, 386, 11, 31, "Input",ExpressionUUID->"5ea72838-e8e9-4809-ada1-b4314c04ad6a"],
Cell[394978, 8703, 751, 13, 34, "Output",ExpressionUUID->"20bdcc45-fd55-42da-ae1d-bbf374b2cef7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395766, 8721, 526, 15, 31, "Input",ExpressionUUID->"1725f0a3-ab4b-437a-9030-310f694fab45"],
Cell[396295, 8738, 1262, 29, 37, "Output",ExpressionUUID->"ac054438-132b-4867-8ced-e908f232b0fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397594, 8772, 23371, 530, 831, "Input",ExpressionUUID->"e4c231bc-e461-4314-921f-e0a71b3e91c0"],
Cell[420968, 9304, 14133, 297, 665, "Output",ExpressionUUID->"8b9f97e6-437c-4bb8-b074-8dcdd3b27b8f"]
}, Open  ]]
}, Open  ]]
}
]
*)

